@@ -3,8 +3,8 @@ package aws
 import (
 	"fmt"
 	"log"
-	"time"
 
+	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/sts"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 )
@@ -44,7 +44,7 @@ func dataSourceAwsCallerIdentityRead(d *schema.ResourceData, meta interface{}) e
 
 	log.Printf("[DEBUG] Received Caller Identity: %s", res)
 
-	d.SetId(time.Now().UTC().String())
+	d.SetId(aws.StringValue(res.Account))
 	d.Set("account_id", res.Account)
 	d.Set("arn", res.Arn)
 	d.Set("user_id", res.UserId)
