@@ -3,7 +3,6 @@ package aws
 import (
 	"encoding/base64"
 	"log"
-	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/kms"
@@ -43,8 +42,6 @@ func dataSourceAwsKmsCiphertext() *schema.Resource {
 func dataSourceAwsKmsCiphertextRead(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).kmsconn
 
-	d.SetId(time.Now().UTC().String())
-
 	req := &kms.EncryptInput{
 		KeyId:     aws.String(d.Get("key_id").(string)),
 		Plaintext: []byte(d.Get("plaintext").(string)),
@@ -60,6 +57,8 @@ func dataSourceAwsKmsCiphertextRead(d *schema.ResourceData, meta interface{}) er
 		return err
 	}
 
+	d.SetId(aws.StringValue(resp.KeyId))
+
 	d.Set("ciphertext_blob", base64.StdEncoding.EncodeToString(resp.CiphertextBlob))
 
 	return nil
