@@ -2,13 +2,15 @@ package aws
 
 import (
 	"testing"
+
+	"github.com/aws/aws-sdk-go/aws/endpoints"
 )
 
 func TestHostedZoneIDForRegion(t *testing.T) {
-	if r, _ := HostedZoneIDForRegion("us-east-1"); r != "Z3AQBSTGFYJSTF" {
+	if r, _ := HostedZoneIDForRegion(endpoints.UsEast1RegionID); r != "Z3AQBSTGFYJSTF" {
 		t.Fatalf("bad: %s", r)
 	}
-	if r, _ := HostedZoneIDForRegion("ap-southeast-2"); r != "Z1WCIGYICN2BYD" {
+	if r, _ := HostedZoneIDForRegion(endpoints.ApSoutheast2RegionID); r != "Z1WCIGYICN2BYD" {
 		t.Fatalf("bad: %s", r)
 	}
 
