@@ -5,7 +5,8 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
+	"github.com/aws/aws-sdk-go/aws"
+	"github.com/aws/aws-sdk-go/service/glue"
 )
 
 func ReadAwsGluePartitionID(id string) (catalogID string, dbName string, tableName string, values []string, error error) {
@@ -17,16 +18,28 @@ func ReadAwsGluePartitionID(id string) (catalogID string, dbName string, tableNa
 	return idParts[0], idParts[1], idParts[2], vals, nil
 }
 
-func CreateAwsGluePartitionID(catalogID, dbName, tableName string, values *schema.Set) string {
+func CreateAwsGluePartitionID(catalogID, dbName, tableName string, values []interface{}) string {
 	return fmt.Sprintf("%s:%s:%s:%s", catalogID, dbName, tableName, stringifyAwsGluePartition(values))
 }
 
-func stringifyAwsGluePartition(partValues *schema.Set) string {
+func stringifyAwsGluePartition(partValues []interface{}) string {
 	var b bytes.Buffer
-	for _, val := range partValues.List() {
+	for _, val := range partValues {
 		b.WriteString(fmt.Sprintf("%s#", val.(string)))
 	}
 	vals := strings.Trim(b.String(), "#")
 
 	return vals
 }
+
+func CreateAwsGlueRegistryID(id string) *glue.RegistryId {
+	return &glue.RegistryId{
+		RegistryArn: aws.String(id),
+	}
+}
+
+func CreateAwsGlueSchemaID(id string) *glue.SchemaId {
+	return &glue.SchemaId{
+		SchemaArn: aws.String(id),
+	}
+}
