@@ -2,10 +2,10 @@ package aws
 
 import (
 	"fmt"
+	"regexp"
 	"testing"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/awserr"
 	"github.com/aws/aws-sdk-go/service/apigateway"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/acctest"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
@@ -14,8 +14,8 @@ import (
 
 func TestAccAWSAPIGatewayUsagePlan_basic(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
-	updatedName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	updatedName := acctest.RandomWithPrefix("tf-acc-test-2")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -28,7 +28,12 @@ func TestAccAWSAPIGatewayUsagePlan_basic(t *testing.T) {
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
+					testAccMatchResourceAttrRegionalARNNoAccount(resourceName, "arn", "apigateway", regexp.MustCompile(`/usageplans/+.`)),
 					resource.TestCheckResourceAttr(resourceName, "description", ""),
+					resource.TestCheckResourceAttr(resourceName, "tags.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "api_stages.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "quota_settings.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "throttle_settings.%", "0"),
 				),
 			},
 			{
@@ -37,28 +42,20 @@ func TestAccAWSAPIGatewayUsagePlan_basic(t *testing.T) {
 				ImportStateVerify: true,
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanBasicUpdatedConfig(updatedName),
+				Config: testAccAWSApiGatewayUsagePlanBasicConfig(updatedName),
 				Check: resource.ComposeTestCheckFunc(
 					resource.TestCheckResourceAttr(resourceName, "name", updatedName),
 					resource.TestCheckResourceAttr(resourceName, "description", ""),
 				),
 			},
-			{
-				Config: testAccAWSApiGatewayUsagePlanBasicConfig(rName),
-				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "name", rName),
-					resource.TestCheckResourceAttr(resourceName, "description", ""),
-				),
-			},
 		},
 	})
 }
 
 func TestAccAWSAPIGatewayUsagePlan_tags(t *testing.T) {
 	var conf apigateway.UsagePlan
-	name := acctest.RandString(10)
-	resourceName := "aws_api_gateway_usage_plan.main"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t); testAccAPIGatewayTypeEDGEPreCheck(t) },
@@ -66,10 +63,10 @@ func TestAccAWSAPIGatewayUsagePlan_tags(t *testing.T) {
 		CheckDestroy: testAccCheckAWSAPIGatewayUsagePlanDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccAWSApiGatewayUsagePlanBasicTags1(name, "key1", "value1"),
+				Config: testAccAWSApiGatewayUsagePlanBasicTags1(rName, "key1", "value1"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "name", name),
+					resource.TestCheckResourceAttr(resourceName, "name", rName),
 					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
 					resource.TestCheckResourceAttr(resourceName, "tags.key1", "value1"),
 				),
@@ -80,19 +77,19 @@ func TestAccAWSAPIGatewayUsagePlan_tags(t *testing.T) {
 				ImportStateVerify: true,
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanBasicTags2(name, "key1", "value1updated", "key2", "value2"),
+				Config: testAccAWSApiGatewayUsagePlanBasicTags2(rName, "key1", "value1updated", "key2", "value2"),
 				Check: resource.ComposeTestCheckFunc(
-					resource.TestCheckResourceAttr(resourceName, "name", name),
+					resource.TestCheckResourceAttr(resourceName, "name", rName),
 					resource.TestCheckResourceAttr(resourceName, "tags.%", "2"),
 					resource.TestCheckResourceAttr(resourceName, "tags.key1", "value1updated"),
 					resource.TestCheckResourceAttr(resourceName, "tags.key2", "value2"),
 				),
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanBasicTags1(name, "key2", "value2"),
+				Config: testAccAWSApiGatewayUsagePlanBasicTags1(rName, "key2", "value2"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "name", name),
+					resource.TestCheckResourceAttr(resourceName, "name", rName),
 					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
 					resource.TestCheckResourceAttr(resourceName, "tags.key2", "value2"),
 				),
@@ -103,7 +100,7 @@ func TestAccAWSAPIGatewayUsagePlan_tags(t *testing.T) {
 
 func TestAccAWSAPIGatewayUsagePlan_description(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -124,20 +121,20 @@ func TestAccAWSAPIGatewayUsagePlan_description(t *testing.T) {
 				ImportStateVerify: true,
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanDescriptionConfig(rName),
+				Config: testAccAWSApiGatewayUsagePlanDescriptionConfig(rName, "This is a description"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "description", "This is a description"),
 				),
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanDescriptionUpdatedConfig(rName),
+				Config: testAccAWSApiGatewayUsagePlanDescriptionConfig(rName, "This is a new description"),
 				Check: resource.ComposeTestCheckFunc(
 					resource.TestCheckResourceAttr(resourceName, "description", "This is a new description"),
 				),
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanDescriptionConfig(rName),
+				Config: testAccAWSApiGatewayUsagePlanDescriptionConfig(rName, "This is a description"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "description", "This is a description"),
@@ -156,7 +153,7 @@ func TestAccAWSAPIGatewayUsagePlan_description(t *testing.T) {
 
 func TestAccAWSAPIGatewayUsagePlan_productCode(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -165,10 +162,10 @@ func TestAccAWSAPIGatewayUsagePlan_productCode(t *testing.T) {
 		CheckDestroy: testAccCheckAWSAPIGatewayUsagePlanDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccAWSApiGatewayUsagePlanBasicConfig(rName),
+				Config: testAccAWSApiGatewayUsagePlanProductCodeConfig(rName, "MYCODE"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "product_code", ""),
+					resource.TestCheckResourceAttr(resourceName, "product_code", "MYCODE"),
 				),
 			},
 			{
@@ -177,25 +174,12 @@ func TestAccAWSAPIGatewayUsagePlan_productCode(t *testing.T) {
 				ImportStateVerify: true,
 			},
 			{
-				Config: testAccAWSApiGatewayUsagePlanProductCodeConfig(rName),
+				Config: testAccAWSApiGatewayUsagePlanProductCodeConfig(rName, "MYCODE2"),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "product_code", "MYCODE"),
-				),
-			},
-			{
-				Config: testAccAWSApiGatewayUsagePlanProductCodeUpdatedConfig(rName),
-				Check: resource.ComposeTestCheckFunc(
 					resource.TestCheckResourceAttr(resourceName, "product_code", "MYCODE2"),
 				),
 			},
-			{
-				Config: testAccAWSApiGatewayUsagePlanProductCodeConfig(rName),
-				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
-					resource.TestCheckResourceAttr(resourceName, "product_code", "MYCODE"),
-				),
-			},
 			{
 				Config: testAccAWSApiGatewayUsagePlanBasicConfig(rName),
 				Check: resource.ComposeTestCheckFunc(
@@ -203,13 +187,20 @@ func TestAccAWSAPIGatewayUsagePlan_productCode(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "product_code", ""),
 				),
 			},
+			{
+				Config: testAccAWSApiGatewayUsagePlanProductCodeConfig(rName, "MYCODE"),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
+					resource.TestCheckResourceAttr(resourceName, "product_code", "MYCODE"),
+				),
+			},
 		},
 	})
 }
 
 func TestAccAWSAPIGatewayUsagePlan_throttling(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -260,10 +251,10 @@ func TestAccAWSAPIGatewayUsagePlan_throttling(t *testing.T) {
 	})
 }
 
-// https://github.com/terraform-providers/terraform-provider-aws/issues/2057
+// https://github.com/hashicorp/terraform-provider-aws/issues/2057
 func TestAccAWSAPIGatewayUsagePlan_throttlingInitialRateLimit(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -289,7 +280,7 @@ func TestAccAWSAPIGatewayUsagePlan_throttlingInitialRateLimit(t *testing.T) {
 
 func TestAccAWSAPIGatewayUsagePlan_quota(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -344,7 +335,7 @@ func TestAccAWSAPIGatewayUsagePlan_quota(t *testing.T) {
 
 func TestAccAWSAPIGatewayUsagePlan_apiStages(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -359,7 +350,9 @@ func TestAccAWSAPIGatewayUsagePlan_apiStages(t *testing.T) {
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
-					resource.TestCheckResourceAttr(resourceName, "api_stages.0.stage", "test"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "test",
+					}),
 				),
 			},
 			{
@@ -382,16 +375,33 @@ func TestAccAWSAPIGatewayUsagePlan_apiStages(t *testing.T) {
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
-					resource.TestCheckResourceAttr(resourceName, "api_stages.0.stage", "test"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "test",
+					}),
 				),
 			},
 			// Handle api stages updates
+			{
+				Config: testAccAWSApiGatewayUsagePlanApiStagesMultipleConfig(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
+					resource.TestCheckResourceAttr(resourceName, "name", rName),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "foo",
+					}),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "test",
+					}),
+				),
+			},
 			{
 				Config: testAccAWSApiGatewayUsagePlanApiStagesModifiedConfig(rName),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
-					resource.TestCheckResourceAttr(resourceName, "api_stages.0.stage", "foo"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "foo",
+					}),
 				),
 			},
 			{
@@ -406,9 +416,41 @@ func TestAccAWSAPIGatewayUsagePlan_apiStages(t *testing.T) {
 	})
 }
 
+func TestAccAWSAPIGatewayUsagePlan_apiStages_multiple(t *testing.T) {
+	var conf apigateway.UsagePlan
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_api_gateway_usage_plan.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t); testAccAPIGatewayTypeEDGEPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSAPIGatewayUsagePlanDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSApiGatewayUsagePlanApiStagesMultipleConfig(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayUsagePlanExists(resourceName, &conf),
+					resource.TestCheckResourceAttr(resourceName, "name", rName),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "foo",
+					}),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "api_stages.*", map[string]string{
+						"stage": "test",
+					}),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
 func TestAccAWSAPIGatewayUsagePlan_disappears(t *testing.T) {
 	var conf apigateway.UsagePlan
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(10))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_api_gateway_usage_plan.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -449,7 +491,7 @@ func testAccCheckAWSAPIGatewayUsagePlanExists(n string, res *apigateway.UsagePla
 			return err
 		}
 
-		if *up.Id != rs.Primary.ID {
+		if aws.StringValue(up.Id) != rs.Primary.ID {
 			return fmt.Errorf("APIGateway Usage Plan not found")
 		}
 
@@ -468,21 +510,17 @@ func testAccCheckAWSAPIGatewayUsagePlanDestroy(s *terraform.State) error {
 		}
 
 		req := &apigateway.GetUsagePlanInput{
-			UsagePlanId: aws.String(s.RootModule().Resources["aws_api_gateway_rest_api.test"].Primary.ID),
+			UsagePlanId: aws.String(rs.Primary.ID),
 		}
 		describe, err := conn.GetUsagePlan(req)
 
 		if err == nil {
-			if describe.Id != nil && *describe.Id == rs.Primary.ID {
+			if describe.Id != nil && aws.StringValue(describe.Id) == rs.Primary.ID {
 				return fmt.Errorf("API Gateway Usage Plan still exists")
 			}
 		}
 
-		aws2err, ok := err.(awserr.Error)
-		if !ok {
-			return err
-		}
-		if aws2err.Code() != apigateway.ErrCodeNotFoundException {
+		if !isAWSErr(err, apigateway.ErrCodeNotFoundException, "") {
 			return err
 		}
 
@@ -561,7 +599,7 @@ resource "aws_api_gateway_deployment" "foo" {
 }
 
 func testAccAWSApiGatewayUsagePlanBasicConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 }
@@ -569,8 +607,8 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanBasicTags1(rName, tagKey1, tagValue1 string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
-resource "aws_api_gateway_usage_plan" "main" {
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
+resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
   tags = {
@@ -581,8 +619,8 @@ resource "aws_api_gateway_usage_plan" "main" {
 }
 
 func testAccAWSApiGatewayUsagePlanBasicTags2(rName, tagKey1, tagValue1, tagKey2, tagValue2 string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
-resource "aws_api_gateway_usage_plan" "main" {
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
+resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
   tags = {
@@ -593,52 +631,26 @@ resource "aws_api_gateway_usage_plan" "main" {
 `, rName, tagKey1, tagValue1, tagKey2, tagValue2)
 }
 
-func testAccAWSApiGatewayUsagePlanDescriptionConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+func testAccAWSApiGatewayUsagePlanDescriptionConfig(rName, desc string) string {
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
-  name        = "%s"
-  description = "This is a description"
+  name        = %[1]q
+  description = %[2]q
 }
-`, rName)
+`, rName, desc)
 }
 
-func testAccAWSApiGatewayUsagePlanDescriptionUpdatedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+func testAccAWSApiGatewayUsagePlanProductCodeConfig(rName, code string) string {
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
-  name        = "%s"
-  description = "This is a new description"
+  name         = %[1]q
+  product_code = %[2]q
 }
-`, rName)
-}
-
-func testAccAWSApiGatewayUsagePlanProductCodeConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
-resource "aws_api_gateway_usage_plan" "test" {
-  name         = "%s"
-  product_code = "MYCODE"
-}
-`, rName)
-}
-
-func testAccAWSApiGatewayUsagePlanProductCodeUpdatedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
-resource "aws_api_gateway_usage_plan" "test" {
-  name         = "%s"
-  product_code = "MYCODE2"
-}
-`, rName)
-}
-
-func testAccAWSApiGatewayUsagePlanBasicUpdatedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
-resource "aws_api_gateway_usage_plan" "test" {
-  name = "%s"
-}
-`, rName)
+`, rName, code)
 }
 
 func testAccAWSApiGatewayUsagePlanThrottlingConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -651,7 +663,7 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanThrottlingModifiedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -664,7 +676,7 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanQuotaConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -678,7 +690,7 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanQuotaModifiedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -692,7 +704,7 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanApiStagesConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -705,7 +717,7 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 
 func testAccAWSApiGatewayUsagePlanApiStagesModifiedConfig(rName string) string {
-	return fmt.Sprintf(testAccAWSAPIGatewayUsagePlanConfig(rName)+`
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
 resource "aws_api_gateway_usage_plan" "test" {
   name = "%s"
 
@@ -716,3 +728,21 @@ resource "aws_api_gateway_usage_plan" "test" {
 }
 `, rName)
 }
+
+func testAccAWSApiGatewayUsagePlanApiStagesMultipleConfig(rName string) string {
+	return testAccAWSAPIGatewayUsagePlanConfig(rName) + fmt.Sprintf(`
+resource "aws_api_gateway_usage_plan" "test" {
+  name = "%s"
+
+  api_stages {
+    api_id = aws_api_gateway_rest_api.test.id
+    stage  = aws_api_gateway_deployment.foo.stage_name
+  }
+
+  api_stages {
+    api_id = aws_api_gateway_rest_api.test.id
+    stage  = aws_api_gateway_deployment.test.stage_name
+  }
+}
+`, rName)
+}
