@@ -40,6 +40,7 @@ func TestAccAWSAPIGatewayV2Integration_basicWebSocket(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
 					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
 					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29000"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
@@ -82,9 +83,12 @@ func TestAccAWSAPIGatewayV2Integration_basicHttp(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "integration_uri", "https://example.com"),
 					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
-					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29000"),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
+					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
 				),
 			},
 			{
@@ -120,6 +124,96 @@ func TestAccAWSAPIGatewayV2Integration_disappears(t *testing.T) {
 	})
 }
 
+func TestAccAWSAPIGatewayV2Integration_DataMappingHttp(t *testing.T) {
+	var apiId string
+	var v apigatewayv2.GetIntegrationOutput
+	resourceName := "aws_apigatewayv2_integration.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSAPIGatewayV2IntegrationDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSAPIGatewayV2IntegrationConfig_dataMappingHttp(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
+					resource.TestCheckResourceAttr(resourceName, "connection_id", ""),
+					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
+					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", ""),
+					resource.TestCheckResourceAttr(resourceName, "credentials_arn", ""),
+					resource.TestCheckResourceAttr(resourceName, "description", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_method", "ANY"),
+					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_subtype", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_type", "HTTP_PROXY"),
+					resource.TestCheckResourceAttr(resourceName, "integration_uri", "http://www.example.com"),
+					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
+					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "2"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.append:header.header1", "$context.requestId"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.remove:querystring.qs1", "''"),
+					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "2"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "response_parameters.*", map[string]string{
+						"status_code":                    "500",
+						"mappings.%":                     "2",
+						"mappings.append:header.header1": "$context.requestId",
+						"mappings.overwrite:statuscode":  "403",
+					}),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "response_parameters.*", map[string]string{
+						"status_code":                  "404",
+						"mappings.%":                   "1",
+						"mappings.append:header.error": "$stageVariables.environmentId",
+					}),
+					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
+					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
+				),
+			},
+			{
+				Config: testAccAWSAPIGatewayV2IntegrationConfig_dataMappingHttpUpdated(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
+					resource.TestCheckResourceAttr(resourceName, "connection_id", ""),
+					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
+					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", ""),
+					resource.TestCheckResourceAttr(resourceName, "credentials_arn", ""),
+					resource.TestCheckResourceAttr(resourceName, "description", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_method", "ANY"),
+					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_subtype", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_type", "HTTP_PROXY"),
+					resource.TestCheckResourceAttr(resourceName, "integration_uri", "http://www.example.com"),
+					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
+					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "2"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.append:header.header1", "$context.accountId"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.overwrite:header.header2", "$stageVariables.environmentId"),
+					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "response_parameters.*", map[string]string{
+						"status_code":                    "500",
+						"mappings.%":                     "2",
+						"mappings.append:header.header1": "$context.requestId",
+						"mappings.overwrite:statuscode":  "403",
+					}),
+					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
+					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportStateIdFunc: testAccAWSAPIGatewayV2IntegrationImportStateIdFunc(resourceName),
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
 func TestAccAWSAPIGatewayV2Integration_IntegrationTypeHttp(t *testing.T) {
 	var apiId string
 	var v apigatewayv2.GetIntegrationOutput
@@ -151,6 +245,7 @@ func TestAccAWSAPIGatewayV2Integration_IntegrationTypeHttp(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "request_parameters.integration.request.querystring.stage", "'value1'"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "1"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.application/json", ""),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", "$request.body.name"),
 					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "28999"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
@@ -178,6 +273,7 @@ func TestAccAWSAPIGatewayV2Integration_IntegrationTypeHttp(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "2"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.application/json", "#set($number=42)"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.application/xml", "#set($percent=$number/100)"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", "$request.body.id"),
 					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "51"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
@@ -197,7 +293,6 @@ func TestAccAWSAPIGatewayV2Integration_LambdaWebSocket(t *testing.T) {
 	var apiId string
 	var v apigatewayv2.GetIntegrationOutput
 	resourceName := "aws_apigatewayv2_integration.test"
-	callerIdentityDatasourceName := "data.aws_caller_identity.current"
 	lambdaResourceName := "aws_lambda_function.test"
 	rName := acctest.RandomWithPrefix("tf-acc-test")
 
@@ -212,7 +307,7 @@ func TestAccAWSAPIGatewayV2Integration_LambdaWebSocket(t *testing.T) {
 					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
 					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
 					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", "CONVERT_TO_TEXT"),
-					resource.TestCheckResourceAttrPair(resourceName, "credentials_arn", callerIdentityDatasourceName, "arn"),
+					resource.TestCheckResourceAttr(resourceName, "credentials_arn", ""),
 					resource.TestCheckResourceAttr(resourceName, "description", "Test Lambda"),
 					resource.TestCheckResourceAttr(resourceName, "integration_method", "POST"),
 					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", "${integration.response.body.errorMessage}"),
@@ -223,6 +318,7 @@ func TestAccAWSAPIGatewayV2Integration_LambdaWebSocket(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
 					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
 					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29000"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
@@ -242,7 +338,6 @@ func TestAccAWSAPIGatewayV2Integration_LambdaHttp(t *testing.T) {
 	var apiId string
 	var v apigatewayv2.GetIntegrationOutput
 	resourceName := "aws_apigatewayv2_integration.test"
-	callerIdentityDatasourceName := "data.aws_caller_identity.current"
 	lambdaResourceName := "aws_lambda_function.test"
 	rName := acctest.RandomWithPrefix("tf-acc-test")
 
@@ -257,7 +352,7 @@ func TestAccAWSAPIGatewayV2Integration_LambdaHttp(t *testing.T) {
 					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
 					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
 					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", ""),
-					resource.TestCheckResourceAttrPair(resourceName, "credentials_arn", callerIdentityDatasourceName, "arn"),
+					resource.TestCheckResourceAttr(resourceName, "credentials_arn", ""),
 					resource.TestCheckResourceAttr(resourceName, "description", "Test Lambda"),
 					resource.TestCheckResourceAttr(resourceName, "integration_method", "POST"),
 					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", ""),
@@ -268,8 +363,9 @@ func TestAccAWSAPIGatewayV2Integration_LambdaHttp(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "2.0"),
 					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
-					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29000"),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
 				),
 			},
@@ -313,6 +409,7 @@ func TestAccAWSAPIGatewayV2Integration_VpcLinkWebSocket(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
 					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
 					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "12345"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
@@ -357,9 +454,11 @@ func TestAccAWSAPIGatewayV2Integration_VpcLinkHttp(t *testing.T) {
 					resource.TestCheckResourceAttrPair(resourceName, "integration_uri", lbListenerResourceName, "arn"),
 					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
-					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "5001"),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29001"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "1"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.0.server_name_to_verify", "www.example.com"),
 				),
@@ -386,9 +485,11 @@ func TestAccAWSAPIGatewayV2Integration_VpcLinkHttp(t *testing.T) {
 					resource.TestCheckResourceAttrPair(resourceName, "integration_uri", lbListenerResourceName, "arn"),
 					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "0"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
-					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "4999"),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29001"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "1"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.0.server_name_to_verify", "www.example.org"),
 				),
@@ -407,6 +508,9 @@ func TestAccAWSAPIGatewayV2Integration_AwsServiceIntegration(t *testing.T) {
 	var apiId string
 	var v apigatewayv2.GetIntegrationOutput
 	resourceName := "aws_apigatewayv2_integration.test"
+	iamRoleResourceName := "aws_iam_role.test"
+	sqsQueue1ResourceName := "aws_sqs_queue.test.0"
+	sqsQueue2ResourceName := "aws_sqs_queue.test.1"
 	rName := acctest.RandomWithPrefix("tf-acc-test")
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -415,11 +519,12 @@ func TestAccAWSAPIGatewayV2Integration_AwsServiceIntegration(t *testing.T) {
 		CheckDestroy: testAccCheckAWSAPIGatewayV2IntegrationDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccAWSAPIGatewayV2IntegrationConfig_sqsIntegration(rName),
+				Config: testAccAWSAPIGatewayV2IntegrationConfig_sqsIntegration(rName, 0),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
 					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
 					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", ""),
+					resource.TestCheckResourceAttrPair(resourceName, "credentials_arn", iamRoleResourceName, "arn"),
 					resource.TestCheckResourceAttr(resourceName, "description", "Test SQS send"),
 					resource.TestCheckResourceAttr(resourceName, "integration_method", ""),
 					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", ""),
@@ -428,12 +533,40 @@ func TestAccAWSAPIGatewayV2Integration_AwsServiceIntegration(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "integration_uri", ""),
 					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
 					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
-					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "2"),
-					resource.TestCheckResourceAttr(resourceName, "request_parameters.QueueUrl", "$request.header.queueUrl"),
-					resource.TestCheckResourceAttr(resourceName, "request_parameters.MessageBody", "$request.body.message"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "3"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.MessageBody", "$request.body"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.MessageGroupId", "$request.body.authentication_key"),
+					resource.TestCheckResourceAttrPair(resourceName, "request_parameters.QueueUrl", sqsQueue1ResourceName, "id"),
 					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
-					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "29000"),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
+					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
+				),
+			},
+			{
+				Config: testAccAWSAPIGatewayV2IntegrationConfig_sqsIntegration(rName, 1),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSAPIGatewayV2IntegrationExists(resourceName, &apiId, &v),
+					resource.TestCheckResourceAttr(resourceName, "connection_type", "INTERNET"),
+					resource.TestCheckResourceAttr(resourceName, "content_handling_strategy", ""),
+					resource.TestCheckResourceAttrPair(resourceName, "credentials_arn", iamRoleResourceName, "arn"),
+					resource.TestCheckResourceAttr(resourceName, "description", "Test SQS send"),
+					resource.TestCheckResourceAttr(resourceName, "integration_method", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_response_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "integration_subtype", "SQS-SendMessage"),
+					resource.TestCheckResourceAttr(resourceName, "integration_type", "AWS_PROXY"),
+					resource.TestCheckResourceAttr(resourceName, "integration_uri", ""),
+					resource.TestCheckResourceAttr(resourceName, "passthrough_behavior", ""),
+					resource.TestCheckResourceAttr(resourceName, "payload_format_version", "1.0"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.%", "3"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.MessageBody", "$request.body"),
+					resource.TestCheckResourceAttr(resourceName, "request_parameters.MessageGroupId", "$request.body.authentication_key"),
+					resource.TestCheckResourceAttrPair(resourceName, "request_parameters.QueueUrl", sqsQueue2ResourceName, "id"),
+					resource.TestCheckResourceAttr(resourceName, "request_templates.%", "0"),
+					resource.TestCheckResourceAttr(resourceName, "response_parameters.#", "0"),
+					resource.TestCheckResourceAttr(resourceName, "template_selection_expression", ""),
+					resource.TestCheckResourceAttr(resourceName, "timeout_milliseconds", "30000"),
 					resource.TestCheckResourceAttr(resourceName, "tls_config.#", "0"),
 				),
 			},
@@ -544,6 +677,60 @@ resource "aws_apigatewayv2_api" "test" {
 `, rName)
 }
 
+func testAccAWSAPIGatewayV2IntegrationConfig_lambdaBase(rName string) string {
+	return fmt.Sprintf(`
+resource "aws_iam_role" "test" {
+  name               = %[1]q
+  assume_role_policy = <<EOF
+{
+  "Version": "2012-10-17",
+  "Statement": [{
+    "Effect": "Allow",
+    "Action": ["sts:AssumeRole"],
+    "Principal": {"Service": "lambda.amazonaws.com"}
+  }]
+}
+EOF
+}
+
+resource "aws_iam_role_policy" "test" {
+  name = %[1]q
+  role = aws_iam_role.test.id
+
+  policy = <<EOF
+{
+  "Version": "2012-10-17",
+  "Statement": [{
+    "Effect": "Allow",
+    "Action": [
+      "logs:CreateLogGroup",
+      "logs:CreateLogStream",
+      "logs:PutLogEvents"
+    ],
+    "Resource": ["*"]
+  }]
+}
+EOF
+}
+
+resource "aws_lambda_function" "test" {
+  filename      = "test-fixtures/lambdatest.zip"
+  function_name = %[1]q
+  role          = aws_iam_role.test.arn
+  handler       = "index.handler"
+  runtime       = "nodejs10.x"
+
+  depends_on = [aws_iam_role_policy.test]
+}
+
+resource "aws_lambda_permission" "test" {
+  action        = "lambda:*"
+  function_name = aws_lambda_function.test.arn
+  principal     = "apigateway.amazonaws.com"
+}
+`, rName)
+}
+
 func testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkHttpBase(rName string) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName),
@@ -599,6 +786,66 @@ resource "aws_apigatewayv2_integration" "test" {
 `
 }
 
+func testAccAWSAPIGatewayV2IntegrationConfig_dataMappingHttp(rName string) string {
+	return testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName) + `
+resource "aws_apigatewayv2_integration" "test" {
+  api_id = aws_apigatewayv2_api.test.id
+
+  integration_type   = "HTTP_PROXY"
+  integration_method = "ANY"
+  integration_uri    = "http://www.example.com"
+
+  request_parameters = {
+    "append:header.header1"  = "$context.requestId"
+    "remove:querystring.qs1" = "''"
+  }
+
+  response_parameters {
+    status_code = "500"
+
+    mappings = {
+      "append:header.header1" = "$context.requestId"
+      "overwrite:statuscode"  = "403"
+    }
+  }
+
+  response_parameters {
+    status_code = "404"
+
+    mappings = {
+      "append:header.error" = "$stageVariables.environmentId"
+    }
+  }
+}
+`
+}
+
+func testAccAWSAPIGatewayV2IntegrationConfig_dataMappingHttpUpdated(rName string) string {
+	return testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName) + `
+resource "aws_apigatewayv2_integration" "test" {
+  api_id = aws_apigatewayv2_api.test.id
+
+  integration_type   = "HTTP_PROXY"
+  integration_method = "ANY"
+  integration_uri    = "http://www.example.com"
+
+  request_parameters = {
+    "append:header.header1"    = "$context.accountId"
+    "overwrite:header.header2" = "$stageVariables.environmentId"
+  }
+
+  response_parameters {
+    status_code = "500"
+
+    mappings = {
+      "append:header.header1" = "$context.requestId"
+      "overwrite:statuscode"  = "403"
+    }
+  }
+}
+`
+}
+
 func testAccAWSAPIGatewayV2IntegrationConfig_integrationTypeHttp(rName string) string {
 	return testAccAWSAPIGatewayV2IntegrationConfig_apiWebSocket(rName) + `
 resource "aws_apigatewayv2_integration" "test" {
@@ -656,63 +903,45 @@ resource "aws_apigatewayv2_integration" "test" {
 func testAccAWSAPIGatewayV2IntegrationConfig_lambdaWebSocket(rName string) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_apiWebSocket(rName),
-		baseAccAWSLambdaConfig(rName, rName, rName),
-		fmt.Sprintf(`
-data "aws_caller_identity" "current" {}
-
-resource "aws_lambda_function" "test" {
-  filename      = "test-fixtures/lambdatest.zip"
-  function_name = %[1]q
-  role          = aws_iam_role.iam_for_lambda.arn
-  handler       = "index.handler"
-  runtime       = "nodejs10.x"
-}
-
+		testAccAWSAPIGatewayV2IntegrationConfig_lambdaBase(rName),
+		`
 resource "aws_apigatewayv2_integration" "test" {
   api_id           = aws_apigatewayv2_api.test.id
   integration_type = "AWS"
 
   connection_type           = "INTERNET"
   content_handling_strategy = "CONVERT_TO_TEXT"
-  credentials_arn           = data.aws_caller_identity.current.arn
   description               = "Test Lambda"
   integration_uri           = aws_lambda_function.test.invoke_arn
   passthrough_behavior      = "WHEN_NO_MATCH"
+
+  depends_on = [aws_lambda_permission.test]
 }
-`, rName))
+`)
 }
 
 func testAccAWSAPIGatewayV2IntegrationConfig_lambdaHttp(rName string) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName),
-		baseAccAWSLambdaConfig(rName, rName, rName),
-		fmt.Sprintf(`
-data "aws_caller_identity" "current" {}
-
-resource "aws_lambda_function" "test" {
-  filename      = "test-fixtures/lambdatest.zip"
-  function_name = %[1]q
-  role          = aws_iam_role.iam_for_lambda.arn
-  handler       = "index.handler"
-  runtime       = "nodejs10.x"
-}
-
+		testAccAWSAPIGatewayV2IntegrationConfig_lambdaBase(rName),
+		`
 resource "aws_apigatewayv2_integration" "test" {
   api_id           = aws_apigatewayv2_api.test.id
   integration_type = "AWS_PROXY"
 
   connection_type = "INTERNET"
-  credentials_arn = data.aws_caller_identity.current.arn
   description     = "Test Lambda"
   integration_uri = aws_lambda_function.test.invoke_arn
 
   payload_format_version = "2.0"
+
+  depends_on = [aws_lambda_permission.test]
 }
-`, rName))
+`)
 }
 
 func testAccAWSAPIGatewayV2IntegrationConfig_httpProxy(rName string) string {
-	return testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName) + fmt.Sprintf(`
+	return composeConfig(testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName), `
 resource "aws_apigatewayv2_integration" "test" {
   api_id           = aws_apigatewayv2_api.test.id
   integration_type = "HTTP_PROXY"
@@ -726,7 +955,7 @@ resource "aws_apigatewayv2_integration" "test" {
 func testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkHttp(rName string) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkHttpBase(rName),
-		fmt.Sprintf(`
+		`
 resource "aws_apigatewayv2_integration" "test" {
   api_id           = aws_apigatewayv2_api.test.id
   integration_type = "HTTP_PROXY"
@@ -736,35 +965,34 @@ resource "aws_apigatewayv2_integration" "test" {
   description          = "Test private integration"
   integration_method   = "GET"
   integration_uri      = aws_lb_listener.test.arn
-  timeout_milliseconds = 5001
+  timeout_milliseconds = 29001
 
   tls_config {
     server_name_to_verify = "www.example.com"
   }
 }
-`))
+`)
 }
 
 func testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkHttpUpdated(rName string) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkHttpBase(rName),
-		fmt.Sprintf(`
+		`
 resource "aws_apigatewayv2_integration" "test" {
   api_id           = aws_apigatewayv2_api.test.id
   integration_type = "HTTP_PROXY"
 
-  connection_type      = "VPC_LINK"
-  connection_id        = aws_apigatewayv2_vpc_link.test.id
-  description          = "Test private integration updated"
-  integration_method   = "POST"
-  integration_uri      = aws_lb_listener.test.arn
-  timeout_milliseconds = 4999
+  connection_type    = "VPC_LINK"
+  connection_id      = aws_apigatewayv2_vpc_link.test.id
+  description        = "Test private integration updated"
+  integration_method = "POST"
+  integration_uri    = aws_lb_listener.test.arn
 
   tls_config {
     server_name_to_verify = "www.example.org"
   }
 }
-`))
+`)
 }
 
 func testAccAWSAPIGatewayV2IntegrationConfig_vpcLinkWebSocket(rName string) string {
@@ -830,7 +1058,7 @@ resource "aws_apigatewayv2_integration" "test" {
 `, rName))
 }
 
-func testAccAWSAPIGatewayV2IntegrationConfig_sqsIntegration(rName string) string {
+func testAccAWSAPIGatewayV2IntegrationConfig_sqsIntegration(rName string, queueIndex int) string {
 	return composeConfig(
 		testAccAWSAPIGatewayV2IntegrationConfig_apiHttp(rName),
 		fmt.Sprintf(`
@@ -865,6 +1093,12 @@ resource "aws_iam_role_policy" "test" {
 EOF
 }
 
+resource "aws_sqs_queue" "test" {
+  count = 2
+
+  name = "%[1]s-${count.index}"
+}
+
 resource "aws_apigatewayv2_integration" "test" {
   api_id              = aws_apigatewayv2_api.test.id
   credentials_arn     = aws_iam_role.test.arn
@@ -873,11 +1107,12 @@ resource "aws_apigatewayv2_integration" "test" {
   integration_subtype = "SQS-SendMessage"
 
   request_parameters = {
-    "QueueUrl"    = "$request.header.queueUrl"
-    "MessageBody" = "$request.body.message"
+    "QueueUrl"       = aws_sqs_queue.test.%[2]d.id
+    "MessageGroupId" = "$request.body.authentication_key"
+    "MessageBody"    = "$request.body"
   }
 
   depends_on = [aws_iam_role_policy.test]
 }
-`, rName))
+`, rName, queueIndex))
 }
