@@ -15,12 +15,17 @@ import (
 	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"github.com/aws/aws-sdk-go/service/elb"
 	"github.com/aws/aws-sdk-go/service/elbv2"
+	"github.com/hashicorp/aws-sdk-go-base/tfawserr"
+	"github.com/hashicorp/go-cty/cty"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/diag"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/customdiff"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/experimental/nullable"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/hashcode"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/keyvaluetags"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/service/autoscaling/waiter"
 )
 
 const (
@@ -204,6 +209,11 @@ func resourceAwsAutoscalingGroup() *schema.Resource {
 				},
 			},
 
+			"capacity_rebalance": {
+				Type:     schema.TypeBool,
+				Optional: true,
+			},
+
 			"desired_capacity": {
 				Type:     schema.TypeInt,
 				Optional: true,
@@ -472,6 +482,50 @@ func resourceAwsAutoscalingGroup() *schema.Resource {
 				Optional: true,
 				Computed: true,
 			},
+
+			"instance_refresh": {
+				Type:     schema.TypeList,
+				MaxItems: 1,
+				Optional: true,
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"strategy": {
+							Type:         schema.TypeString,
+							Required:     true,
+							ValidateFunc: validation.StringInSlice(autoscaling.RefreshStrategy_Values(), false),
+						},
+						"preferences": {
+							Type:     schema.TypeList,
+							MaxItems: 1,
+							Optional: true,
+							Elem: &schema.Resource{
+								Schema: map[string]*schema.Schema{
+									"instance_warmup": {
+										Type:         nullable.TypeNullableInt,
+										Optional:     true,
+										ValidateFunc: nullable.ValidateTypeStringNullableIntAtLeast(0),
+									},
+									"min_healthy_percentage": {
+										Type:         schema.TypeInt,
+										Optional:     true,
+										Default:      90,
+										ValidateFunc: validation.IntBetween(0, 100),
+									},
+								},
+							},
+						},
+						"triggers": {
+							Type:     schema.TypeSet,
+							Optional: true,
+							Set:      schema.HashString,
+							Elem: &schema.Schema{
+								Type:             schema.TypeString,
+								ValidateDiagFunc: validateAutoScalingGroupInstanceRefreshTriggerFields,
+							},
+						},
+					},
+				},
+			},
 		},
 
 		CustomizeDiff: customdiff.Sequence(
@@ -579,7 +633,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 	launchTemplateValue, launchTemplateOk := d.GetOk("launch_template")
 
 	if createOpts.MixedInstancesPolicy == nil && !launchConfigurationOk && !launchTemplateOk {
-		return fmt.Errorf("One of `launch_configuration`, `launch_template`, or `mixed_instances_policy` must be set for an autoscaling group")
+		return fmt.Errorf("One of `launch_configuration`, `launch_template`, or `mixed_instances_policy` must be set for an Auto Scaling Group")
 	}
 
 	if launchConfigurationOk {
@@ -596,7 +650,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 
 	// Availability Zones are optional if VPC Zone Identifier(s) are specified
 	if v, ok := d.GetOk("availability_zones"); ok && v.(*schema.Set).Len() > 0 {
-		createOpts.AvailabilityZones = expandStringList(v.(*schema.Set).List())
+		createOpts.AvailabilityZones = expandStringSet(v.(*schema.Set))
 	}
 
 	resourceID := d.Get("name").(string)
@@ -609,6 +663,10 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 		createOpts.Tags = keyvaluetags.AutoscalingKeyValueTags(v, resourceID, autoscalingTagResourceTypeAutoScalingGroup).IgnoreAws().AutoscalingTags()
 	}
 
+	if v, ok := d.GetOk("capacity_rebalance"); ok {
+		createOpts.CapacityRebalance = aws.Bool(v.(bool))
+	}
+
 	if v, ok := d.GetOk("default_cooldown"); ok {
 		createOpts.DefaultCooldown = aws.Int64(int64(v.(int)))
 	}
@@ -626,8 +684,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 	}
 
 	if v, ok := d.GetOk("load_balancers"); ok && v.(*schema.Set).Len() > 0 {
-		createOpts.LoadBalancerNames = expandStringList(
-			v.(*schema.Set).List())
+		createOpts.LoadBalancerNames = expandStringSet(v.(*schema.Set))
 	}
 
 	if v, ok := d.GetOk("vpc_zone_identifier"); ok && v.(*schema.Set).Len() > 0 {
@@ -639,7 +696,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 	}
 
 	if v, ok := d.GetOk("target_group_arns"); ok && len(v.(*schema.Set).List()) > 0 {
-		createOpts.TargetGroupARNs = expandStringList(v.(*schema.Set).List())
+		createOpts.TargetGroupARNs = expandStringSet(v.(*schema.Set))
 	}
 
 	if v, ok := d.GetOk("service_linked_role_arn"); ok {
@@ -650,7 +707,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 		createOpts.MaxInstanceLifetime = aws.Int64(int64(v.(int)))
 	}
 
-	log.Printf("[DEBUG] AutoScaling Group create configuration: %#v", createOpts)
+	log.Printf("[DEBUG] Auto Scaling Group create configuration: %#v", createOpts)
 
 	// Retry for IAM eventual consistency
 	err := resource.Retry(1*time.Minute, func() *resource.RetryError {
@@ -671,11 +728,11 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 		_, err = conn.CreateAutoScalingGroup(&createOpts)
 	}
 	if err != nil {
-		return fmt.Errorf("Error creating AutoScaling Group: %s", err)
+		return fmt.Errorf("Error creating Auto Scaling Group: %s", err)
 	}
 
 	d.SetId(d.Get("name").(string))
-	log.Printf("[INFO] AutoScaling Group ID: %s", d.Id())
+	log.Printf("[INFO] Auto Scaling Group ID: %s", d.Id())
 
 	if twoPhases {
 		for _, hook := range generatePutLifecycleHookInputs(asgName, initialLifecycleHooks) {
@@ -686,7 +743,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 
 		_, err = conn.UpdateAutoScalingGroup(&updateOpts)
 		if err != nil {
-			return fmt.Errorf("Error setting AutoScaling Group initial capacity: %s", err)
+			return fmt.Errorf("Error setting Auto Scaling Group initial capacity: %s", err)
 		}
 	}
 
@@ -711,6 +768,7 @@ func resourceAwsAutoscalingGroupCreate(d *schema.ResourceData, meta interface{})
 	return resourceAwsAutoscalingGroupRead(d, meta)
 }
 
+// TODO: wrap all top-level error returns
 func resourceAwsAutoscalingGroupRead(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).autoscalingconn
 	ignoreTagsConfig := meta.(*AWSClient).IgnoreTagsConfig
@@ -720,7 +778,7 @@ func resourceAwsAutoscalingGroupRead(d *schema.ResourceData, meta interface{}) e
 		return err
 	}
 	if g == nil {
-		log.Printf("[WARN] Autoscaling Group (%s) not found, removing from state", d.Id())
+		log.Printf("[WARN] Auto Scaling Group (%s) not found, removing from state", d.Id())
 		d.SetId("")
 		return nil
 	}
@@ -730,6 +788,7 @@ func resourceAwsAutoscalingGroupRead(d *schema.ResourceData, meta interface{}) e
 	}
 
 	d.Set("arn", g.AutoScalingGroupARN)
+	d.Set("capacity_rebalance", g.CapacityRebalance)
 	d.Set("default_cooldown", g.DefaultCooldown)
 	d.Set("desired_capacity", g.DesiredCapacity)
 
@@ -900,6 +959,7 @@ func waitUntilAutoscalingGroupLoadBalancerTargetGroupsAdded(conn *autoscaling.Au
 func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).autoscalingconn
 	shouldWaitForCapacity := false
+	shouldRefreshInstances := false
 
 	opts := autoscaling.UpdateAutoScalingGroupInput{
 		AutoScalingGroupName: aws.String(d.Id()),
@@ -911,6 +971,16 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 		opts.DefaultCooldown = aws.Int64(int64(d.Get("default_cooldown").(int)))
 	}
 
+	if d.HasChange("capacity_rebalance") {
+		// If the capacity rebalance field is set to null, we need to explicitly set
+		// it back to "false", or the API won't reset it for us.
+		if v, ok := d.GetOk("capacity_rebalance"); ok {
+			opts.CapacityRebalance = aws.Bool(v.(bool))
+		} else {
+			opts.CapacityRebalance = aws.Bool(false)
+		}
+	}
+
 	if d.HasChange("desired_capacity") {
 		opts.DesiredCapacity = aws.Int64(int64(d.Get("desired_capacity").(int)))
 		shouldWaitForCapacity = true
@@ -920,16 +990,19 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 		if v, ok := d.GetOk("launch_configuration"); ok {
 			opts.LaunchConfigurationName = aws.String(v.(string))
 		}
+		shouldRefreshInstances = true
 	}
 
 	if d.HasChange("launch_template") {
 		if v, ok := d.GetOk("launch_template"); ok && len(v.([]interface{})) > 0 {
 			opts.LaunchTemplate, _ = expandLaunchTemplateSpecification(v.([]interface{}))
 		}
+		shouldRefreshInstances = true
 	}
 
 	if d.HasChange("mixed_instances_policy") {
 		opts.MixedInstancesPolicy = expandAutoScalingMixedInstancesPolicy(d.Get("mixed_instances_policy").([]interface{}))
+		shouldRefreshInstances = true
 	}
 
 	if d.HasChange("min_size") {
@@ -960,7 +1033,7 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 
 	if d.HasChange("availability_zones") {
 		if v, ok := d.GetOk("availability_zones"); ok && v.(*schema.Set).Len() > 0 {
-			opts.AvailabilityZones = expandStringList(v.(*schema.Set).List())
+			opts.AvailabilityZones = expandStringSet(v.(*schema.Set))
 		}
 	}
 
@@ -1000,10 +1073,10 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 		}
 	}
 
-	log.Printf("[DEBUG] AutoScaling Group update configuration: %#v", opts)
+	log.Printf("[DEBUG] Auto Scaling Group update configuration: %#v", opts)
 	_, err := conn.UpdateAutoScalingGroup(&opts)
 	if err != nil {
-		return fmt.Errorf("Error updating Autoscaling group: %s", err)
+		return fmt.Errorf("Error updating Auto Scaling Group: %s", err)
 	}
 
 	if d.HasChange("load_balancers") {
@@ -1018,8 +1091,8 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 
 		os := o.(*schema.Set)
 		ns := n.(*schema.Set)
-		remove := expandStringList(os.Difference(ns).List())
-		add := expandStringList(ns.Difference(os).List())
+		remove := expandStringSet(os.Difference(ns))
+		add := expandStringSet(ns.Difference(os))
 
 		if len(remove) > 0 {
 			// API only supports removing 10 at a time
@@ -1039,11 +1112,11 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 				})
 
 				if err != nil {
-					return fmt.Errorf("error detaching AutoScaling Group (%s) Load Balancers: %s", d.Id(), err)
+					return fmt.Errorf("error detaching Auto Scaling Group (%s) Load Balancers: %s", d.Id(), err)
 				}
 
 				if err := waitUntilAutoscalingGroupLoadBalancersRemoved(conn, d.Id()); err != nil {
-					return fmt.Errorf("error describing AutoScaling Group (%s) Load Balancers being removed: %s", d.Id(), err)
+					return fmt.Errorf("error describing Auto Scaling Group (%s) Load Balancers being removed: %s", d.Id(), err)
 				}
 			}
 		}
@@ -1066,11 +1139,11 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 				})
 
 				if err != nil {
-					return fmt.Errorf("error attaching AutoScaling Group (%s) Load Balancers: %s", d.Id(), err)
+					return fmt.Errorf("error attaching Auto Scaling Group (%s) Load Balancers: %s", d.Id(), err)
 				}
 
 				if err := waitUntilAutoscalingGroupLoadBalancersAdded(conn, d.Id()); err != nil {
-					return fmt.Errorf("error describing AutoScaling Group (%s) Load Balancers being added: %s", d.Id(), err)
+					return fmt.Errorf("error describing Auto Scaling Group (%s) Load Balancers being added: %s", d.Id(), err)
 				}
 			}
 		}
@@ -1088,8 +1161,8 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 
 		os := o.(*schema.Set)
 		ns := n.(*schema.Set)
-		remove := expandStringList(os.Difference(ns).List())
-		add := expandStringList(ns.Difference(os).List())
+		remove := expandStringSet(os.Difference(ns))
+		add := expandStringSet(ns.Difference(os))
 
 		if len(remove) > 0 {
 			// AWS API only supports adding/removing 10 at a time
@@ -1108,11 +1181,11 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 					TargetGroupARNs:      batch,
 				})
 				if err != nil {
-					return fmt.Errorf("Error updating Load Balancers Target Groups for AutoScaling Group (%s), error: %s", d.Id(), err)
+					return fmt.Errorf("Error updating Load Balancers Target Groups for Auto Scaling Group (%s), error: %s", d.Id(), err)
 				}
 
 				if err := waitUntilAutoscalingGroupLoadBalancerTargetGroupsRemoved(conn, d.Id()); err != nil {
-					return fmt.Errorf("error describing AutoScaling Group (%s) Load Balancer Target Groups being removed: %s", d.Id(), err)
+					return fmt.Errorf("error describing Auto Scaling Group (%s) Load Balancer Target Groups being removed: %s", d.Id(), err)
 				}
 			}
 
@@ -1135,31 +1208,57 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 				})
 
 				if err != nil {
-					return fmt.Errorf("Error updating Load Balancers Target Groups for AutoScaling Group (%s), error: %s", d.Id(), err)
+					return fmt.Errorf("Error updating Load Balancers Target Groups for Auto Scaling Group (%s), error: %s", d.Id(), err)
 				}
 
 				if err := waitUntilAutoscalingGroupLoadBalancerTargetGroupsAdded(conn, d.Id()); err != nil {
-					return fmt.Errorf("error describing AutoScaling Group (%s) Load Balancer Target Groups being added: %s", d.Id(), err)
+					return fmt.Errorf("error describing Auto Scaling Group (%s) Load Balancer Target Groups being added: %s", d.Id(), err)
 				}
 			}
 		}
 	}
 
+	if instanceRefreshRaw, ok := d.GetOk("instance_refresh"); ok {
+		instanceRefresh := instanceRefreshRaw.([]interface{})
+		if !shouldRefreshInstances {
+			if len(instanceRefresh) > 0 && instanceRefresh[0] != nil {
+				m := instanceRefresh[0].(map[string]interface{})
+				attrsSet := m["triggers"].(*schema.Set)
+				attrs := attrsSet.List()
+				strs := make([]string, len(attrs))
+				for i, a := range attrs {
+					strs[i] = a.(string)
+				}
+				if attrsSet.Contains("tag") && !attrsSet.Contains("tags") {
+					strs = append(strs, "tags") // nozero
+				} else if !attrsSet.Contains("tag") && attrsSet.Contains("tags") {
+					strs = append(strs, "tag") // nozero
+				}
+				shouldRefreshInstances = d.HasChanges(strs...)
+			}
+		}
+		if shouldRefreshInstances {
+			if err := autoScalingGroupRefreshInstances(conn, d.Id(), instanceRefresh); err != nil {
+				return fmt.Errorf("failed to start instance refresh of Auto Scaling Group %s: %w", d.Id(), err)
+			}
+		}
+	}
+
 	if shouldWaitForCapacity {
 		if err := waitForASGCapacity(d, meta, capacitySatisfiedUpdate); err != nil {
-			return fmt.Errorf("Error waiting for AutoScaling Group Capacity: %s", err)
+			return fmt.Errorf("error waiting for Auto Scaling Group Capacity: %w", err)
 		}
 	}
 
 	if d.HasChange("enabled_metrics") {
 		if err := updateASGMetricsCollection(d, conn); err != nil {
-			return fmt.Errorf("Error updating AutoScaling Group Metrics collection: %s", err)
+			return fmt.Errorf("Error updating Auto Scaling Group Metrics collection: %s", err)
 		}
 	}
 
 	if d.HasChange("suspended_processes") {
 		if err := updateASGSuspendedProcesses(d, conn); err != nil {
-			return fmt.Errorf("Error updating AutoScaling Group Suspended Processes: %s", err)
+			return fmt.Errorf("Error updating Auto Scaling Group Suspended Processes: %s", err)
 		}
 	}
 
@@ -1169,7 +1268,7 @@ func resourceAwsAutoscalingGroupUpdate(d *schema.ResourceData, meta interface{})
 func resourceAwsAutoscalingGroupDelete(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).autoscalingconn
 
-	// Read the autoscaling group first. If it doesn't exist, we're done.
+	// Read the Auto Scaling Group first. If it doesn't exist, we're done.
 	// We need the group in order to check if there are instances attached.
 	// If so, we need to remove those first.
 	g, err := getAwsAutoscalingGroup(d.Id(), conn)
@@ -1177,7 +1276,7 @@ func resourceAwsAutoscalingGroupDelete(d *schema.ResourceData, meta interface{})
 		return err
 	}
 	if g == nil {
-		log.Printf("[WARN] Autoscaling Group (%s) not found, removing from state", d.Id())
+		log.Printf("[WARN] Auto Scaling Group (%s) not found, removing from state", d.Id())
 		return nil
 	}
 	if len(g.Instances) > 0 || *g.DesiredCapacity > 0 {
@@ -1186,7 +1285,7 @@ func resourceAwsAutoscalingGroupDelete(d *schema.ResourceData, meta interface{})
 		}
 	}
 
-	log.Printf("[DEBUG] AutoScaling Group destroy: %v", d.Id())
+	log.Printf("[DEBUG] Auto Scaling Group destroy: %v", d.Id())
 	deleteopts := autoscaling.DeleteAutoScalingGroupInput{
 		AutoScalingGroupName: aws.String(d.Id()),
 		ForceDelete:          aws.Bool(d.Get("force_delete").(bool)),
@@ -1220,7 +1319,7 @@ func resourceAwsAutoscalingGroupDelete(d *schema.ResourceData, meta interface{})
 		}
 	}
 	if err != nil {
-		return fmt.Errorf("Error deleting autoscaling group: %s", err)
+		return fmt.Errorf("Error deleting Auto Scaling Group: %s", err)
 	}
 
 	var group *autoscaling.Group
@@ -1239,17 +1338,19 @@ func resourceAwsAutoscalingGroupDelete(d *schema.ResourceData, meta interface{})
 		}
 	}
 	if err != nil {
-		return fmt.Errorf("Error deleting autoscaling group: %s", err)
+		return fmt.Errorf("Error deleting Auto Scaling Group: %s", err)
 	}
 	return nil
 }
 
+// TODO: make this a finder
+// TODO: this should return a NotFoundError if not found
 func getAwsAutoscalingGroup(asgName string, conn *autoscaling.AutoScaling) (*autoscaling.Group, error) {
 	describeOpts := autoscaling.DescribeAutoScalingGroupsInput{
 		AutoScalingGroupNames: []*string{aws.String(asgName)},
 	}
 
-	log.Printf("[DEBUG] AutoScaling Group describe configuration: %#v", describeOpts)
+	log.Printf("[DEBUG] Auto Scaling Group describe configuration: %#v", describeOpts)
 	describeGroups, err := conn.DescribeAutoScalingGroups(&describeOpts)
 	if err != nil {
 		autoscalingerr, ok := err.(awserr.Error)
@@ -1257,10 +1358,10 @@ func getAwsAutoscalingGroup(asgName string, conn *autoscaling.AutoScaling) (*aut
 			return nil, nil
 		}
 
-		return nil, fmt.Errorf("Error retrieving AutoScaling groups: %s", err)
+		return nil, fmt.Errorf("Error retrieving Auto Scaling Groups: %s", err)
 	}
 
-	// Search for the autoscaling group
+	// Search for the Auto Scaling Group
 	for idx, asc := range describeGroups.AutoScalingGroups {
 		if *asc.AutoScalingGroupName == asgName {
 			return describeGroups.AutoScalingGroups[idx], nil
@@ -1274,12 +1375,12 @@ func resourceAwsAutoscalingGroupDrain(d *schema.ResourceData, meta interface{})
 	conn := meta.(*AWSClient).autoscalingconn
 
 	if d.Get("force_delete").(bool) {
-		log.Printf("[DEBUG] Skipping ASG drain, force_delete was set.")
+		log.Printf("[DEBUG] Skipping Auto Scaling Group drain, force_delete was set.")
 		return nil
 	}
 
 	// First, set the capacity to zero so the group will drain
-	log.Printf("[DEBUG] Reducing autoscaling group capacity to zero")
+	log.Printf("[DEBUG] Reducing Auto Scaling Group capacity to zero")
 	opts := autoscaling.UpdateAutoScalingGroupInput{
 		AutoScalingGroupName: aws.String(d.Id()),
 		DesiredCapacity:      aws.Int64(0),
@@ -1290,7 +1391,7 @@ func resourceAwsAutoscalingGroupDrain(d *schema.ResourceData, meta interface{})
 		return fmt.Errorf("Error setting capacity to zero to drain: %s", err)
 	}
 
-	// Next, wait for the autoscale group to drain
+	// Next, wait for the Auto Scaling Group to drain
 	log.Printf("[DEBUG] Waiting for group to have zero instances")
 	var g *autoscaling.Group
 	err := resource.Retry(d.Timeout(schema.TimeoutDelete), func() *resource.RetryError {
@@ -1299,7 +1400,7 @@ func resourceAwsAutoscalingGroupDrain(d *schema.ResourceData, meta interface{})
 			return resource.NonRetryableError(err)
 		}
 		if g == nil {
-			log.Printf("[WARN] Autoscaling Group (%s) not found, removing from state", d.Id())
+			log.Printf("[WARN] Auto Scaling Group (%s) not found, removing from state", d.Id())
 			d.SetId("")
 			return nil
 		}
@@ -1314,14 +1415,14 @@ func resourceAwsAutoscalingGroupDrain(d *schema.ResourceData, meta interface{})
 	if isResourceTimeoutError(err) {
 		g, err = getAwsAutoscalingGroup(d.Id(), conn)
 		if err != nil {
-			return fmt.Errorf("Error getting autoscaling group info when draining: %s", err)
+			return fmt.Errorf("Error getting Auto Scaling Group info when draining: %s", err)
 		}
 		if g != nil && len(g.Instances) > 0 {
 			return fmt.Errorf("Group still has %d instances", len(g.Instances))
 		}
 	}
 	if err != nil {
-		return fmt.Errorf("Error draining autoscaling group: %s", err)
+		return fmt.Errorf("Error draining Auto Scaling Group: %s", err)
 	}
 	return nil
 }
@@ -1329,7 +1430,7 @@ func resourceAwsAutoscalingGroupDrain(d *schema.ResourceData, meta interface{})
 func enableASGSuspendedProcesses(d *schema.ResourceData, conn *autoscaling.AutoScaling) error {
 	props := &autoscaling.ScalingProcessQuery{
 		AutoScalingGroupName: aws.String(d.Id()),
-		ScalingProcesses:     expandStringList(d.Get("suspended_processes").(*schema.Set).List()),
+		ScalingProcesses:     expandStringSet(d.Get("suspended_processes").(*schema.Set)),
 	}
 
 	_, err := conn.SuspendProcesses(props)
@@ -1340,10 +1441,10 @@ func enableASGMetricsCollection(d *schema.ResourceData, conn *autoscaling.AutoSc
 	props := &autoscaling.EnableMetricsCollectionInput{
 		AutoScalingGroupName: aws.String(d.Id()),
 		Granularity:          aws.String(d.Get("metrics_granularity").(string)),
-		Metrics:              expandStringList(d.Get("enabled_metrics").(*schema.Set).List()),
+		Metrics:              expandStringSet(d.Get("enabled_metrics").(*schema.Set)),
 	}
 
-	log.Printf("[INFO] Enabling metrics collection for the ASG: %s", d.Id())
+	log.Printf("[INFO] Enabling metrics collection for the Auto Scaling Group: %s", d.Id())
 	_, metricsErr := conn.EnableMetricsCollection(props)
 	return metricsErr
 
@@ -1365,12 +1466,12 @@ func updateASGSuspendedProcesses(d *schema.ResourceData, conn *autoscaling.AutoS
 	if resumeProcesses.Len() != 0 {
 		props := &autoscaling.ScalingProcessQuery{
 			AutoScalingGroupName: aws.String(d.Id()),
-			ScalingProcesses:     expandStringList(resumeProcesses.List()),
+			ScalingProcesses:     expandStringSet(resumeProcesses),
 		}
 
 		_, err := conn.ResumeProcesses(props)
 		if err != nil {
-			return fmt.Errorf("Error Resuming Processes for ASG %q: %s", d.Id(), err)
+			return fmt.Errorf("Error Resuming Processes for Auto Scaling Group %q: %s", d.Id(), err)
 		}
 	}
 
@@ -1378,12 +1479,12 @@ func updateASGSuspendedProcesses(d *schema.ResourceData, conn *autoscaling.AutoS
 	if suspendedProcesses.Len() != 0 {
 		props := &autoscaling.ScalingProcessQuery{
 			AutoScalingGroupName: aws.String(d.Id()),
-			ScalingProcesses:     expandStringList(suspendedProcesses.List()),
+			ScalingProcesses:     expandStringSet(suspendedProcesses),
 		}
 
 		_, err := conn.SuspendProcesses(props)
 		if err != nil {
-			return fmt.Errorf("Error Suspending Processes for ASG %q: %s", d.Id(), err)
+			return fmt.Errorf("Error Suspending Processes for Auto Scaling Group %q: %s", d.Id(), err)
 		}
 	}
 
@@ -1408,12 +1509,12 @@ func updateASGMetricsCollection(d *schema.ResourceData, conn *autoscaling.AutoSc
 	if disableMetrics.Len() != 0 {
 		props := &autoscaling.DisableMetricsCollectionInput{
 			AutoScalingGroupName: aws.String(d.Id()),
-			Metrics:              expandStringList(disableMetrics.List()),
+			Metrics:              expandStringSet(disableMetrics),
 		}
 
 		_, err := conn.DisableMetricsCollection(props)
 		if err != nil {
-			return fmt.Errorf("Failure to Disable metrics collection types for ASG %s: %s", d.Id(), err)
+			return fmt.Errorf("Failure to Disable metrics collection types for Auto Scaling Group %s: %s", d.Id(), err)
 		}
 	}
 
@@ -1421,13 +1522,13 @@ func updateASGMetricsCollection(d *schema.ResourceData, conn *autoscaling.AutoSc
 	if enabledMetrics.Len() != 0 {
 		props := &autoscaling.EnableMetricsCollectionInput{
 			AutoScalingGroupName: aws.String(d.Id()),
-			Metrics:              expandStringList(enabledMetrics.List()),
+			Metrics:              expandStringSet(enabledMetrics),
 			Granularity:          aws.String(d.Get("metrics_granularity").(string)),
 		}
 
 		_, err := conn.EnableMetricsCollection(props)
 		if err != nil {
-			return fmt.Errorf("Failure to Enable metrics collection types for ASG %s: %s", d.Id(), err)
+			return fmt.Errorf("Failure to Enable metrics collection types for Auto Scaling Group %s: %s", d.Id(), err)
 		}
 	}
 
@@ -1493,8 +1594,8 @@ func getTargetGroupInstanceStates(g *autoscaling.Group, meta interface{}) (map[s
 
 func expandVpcZoneIdentifiers(list []interface{}) *string {
 	strs := make([]string, len(list))
-	for _, s := range list {
-		strs = append(strs, s.(string))
+	for i, s := range list {
+		strs[i] = s.(string)
 	}
 	return aws.String(strings.Join(strs, ","))
 }
@@ -1775,3 +1876,116 @@ func waitUntilAutoscalingGroupLoadBalancersRemoved(conn *autoscaling.AutoScaling
 
 	return nil
 }
+
+func createAutoScalingGroupInstanceRefreshInput(asgName string, l []interface{}) *autoscaling.StartInstanceRefreshInput {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	m := l[0].(map[string]interface{})
+
+	return &autoscaling.StartInstanceRefreshInput{
+		AutoScalingGroupName: aws.String(asgName),
+		Strategy:             aws.String(m["strategy"].(string)),
+		Preferences:          expandAutoScalingGroupInstanceRefreshPreferences(m["preferences"].([]interface{})),
+	}
+}
+
+func expandAutoScalingGroupInstanceRefreshPreferences(l []interface{}) *autoscaling.RefreshPreferences {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	m := l[0].(map[string]interface{})
+
+	refreshPreferences := &autoscaling.RefreshPreferences{}
+
+	if v, ok := m["instance_warmup"]; ok {
+		if v, null, _ := nullable.Int(v.(string)).Value(); !null {
+			refreshPreferences.InstanceWarmup = aws.Int64(v)
+		}
+	}
+
+	if v, ok := m["min_healthy_percentage"]; ok {
+		refreshPreferences.MinHealthyPercentage = aws.Int64(int64(v.(int)))
+	}
+
+	return refreshPreferences
+}
+
+func autoScalingGroupRefreshInstances(conn *autoscaling.AutoScaling, asgName string, refreshConfig []interface{}) error {
+	input := createAutoScalingGroupInstanceRefreshInput(asgName, refreshConfig)
+	err := resource.Retry(waiter.InstanceRefreshStartedTimeout, func() *resource.RetryError {
+		_, err := conn.StartInstanceRefresh(input)
+		if tfawserr.ErrCodeEquals(err, autoscaling.ErrCodeInstanceRefreshInProgressFault) {
+			cancelErr := cancelAutoscalingInstanceRefresh(conn, asgName)
+			if cancelErr != nil {
+				return resource.NonRetryableError(cancelErr)
+			}
+			return resource.RetryableError(err)
+		}
+		if err != nil {
+			return resource.NonRetryableError(err)
+		}
+		return nil
+	})
+	if isResourceTimeoutError(err) {
+		_, err = conn.StartInstanceRefresh(input)
+	}
+	if err != nil {
+		return fmt.Errorf("error starting Instance Refresh: %w", err)
+	}
+
+	return nil
+}
+
+func cancelAutoscalingInstanceRefresh(conn *autoscaling.AutoScaling, asgName string) error {
+	input := autoscaling.CancelInstanceRefreshInput{
+		AutoScalingGroupName: aws.String(asgName),
+	}
+	output, err := conn.CancelInstanceRefresh(&input)
+	if tfawserr.ErrCodeEquals(err, autoscaling.ErrCodeActiveInstanceRefreshNotFoundFault) {
+		return nil
+	}
+	if err != nil {
+		return fmt.Errorf("error cancelling Instance Refresh on Auto Scaling Group (%s): %w", asgName, err)
+	}
+	if output == nil {
+		return fmt.Errorf("error cancelling Instance Refresh on Auto Scaling Group (%s): empty result", asgName)
+	}
+
+	_, err = waiter.InstanceRefreshCancelled(conn, asgName, aws.StringValue(output.InstanceRefreshId))
+	if err != nil {
+		return fmt.Errorf("error waiting for cancellation of Instance Refresh (%s) on Auto Scaling Group (%s): %w", aws.StringValue(output.InstanceRefreshId), asgName, err)
+	}
+
+	return nil
+}
+
+func validateAutoScalingGroupInstanceRefreshTriggerFields(i interface{}, path cty.Path) diag.Diagnostics {
+	v, ok := i.(string)
+	if !ok {
+		return diag.Errorf("expected type to be string")
+	}
+
+	if v == "launch_configuration" || v == "launch_template" || v == "mixed_instances_policy" {
+		return diag.Diagnostics{
+			diag.Diagnostic{
+				Severity: diag.Warning,
+				Summary:  fmt.Sprintf("'%s' always triggers an instance refresh and can be removed", v),
+			},
+		}
+	}
+
+	schema := resourceAwsAutoscalingGroup().Schema
+	for attr, attrSchema := range schema {
+		if v == attr {
+			if attrSchema.Computed && !attrSchema.Optional {
+				return diag.Errorf("'%s' is a read-only parameter and cannot be used to trigger an instance refresh", v)
+			}
+			return nil
+		}
+	}
+
+	return diag.Errorf("'%s' is not a recognized parameter name for aws_autoscaling_group", v)
+}
