@@ -379,12 +379,12 @@ func flattenBatchComputeResources(computeResource *batch.ComputeResource) []map[
 	m["ec2_key_pair"] = aws.StringValue(computeResource.Ec2KeyPair)
 	m["image_id"] = aws.StringValue(computeResource.ImageId)
 	m["instance_role"] = aws.StringValue(computeResource.InstanceRole)
-	m["instance_type"] = schema.NewSet(schema.HashString, flattenStringList(computeResource.InstanceTypes))
+	m["instance_type"] = flattenStringSet(computeResource.InstanceTypes)
 	m["max_vcpus"] = int(aws.Int64Value(computeResource.MaxvCpus))
 	m["min_vcpus"] = int(aws.Int64Value(computeResource.MinvCpus))
-	m["security_group_ids"] = schema.NewSet(schema.HashString, flattenStringList(computeResource.SecurityGroupIds))
+	m["security_group_ids"] = flattenStringSet(computeResource.SecurityGroupIds)
 	m["spot_iam_fleet_role"] = aws.StringValue(computeResource.SpotIamFleetRole)
-	m["subnets"] = schema.NewSet(schema.HashString, flattenStringList(computeResource.Subnets))
+	m["subnets"] = flattenStringSet(computeResource.Subnets)
 	m["tags"] = keyvaluetags.BatchKeyValueTags(computeResource.Tags).IgnoreAws().Map()
 	m["type"] = aws.StringValue(computeResource.Type)
 
