@@ -3,9 +3,8 @@ package aws
 import (
 	"fmt"
 	"log"
-	"testing"
-
 	"regexp"
+	"testing"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/service/cloudtrail"
@@ -697,12 +696,14 @@ func testAccCheckCloudTrailLoadTags(trail *cloudtrail.Trail, tags *[]*cloudtrail
 func testAccAWSCloudTrailConfig(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-trail-foobar-%d"
+  name           = "tf-trail-foobar-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -714,14 +715,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -732,21 +733,23 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfigModified(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name                          = "tf-trail-foobar-%d"
+  name                          = "tf-trail-foobar-%[1]d"
   s3_bucket_name                = aws_s3_bucket.foo.id
   s3_key_prefix                 = "prefix"
   include_global_service_events = false
   enable_logging                = false
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -758,14 +761,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -776,21 +779,23 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfigCloudWatch(randInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "test" {
-  name           = "tf-acc-test-%d"
+  name           = "tf-acc-test-%[1]d"
   s3_bucket_name = aws_s3_bucket.test.id
 
   cloud_watch_logs_group_arn = "${aws_cloudwatch_log_group.test.arn}:*"
   cloud_watch_logs_role_arn  = aws_iam_role.test.arn
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "test" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -802,14 +807,14 @@ resource "aws_s3_bucket" "test" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -822,11 +827,11 @@ POLICY
 }
 
 resource "aws_cloudwatch_log_group" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
 }
 
 resource "aws_iam_role" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
 
   assume_role_policy = <<POLICY
 {
@@ -836,7 +841,7 @@ resource "aws_iam_role" "test" {
       "Sid": "",
       "Effect": "Allow",
       "Principal": {
-        "Service": "cloudtrail.amazonaws.com"
+        "Service": "cloudtrail.${data.aws_partition.current.dns_suffix}"
       },
       "Action": "sts:AssumeRole"
     }
@@ -846,7 +851,7 @@ POLICY
 }
 
 resource "aws_iam_role_policy" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
   role = aws_iam_role.test.id
 
   policy = <<POLICY
@@ -866,21 +871,23 @@ resource "aws_iam_role_policy" "test" {
 }
 POLICY
 }
-`, randInt, randInt, randInt, randInt, randInt, randInt, randInt)
+`, randInt)
 }
 
 func testAccAWSCloudTrailConfigCloudWatchModified(randInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "test" {
-  name           = "tf-acc-test-%d"
+  name           = "tf-acc-test-%[1]d"
   s3_bucket_name = aws_s3_bucket.test.id
 
   cloud_watch_logs_group_arn = "${aws_cloudwatch_log_group.second.arn}:*"
   cloud_watch_logs_role_arn  = aws_iam_role.test.arn
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "test" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -892,14 +899,14 @@ resource "aws_s3_bucket" "test" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -912,15 +919,15 @@ POLICY
 }
 
 resource "aws_cloudwatch_log_group" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
 }
 
 resource "aws_cloudwatch_log_group" "second" {
-  name = "tf-acc-test-cloudtrail-second-%d"
+  name = "tf-acc-test-cloudtrail-second-%[1]d"
 }
 
 resource "aws_iam_role" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
 
   assume_role_policy = <<POLICY
 {
@@ -930,7 +937,7 @@ resource "aws_iam_role" "test" {
       "Sid": "",
       "Effect": "Allow",
       "Principal": {
-        "Service": "cloudtrail.amazonaws.com"
+        "Service": "cloudtrail.${data.aws_partition.current.dns_suffix}"
       },
       "Action": "sts:AssumeRole"
     }
@@ -940,7 +947,7 @@ POLICY
 }
 
 resource "aws_iam_role_policy" "test" {
-  name = "tf-acc-test-cloudtrail-%d"
+  name = "tf-acc-test-cloudtrail-%[1]d"
   role = aws_iam_role.test.id
 
   policy = <<POLICY
@@ -960,19 +967,21 @@ resource "aws_iam_role_policy" "test" {
 }
 POLICY
 }
-`, randInt, randInt, randInt, randInt, randInt, randInt, randInt, randInt)
+`, randInt)
 }
 
 func testAccAWSCloudTrailConfigMultiRegion(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name                  = "tf-trail-foobar-%d"
+  name                  = "tf-trail-foobar-%[1]d"
   s3_bucket_name        = aws_s3_bucket.foo.id
   is_multi_region_trail = true
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -984,14 +993,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1002,23 +1011,25 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfigOrganization(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
+data "aws_partition" "current" {}
+
 resource "aws_organizations_organization" "test" {
-  aws_service_access_principals = ["cloudtrail.amazonaws.com"]
+  aws_service_access_principals = ["cloudtrail.${data.aws_partition.current.dns_suffix}"]
 }
 
 resource "aws_cloudtrail" "foobar" {
   is_organization_trail = true
-  name                  = "tf-trail-foobar-%d"
+  name                  = "tf-trail-foobar-%[1]d"
   s3_bucket_name        = aws_s3_bucket.foo.id
 }
 
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1030,14 +1041,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1048,21 +1059,23 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_logValidation(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name                          = "tf-acc-trail-log-validation-test-%d"
+  name                          = "tf-acc-trail-log-validation-test-%[1]d"
   s3_bucket_name                = aws_s3_bucket.foo.id
   is_multi_region_trail         = true
   include_global_service_events = true
   enable_log_file_validation    = true
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1074,14 +1087,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1092,19 +1105,21 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_logValidationModified(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name                          = "tf-acc-trail-log-validation-test-%d"
+  name                          = "tf-acc-trail-log-validation-test-%[1]d"
   s3_bucket_name                = aws_s3_bucket.foo.id
   include_global_service_events = true
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1116,14 +1131,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1134,13 +1149,13 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_kmsKey(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_kms_key" "foo" {
-  description = "Terraform acc test %d"
+  description = "Terraform acc test %[1]d"
 
   policy = <<POLICY
 {
@@ -1161,15 +1176,17 @@ resource "aws_kms_key" "foo" {
 POLICY
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_cloudtrail" "foobar" {
-  name                          = "tf-acc-trail-log-validation-test-%d"
+  name                          = "tf-acc-trail-log-validation-test-%[1]d"
   s3_bucket_name                = aws_s3_bucket.foo.id
   include_global_service_events = true
   kms_key_id                    = aws_kms_key.foo.arn
 }
 
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1181,14 +1198,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1199,18 +1216,20 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 var testAccAWSCloudTrailConfig_tags_tpl = `
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-acc-trail-log-validation-test-%d"
+  name           = "tf-acc-trail-log-validation-test-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
-  %s
+  %[2]s
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1222,14 +1241,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1245,13 +1264,15 @@ POLICY
 func testAccAWSCloudTrailConfig_include_global_service_events(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name                          = "tf-trail-foobar-%d"
+  name                          = "tf-trail-foobar-%[1]d"
   s3_bucket_name                = aws_s3_bucket.foo.id
   include_global_service_events = false
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1263,14 +1284,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1281,7 +1302,7 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_tags(cloudTrailRandInt int) string {
@@ -1292,12 +1313,7 @@ tags = {
 }
 `
 
-	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl,
-		cloudTrailRandInt,
-		tagsString,
-		cloudTrailRandInt,
-		cloudTrailRandInt,
-		cloudTrailRandInt)
+	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl, cloudTrailRandInt, tagsString)
 }
 
 func testAccAWSCloudTrailConfig_tagsModified(cloudTrailRandInt int) string {
@@ -1309,23 +1325,17 @@ tags = {
 }
 `
 
-	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl,
-		cloudTrailRandInt,
-		tagsString,
-		cloudTrailRandInt,
-		cloudTrailRandInt,
-		cloudTrailRandInt)
+	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl, cloudTrailRandInt, tagsString)
 }
 
 func testAccAWSCloudTrailConfig_tagsModifiedAgain(cloudTrailRandInt int) string {
-	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl,
-		cloudTrailRandInt, "", cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+	return fmt.Sprintf(testAccAWSCloudTrailConfig_tags_tpl, cloudTrailRandInt, "")
 }
 
 func testAccAWSCloudTrailConfig_eventSelector(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-trail-foobar-%d"
+  name           = "tf-trail-foobar-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
 
   event_selector {
@@ -1343,8 +1353,10 @@ resource "aws_cloudtrail" "foobar" {
   }
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1356,14 +1368,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1376,16 +1388,16 @@ POLICY
 }
 
 resource "aws_s3_bucket" "bar" {
-  bucket        = "tf-test-trail-event-select-%d"
+  bucket        = "tf-test-trail-event-select-%[1]d"
   force_destroy = true
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_eventSelectorReadWriteType(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-trail-foobar-%d"
+  name           = "tf-trail-foobar-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
 
   event_selector {
@@ -1394,8 +1406,10 @@ resource "aws_cloudtrail" "foobar" {
   }
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1407,14 +1421,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1425,13 +1439,13 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_eventSelectorModified(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-trail-foobar-%d"
+  name           = "tf-trail-foobar-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
 
   event_selector {
@@ -1471,8 +1485,10 @@ resource "aws_cloudtrail" "foobar" {
   }
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1484,14 +1500,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1504,12 +1520,12 @@ POLICY
 }
 
 resource "aws_s3_bucket" "bar" {
-  bucket        = "tf-test-trail-event-select-%d"
+  bucket        = "tf-test-trail-event-select-%[1]d"
   force_destroy = true
 }
 
 resource "aws_iam_role" "iam_for_lambda" {
-  name = "tf-test-trail-event-select-%d"
+  name = "tf-test-trail-event-select-%[1]d"
 
   assume_role_policy = <<EOF
 {
@@ -1518,7 +1534,7 @@ resource "aws_iam_role" "iam_for_lambda" {
     {
       "Action": "sts:AssumeRole",
       "Principal": {
-        "Service": "lambda.amazonaws.com"
+        "Service": "lambda.${data.aws_partition.current.dns_suffix}"
       },
       "Effect": "Allow",
       "Sid": ""
@@ -1530,23 +1546,25 @@ EOF
 
 resource "aws_lambda_function" "lambda_function_test" {
   filename      = "test-fixtures/lambdatest.zip"
-  function_name = "tf-test-trail-event-select-%d"
+  function_name = "tf-test-trail-event-select-%[1]d"
   role          = aws_iam_role.iam_for_lambda.arn
   handler       = "exports.example"
   runtime       = "nodejs12.x"
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_eventSelectorNone(cloudTrailRandInt int) string {
 	return fmt.Sprintf(`
 resource "aws_cloudtrail" "foobar" {
-  name           = "tf-trail-foobar-%d"
+  name           = "tf-trail-foobar-%[1]d"
   s3_bucket_name = aws_s3_bucket.foo.id
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "foo" {
-  bucket        = "tf-test-trail-%d"
+  bucket        = "tf-test-trail-%[1]d"
   force_destroy = true
 
   policy = <<POLICY
@@ -1558,14 +1576,14 @@ resource "aws_s3_bucket" "foo" {
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:GetBucketAcl",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d"
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d"
     },
     {
       "Sid": "AWSCloudTrailWrite",
       "Effect": "Allow",
       "Principal": "*",
       "Action": "s3:PutObject",
-      "Resource": "arn:aws:s3:::tf-test-trail-%d/*",
+      "Resource": "arn:${data.aws_partition.current.partition}:s3:::tf-test-trail-%[1]d/*",
       "Condition": {
         "StringEquals": {
           "s3:x-amz-acl": "bucket-owner-full-control"
@@ -1576,7 +1594,7 @@ resource "aws_s3_bucket" "foo" {
 }
 POLICY
 }
-`, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt, cloudTrailRandInt)
+`, cloudTrailRandInt)
 }
 
 func testAccAWSCloudTrailConfig_insightSelector(rName string) string {
@@ -1591,6 +1609,8 @@ resource "aws_cloudtrail" "test" {
   }
 }
 
+data "aws_partition" "current" {}
+
 resource "aws_s3_bucket" "test" {
   bucket        = %[1]q
   force_destroy = true
@@ -1604,14 +1624,14 @@ resource "aws_s3_bucket" "test" {
 			"Effect": "Allow",
 			"Principal": "*",
 			"Action": "s3:GetBucketAcl",
-			"Resource": "arn:aws:s3:::%[1]s"
+			"Resource": "arn:${data.aws_partition.current.partition}:s3:::%[1]s"
 		},
 		{
 			"Sid": "AWSCloudTrailWrite",
 			"Effect": "Allow",
 			"Principal": "*",
 			"Action": "s3:PutObject",
-			"Resource": "arn:aws:s3:::%[1]s/*",
+			"Resource": "arn:${data.aws_partition.current.partition}:s3:::%[1]s/*",
 			"Condition": {
 				"StringEquals": {
 					"s3:x-amz-acl": "bucket-owner-full-control"
