@@ -5,15 +5,15 @@ import (
 	"log"
 	"math"
 	"regexp"
-	"strings"
-
-	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
-	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/awserr"
 	events "github.com/aws/aws-sdk-go/service/cloudwatchevents"
+	"github.com/hashicorp/aws-sdk-go-base/tfawserr"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
+	tfevents "github.com/terraform-providers/terraform-provider-aws/aws/internal/service/cloudwatchevents"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/service/cloudwatchevents/finder"
 )
 
 func resourceAwsCloudWatchEventTarget() *schema.Resource {
@@ -27,7 +27,24 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 			State: resourceAwsCloudWatchEventTargetImport,
 		},
 
+		SchemaVersion: 1,
+		StateUpgraders: []schema.StateUpgrader{
+			{
+				Type:    resourceAwsCloudWatchEventTargetV0().CoreConfigSchema().ImpliedType(),
+				Upgrade: resourceAwsCloudWatchEventTargetStateUpgradeV0,
+				Version: 0,
+			},
+		},
+
 		Schema: map[string]*schema.Schema{
+			"event_bus_name": {
+				Type:         schema.TypeString,
+				Optional:     true,
+				ForceNew:     true,
+				ValidateFunc: validateCloudWatchEventBusName,
+				Default:      tfevents.DefaultEventBusName,
+			},
+
 			"rule": {
 				Type:         schema.TypeString,
 				Required:     true,
@@ -44,14 +61,15 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 			},
 
 			"arn": {
-				Type:     schema.TypeString,
-				Required: true,
+				Type:         schema.TypeString,
+				Required:     true,
+				ValidateFunc: validateArn,
 			},
 
 			"input": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"input_path"},
+				ConflictsWith: []string{"input_path", "input_transformer"},
 				// We could be normalizing the JSON here,
 				// but for built-in targets input may not be JSON
 			},
@@ -59,12 +77,13 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 			"input_path": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"input"},
+				ConflictsWith: []string{"input", "input_transformer"},
 			},
 
 			"role_arn": {
-				Type:     schema.TypeString,
-				Optional: true,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validateArn,
 			},
 
 			"run_command_targets": {
@@ -99,9 +118,10 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 							ValidateFunc: validation.StringLenBetween(1, 255),
 						},
 						"launch_type": {
-							Type:     schema.TypeString,
-							Optional: true,
-							Default:  "EC2",
+							Type:         schema.TypeString,
+							Optional:     true,
+							Default:      events.LaunchTypeEc2,
+							ValidateFunc: validation.StringInSlice(events.LaunchType_Values(), false),
 						},
 						"network_configuration": {
 							Type:     schema.TypeList,
@@ -113,13 +133,11 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 										Type:     schema.TypeSet,
 										Optional: true,
 										Elem:     &schema.Schema{Type: schema.TypeString},
-										Set:      schema.HashString,
 									},
 									"subnets": {
 										Type:     schema.TypeSet,
 										Required: true,
 										Elem:     &schema.Schema{Type: schema.TypeString},
-										Set:      schema.HashString,
 									},
 									"assign_public_ip": {
 										Type:     schema.TypeBool,
@@ -143,7 +161,7 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 						"task_definition_arn": {
 							Type:         schema.TypeString,
 							Required:     true,
-							ValidateFunc: validation.StringLenBetween(1, 1600),
+							ValidateFunc: validateArn,
 						},
 					},
 				},
@@ -207,15 +225,20 @@ func resourceAwsCloudWatchEventTarget() *schema.Resource {
 			},
 
 			"input_transformer": {
-				Type:     schema.TypeList,
-				Optional: true,
-				MaxItems: 1,
+				Type:          schema.TypeList,
+				Optional:      true,
+				MaxItems:      1,
+				ConflictsWith: []string{"input", "input_path"},
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"input_paths": {
 							Type:     schema.TypeMap,
 							Optional: true,
 							Elem:     &schema.Schema{Type: schema.TypeString},
+							ValidateFunc: validation.All(
+								MapMaxItems(10),
+								MapKeysDoNotMatch(regexp.MustCompile(`^AWS.*$`), "input_path must not start with \"AWS\""),
+							),
 						},
 						"input_template": {
 							Type:         schema.TypeString,
@@ -234,31 +257,34 @@ func resourceAwsCloudWatchEventTargetCreate(d *schema.ResourceData, meta interfa
 
 	rule := d.Get("rule").(string)
 
-	var targetId string
+	var targetID string
 	if v, ok := d.GetOk("target_id"); ok {
-		targetId = v.(string)
+		targetID = v.(string)
 	} else {
-		targetId = resource.UniqueId()
-		d.Set("target_id", targetId)
+		targetID = resource.UniqueId()
+		d.Set("target_id", targetID)
+	}
+	var busName string
+	if v, ok := d.GetOk("event_bus_name"); ok {
+		busName = v.(string)
 	}
 
 	input := buildPutTargetInputStruct(d)
 
-	log.Printf("[DEBUG] Creating CloudWatch Event Target: %s", input)
+	log.Printf("[DEBUG] Creating CloudWatch Events Target: %s", input)
 	out, err := conn.PutTargets(input)
 	if err != nil {
-		return fmt.Errorf("Creating CloudWatch Event Target failed: %s", err)
+		return fmt.Errorf("Creating CloudWatch Events Target failed: %w", err)
 	}
 
 	if len(out.FailedEntries) > 0 {
-		return fmt.Errorf("Creating CloudWatch Event Target failed: %s",
-			out.FailedEntries)
+		return fmt.Errorf("Creating CloudWatch Events Target failed: %s", out.FailedEntries)
 	}
 
-	id := rule + "-" + targetId
+	id := tfevents.TargetCreateID(busName, rule, targetID)
 	d.SetId(id)
 
-	log.Printf("[INFO] CloudWatch Event Target %q created", d.Id())
+	log.Printf("[INFO] CloudWatch Events Target (%s) created", d.Id())
 
 	return resourceAwsCloudWatchEventTargetRead(d, meta)
 }
@@ -266,32 +292,17 @@ func resourceAwsCloudWatchEventTargetCreate(d *schema.ResourceData, meta interfa
 func resourceAwsCloudWatchEventTargetRead(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).cloudwatcheventsconn
 
-	t, err := findEventTargetById(
-		d.Get("target_id").(string),
-		d.Get("rule").(string),
-		nil, conn)
+	busName := d.Get("event_bus_name").(string)
+
+	t, err := finder.Target(conn, busName, d.Get("rule").(string), d.Get("target_id").(string))
 	if err != nil {
-		if regexp.MustCompile(" not found$").MatchString(err.Error()) {
-			log.Printf("[WARN] Removing CloudWatch Event Target %q because it's gone.", d.Id())
+		if tfawserr.ErrCodeEquals(err, "ValidationException") ||
+			tfawserr.ErrCodeEquals(err, events.ErrCodeResourceNotFoundException) ||
+			regexp.MustCompile(" not found$").MatchString(err.Error()) {
+			log.Printf("[WARN] CloudWatch Events Target (%s) not found, removing from state", d.Id())
 			d.SetId("")
 			return nil
 		}
-		if awsErr, ok := err.(awserr.Error); ok {
-			// This should never happen, but it's useful
-			// for recovering from https://github.com/hashicorp/terraform/issues/5389
-			if awsErr.Code() == "ValidationException" {
-				log.Printf("[WARN] Removing CloudWatch Event Target %q because it never existed.", d.Id())
-				d.SetId("")
-				return nil
-			}
-
-			if awsErr.Code() == "ResourceNotFoundException" {
-				log.Printf("[WARN] CloudWatch Event Target (%q) not found. Removing it from state.", d.Id())
-				d.SetId("")
-				return nil
-			}
-
-		}
 		return err
 	}
 	log.Printf("[DEBUG] Found Event Target: %s", t)
@@ -301,80 +312,56 @@ func resourceAwsCloudWatchEventTargetRead(d *schema.ResourceData, meta interface
 	d.Set("input", t.Input)
 	d.Set("input_path", t.InputPath)
 	d.Set("role_arn", t.RoleArn)
+	d.Set("event_bus_name", busName)
 
 	if t.RunCommandParameters != nil {
 		if err := d.Set("run_command_targets", flattenAwsCloudWatchEventTargetRunParameters(t.RunCommandParameters)); err != nil {
-			return fmt.Errorf("Error setting run_command_targets error: %#v", err)
+			return fmt.Errorf("Error setting run_command_targets error: %w", err)
 		}
 	}
 
 	if t.EcsParameters != nil {
 		if err := d.Set("ecs_target", flattenAwsCloudWatchEventTargetEcsParameters(t.EcsParameters)); err != nil {
-			return fmt.Errorf("Error setting ecs_target error: %#v", err)
+			return fmt.Errorf("Error setting ecs_target error: %w", err)
 		}
 	}
 
 	if t.BatchParameters != nil {
 		if err := d.Set("batch_target", flattenAwsCloudWatchEventTargetBatchParameters(t.BatchParameters)); err != nil {
-			return fmt.Errorf("Error setting batch_target error: %#v", err)
+			return fmt.Errorf("Error setting batch_target error: %w", err)
 		}
 	}
 
 	if t.KinesisParameters != nil {
 		if err := d.Set("kinesis_target", flattenAwsCloudWatchEventTargetKinesisParameters(t.KinesisParameters)); err != nil {
-			return fmt.Errorf("Error setting kinesis_target error: %#v", err)
+			return fmt.Errorf("Error setting kinesis_target error: %w", err)
 		}
 	}
 
 	if t.SqsParameters != nil {
 		if err := d.Set("sqs_target", flattenAwsCloudWatchEventTargetSqsParameters(t.SqsParameters)); err != nil {
-			return fmt.Errorf("Error setting sqs_target error: %#v", err)
+			return fmt.Errorf("Error setting sqs_target error: %w", err)
 		}
 	}
 
 	if t.InputTransformer != nil {
 		if err := d.Set("input_transformer", flattenAwsCloudWatchInputTransformer(t.InputTransformer)); err != nil {
-			return fmt.Errorf("Error setting input_transformer error: %#v", err)
+			return fmt.Errorf("Error setting input_transformer error: %w", err)
 		}
 	}
 
 	return nil
 }
 
-func findEventTargetById(id, rule string, nextToken *string, conn *events.CloudWatchEvents) (*events.Target, error) {
-	input := events.ListTargetsByRuleInput{
-		Rule:      aws.String(rule),
-		NextToken: nextToken,
-		Limit:     aws.Int64(100), // Set limit to allowed maximum to prevent API throttling
-	}
-	log.Printf("[DEBUG] Reading CloudWatch Event Target: %s", input)
-	out, err := conn.ListTargetsByRule(&input)
-	if err != nil {
-		return nil, err
-	}
-
-	for _, t := range out.Targets {
-		if *t.Id == id {
-			return t, nil
-		}
-	}
-
-	if out.NextToken != nil {
-		return findEventTargetById(id, rule, nextToken, conn)
-	}
-
-	return nil, fmt.Errorf("CloudWatch Event Target %q (%q) not found", id, rule)
-}
-
 func resourceAwsCloudWatchEventTargetUpdate(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).cloudwatcheventsconn
 
 	input := buildPutTargetInputStruct(d)
 
-	log.Printf("[DEBUG] Updating CloudWatch Event Target: %s", input)
+	log.Printf("[DEBUG] Updating CloudWatch Events Target: %s", input)
 	_, err := conn.PutTargets(input)
 	if err != nil {
-		return fmt.Errorf("Updating CloudWatch Event Target failed: %s", err)
+		return fmt.Errorf("error updating CloudWatch Events Target (%s): %w", d.Id(), err)
 	}
 
 	return resourceAwsCloudWatchEventTargetRead(d, meta)
@@ -388,15 +375,21 @@ func resourceAwsCloudWatchEventTargetDelete(d *schema.ResourceData, meta interfa
 		Rule: aws.String(d.Get("rule").(string)),
 	}
 
-	output, err := conn.RemoveTargets(input)
+	if v, ok := d.GetOk("event_bus_name"); ok {
+		input.EventBusName = aws.String(v.(string))
+	}
 
+	output, err := conn.RemoveTargets(input)
 	if err != nil {
-		return fmt.Errorf("error deleting CloudWatch Event Target (%s): %s", d.Id(), err)
+		if tfawserr.ErrCodeEquals(err, events.ErrCodeResourceNotFoundException) {
+			return nil
+		}
+		return fmt.Errorf("error deleting CloudWatch Events Target (%s): %w", d.Id(), err)
 	}
 
 	if output != nil && len(output.FailedEntries) > 0 && output.FailedEntries[0] != nil {
 		failedEntry := output.FailedEntries[0]
-		return fmt.Errorf("error deleting CloudWatch Event Target (%s): failure entry: %s: %s", d.Id(), aws.StringValue(failedEntry.ErrorCode), aws.StringValue(failedEntry.ErrorMessage))
+		return fmt.Errorf("error deleting CloudWatch Events Target (%s): failure entry: %s: %s", d.Id(), aws.StringValue(failedEntry.ErrorCode), aws.StringValue(failedEntry.ErrorMessage))
 	}
 
 	return nil
@@ -445,21 +438,21 @@ func buildPutTargetInputStruct(d *schema.ResourceData) *events.PutTargetsInput {
 		Rule:    aws.String(d.Get("rule").(string)),
 		Targets: []*events.Target{e},
 	}
+	if v, ok := d.GetOk("event_bus_name"); ok {
+		input.EventBusName = aws.String(v.(string))
+	}
 
 	return &input
 }
 
 func expandAwsCloudWatchEventTargetRunParameters(config []interface{}) *events.RunCommandParameters {
-
 	commands := make([]*events.RunCommandTarget, 0)
-
 	for _, c := range config {
 		param := c.(map[string]interface{})
 		command := &events.RunCommandTarget{
 			Key:    aws.String(param["key"].(string)),
 			Values: expandStringList(param["values"].([]interface{})),
 		}
-
 		commands = append(commands, command)
 	}
 
@@ -582,7 +575,7 @@ func flattenAwsCloudWatchEventTargetRunParameters(runCommand *events.RunCommandP
 	for _, x := range runCommand.RunCommandTargets {
 		config := make(map[string]interface{})
 
-		config["key"] = *x.Key
+		config["key"] = aws.StringValue(x.Key)
 		config["values"] = flattenStringList(x.Values)
 
 		result = append(result, config)
@@ -593,31 +586,32 @@ func flattenAwsCloudWatchEventTargetRunParameters(runCommand *events.RunCommandP
 func flattenAwsCloudWatchEventTargetEcsParameters(ecsParameters *events.EcsParameters) []map[string]interface{} {
 	config := make(map[string]interface{})
 	if ecsParameters.Group != nil {
-		config["group"] = *ecsParameters.Group
+		config["group"] = aws.StringValue(ecsParameters.Group)
 	}
 	if ecsParameters.LaunchType != nil {
-		config["launch_type"] = *ecsParameters.LaunchType
+		config["launch_type"] = aws.StringValue(ecsParameters.LaunchType)
 	}
 	config["network_configuration"] = flattenAwsCloudWatchEventTargetEcsParametersNetworkConfiguration(ecsParameters.NetworkConfiguration)
 	if ecsParameters.PlatformVersion != nil {
-		config["platform_version"] = *ecsParameters.PlatformVersion
+		config["platform_version"] = aws.StringValue(ecsParameters.PlatformVersion)
 	}
-	config["task_count"] = *ecsParameters.TaskCount
-	config["task_definition_arn"] = *ecsParameters.TaskDefinitionArn
+	config["task_count"] = aws.Int64Value(ecsParameters.TaskCount)
+	config["task_definition_arn"] = aws.StringValue(ecsParameters.TaskDefinitionArn)
 	result := []map[string]interface{}{config}
 	return result
 }
+
 func flattenAwsCloudWatchEventTargetEcsParametersNetworkConfiguration(nc *events.NetworkConfiguration) []interface{} {
 	if nc == nil {
 		return nil
 	}
 
 	result := make(map[string]interface{})
-	result["security_groups"] = schema.NewSet(schema.HashString, flattenStringList(nc.AwsvpcConfiguration.SecurityGroups))
-	result["subnets"] = schema.NewSet(schema.HashString, flattenStringList(nc.AwsvpcConfiguration.Subnets))
+	result["security_groups"] = flattenStringSet(nc.AwsvpcConfiguration.SecurityGroups)
+	result["subnets"] = flattenStringSet(nc.AwsvpcConfiguration.Subnets)
 
 	if nc.AwsvpcConfiguration.AssignPublicIp != nil {
-		result["assign_public_ip"] = *nc.AwsvpcConfiguration.AssignPublicIp == events.AssignPublicIpEnabled
+		result["assign_public_ip"] = aws.StringValue(nc.AwsvpcConfiguration.AssignPublicIp) == events.AssignPublicIpEnabled
 	}
 
 	return []interface{}{result}
@@ -639,14 +633,14 @@ func flattenAwsCloudWatchEventTargetBatchParameters(batchParameters *events.Batc
 
 func flattenAwsCloudWatchEventTargetKinesisParameters(kinesisParameters *events.KinesisParameters) []map[string]interface{} {
 	config := make(map[string]interface{})
-	config["partition_key_path"] = *kinesisParameters.PartitionKeyPath
+	config["partition_key_path"] = aws.StringValue(kinesisParameters.PartitionKeyPath)
 	result := []map[string]interface{}{config}
 	return result
 }
 
 func flattenAwsCloudWatchEventTargetSqsParameters(sqsParameters *events.SqsParameters) []map[string]interface{} {
 	config := make(map[string]interface{})
-	config["message_group_id"] = *sqsParameters.MessageGroupId
+	config["message_group_id"] = aws.StringValue(sqsParameters.MessageGroupId)
 	result := []map[string]interface{}{config}
 	return result
 }
@@ -655,9 +649,9 @@ func flattenAwsCloudWatchInputTransformer(inputTransformer *events.InputTransfor
 	config := make(map[string]interface{})
 	inputPathsMap := make(map[string]string)
 	for k, v := range inputTransformer.InputPathsMap {
-		inputPathsMap[k] = *v
+		inputPathsMap[k] = aws.StringValue(v)
 	}
-	config["input_template"] = *inputTransformer.InputTemplate
+	config["input_template"] = aws.StringValue(inputTransformer.InputTemplate)
 	config["input_paths"] = inputPathsMap
 
 	result := []map[string]interface{}{config}
@@ -665,17 +659,16 @@ func flattenAwsCloudWatchInputTransformer(inputTransformer *events.InputTransfor
 }
 
 func resourceAwsCloudWatchEventTargetImport(d *schema.ResourceData, meta interface{}) ([]*schema.ResourceData, error) {
-	idParts := strings.SplitN(d.Id(), "/", 2)
-	if len(idParts) != 2 || idParts[0] == "" || idParts[1] == "" {
-		return nil, fmt.Errorf("unexpected format (%q), expected <rule-name>/<target-id>", d.Id())
+	busName, ruleName, targetID, err := tfevents.TargetParseImportID(d.Id())
+	if err != nil {
+		return []*schema.ResourceData{}, err
 	}
 
-	ruleName := idParts[0]
-	targetName := idParts[1]
-
-	d.Set("target_id", targetName)
+	id := tfevents.TargetCreateID(busName, ruleName, targetID)
+	d.SetId(id)
+	d.Set("target_id", targetID)
 	d.Set("rule", ruleName)
-	d.SetId(ruleName + "-" + targetName)
+	d.Set("event_bus_name", busName)
 
 	return []*schema.ResourceData{d}, nil
 }
