@@ -10,13 +10,13 @@ import (
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/acctest"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/terraform"
-	"github.com/terraform-providers/terraform-provider-aws/aws/internal/tfawsresource"
 )
 
 func TestAccAWSDefaultRouteTable_basic(t *testing.T) {
-	var routeTable1 ec2.RouteTable
+	var routeTable ec2.RouteTable
 	resourceName := "aws_default_route_table.test"
 	vpcResourceName := "aws_vpc.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t) },
@@ -34,9 +34,9 @@ func TestAccAWSDefaultRouteTable_basic(t *testing.T) {
 				ExpectError: regexp.MustCompile(`EC2 Default Route Table \(vpc-00000000\): not found`),
 			},
 			{
-				Config: testAccDefaultRouteTableConfigRequired(),
+				Config: testAccDefaultRouteTableConfigBasic(rName),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(resourceName, &routeTable1),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
 					testAccCheckResourceAttrAccountID(resourceName, "owner_id"),
 					resource.TestCheckResourceAttr(resourceName, "propagating_vgws.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "route.#", "0"),
@@ -55,10 +55,11 @@ func TestAccAWSDefaultRouteTable_basic(t *testing.T) {
 }
 
 func TestAccAWSDefaultRouteTable_disappears_Vpc(t *testing.T) {
-	var routeTable1 ec2.RouteTable
-	var vpc1 ec2.Vpc
+	var routeTable ec2.RouteTable
+	var vpc ec2.Vpc
 	resourceName := "aws_default_route_table.test"
 	vpcResourceName := "aws_vpc.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t) },
@@ -66,11 +67,11 @@ func TestAccAWSDefaultRouteTable_disappears_Vpc(t *testing.T) {
 		CheckDestroy: testAccCheckRouteTableDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccDefaultRouteTableConfigRequired(),
+				Config: testAccDefaultRouteTableConfigBasic(rName),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(resourceName, &routeTable1),
-					testAccCheckVpcExists(vpcResourceName, &vpc1),
-					testAccCheckVpcDisappears(&vpc1),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckVpcExists(vpcResourceName, &vpc),
+					testAccCheckResourceDisappears(testAccProvider, resourceAwsVpc(), vpcResourceName),
 				),
 				ExpectNonEmptyPlan: true,
 			},
@@ -78,9 +79,12 @@ func TestAccAWSDefaultRouteTable_disappears_Vpc(t *testing.T) {
 	})
 }
 
-func TestAccAWSDefaultRouteTable_Route(t *testing.T) {
-	var v ec2.RouteTable
-	resourceName := "aws_default_route_table.foo"
+func TestAccAWSDefaultRouteTable_Route_ConfigMode(t *testing.T) {
+	var routeTable ec2.RouteTable
+	resourceName := "aws_default_route_table.test"
+	igwResourceName := "aws_internet_gateway.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr := "10.2.0.0/16"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:      func() { testAccPreCheck(t) },
@@ -89,10 +93,16 @@ func TestAccAWSDefaultRouteTable_Route(t *testing.T) {
 		CheckDestroy:  testAccCheckDefaultRouteTableDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccDefaultRouteTableConfig,
+				Config: testAccDefaultRouteTableConfigIpv4InternetGateway(rName, destinationCidr),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(resourceName, &v),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
 					testAccCheckResourceAttrAccountID(resourceName, "owner_id"),
+					resource.TestCheckResourceAttr(resourceName, "propagating_vgws.#", "0"),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "gateway_id", igwResourceName, "id"),
+					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
+					resource.TestCheckResourceAttr(resourceName, "tags.Name", rName),
 				),
 			},
 			{
@@ -102,19 +112,32 @@ func TestAccAWSDefaultRouteTable_Route(t *testing.T) {
 				ImportStateVerify: true,
 			},
 			{
-				Config: testAccDefaultRouteTableConfig_noRouteBlock,
+				Config: testAccDefaultRouteTableConfigNoRouteBlock(rName),
 				Check: resource.ComposeTestCheckFunc(
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					testAccCheckResourceAttrAccountID(resourceName, "owner_id"),
+					resource.TestCheckResourceAttr(resourceName, "propagating_vgws.#", "0"),
 					// The route block from the previous step should still be
 					// present, because no blocks means "ignore existing blocks".
 					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "gateway_id", igwResourceName, "id"),
+					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
+					resource.TestCheckResourceAttr(resourceName, "tags.Name", rName),
 				),
 			},
 			{
-				Config: testAccDefaultRouteTableConfig_routeBlocksExplicitZero,
+				Config: testAccDefaultRouteTableConfigRouteBlocksExplicitZero(rName),
 				Check: resource.ComposeTestCheckFunc(
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 1),
+					testAccCheckResourceAttrAccountID(resourceName, "owner_id"),
+					resource.TestCheckResourceAttr(resourceName, "propagating_vgws.#", "0"),
 					// This config uses attribute syntax to set zero routes
 					// explicitly, so should remove the one we created before.
 					resource.TestCheckResourceAttr(resourceName, "route.#", "0"),
+					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
+					resource.TestCheckResourceAttr(resourceName, "tags.Name", rName),
 				),
 			},
 		},
@@ -122,8 +145,13 @@ func TestAccAWSDefaultRouteTable_Route(t *testing.T) {
 }
 
 func TestAccAWSDefaultRouteTable_swap(t *testing.T) {
-	var v ec2.RouteTable
-	resourceName := "aws_default_route_table.foo"
+	var routeTable ec2.RouteTable
+	resourceName := "aws_default_route_table.test"
+	igwResourceName := "aws_internet_gateway.test"
+	rtResourceName := "aws_route_table.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr1 := "10.2.0.0/16"
+	destinationCidr2 := "10.3.0.0/16"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:      func() { testAccPreCheck(t) },
@@ -132,10 +160,16 @@ func TestAccAWSDefaultRouteTable_swap(t *testing.T) {
 		CheckDestroy:  testAccCheckDefaultRouteTableDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccDefaultRouteTable_change,
+				Config: testAccDefaultRouteTableConfigIpv4InternetGateway(rName, destinationCidr1),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(
-						resourceName, &v),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					testAccCheckResourceAttrAccountID(resourceName, "owner_id"),
+					resource.TestCheckResourceAttr(resourceName, "propagating_vgws.#", "0"),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr1, "gateway_id", igwResourceName, "id"),
+					resource.TestCheckResourceAttr(resourceName, "tags.%", "1"),
+					resource.TestCheckResourceAttr(resourceName, "tags.Name", rName),
 				),
 			},
 			{
@@ -151,20 +185,38 @@ func TestAccAWSDefaultRouteTable_swap(t *testing.T) {
 			// this case) a diff as the table now needs to be updated to match the
 			// config
 			{
-				Config: testAccDefaultRouteTable_change_mod,
+				Config: testAccDefaultRouteTableConfigSwap(rName, destinationCidr1, destinationCidr2),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(
-						resourceName, &v),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr1, "gateway_id", igwResourceName, "id"),
 				),
 				ExpectNonEmptyPlan: true,
 			},
+			{
+				Config: testAccDefaultRouteTableConfigSwap(rName, destinationCidr1, destinationCidr2),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr1, "gateway_id", igwResourceName, "id"),
+					resource.TestCheckResourceAttrPair(resourceName, "id", rtResourceName, "id"),
+				),
+				// Follow up plan will now show a diff as the destination CIDR on the aws_route_table
+				// (now also the aws_default_route_table) will change from destinationCidr1 to destinationCidr2.
+				ExpectNonEmptyPlan: true,
+			},
 		},
 	})
 }
 
-func TestAccAWSDefaultRouteTable_Route_TransitGatewayID(t *testing.T) {
-	var routeTable1 ec2.RouteTable
+func TestAccAWSDefaultRouteTable_IPv4_To_TransitGateway(t *testing.T) {
+	var routeTable ec2.RouteTable
 	resourceName := "aws_default_route_table.test"
+	tgwResourceName := "aws_ec2_transit_gateway.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr := "10.2.0.0/16"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t) },
@@ -172,9 +224,12 @@ func TestAccAWSDefaultRouteTable_Route_TransitGatewayID(t *testing.T) {
 		CheckDestroy: testAccCheckRouteTableDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccAWSDefaultRouteTableConfigRouteTransitGatewayID(),
+				Config: testAccDefaultRouteTableConfigIpv4TransitGateway(rName, destinationCidr),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(resourceName, &routeTable1),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "transit_gateway_id", tgwResourceName, "id"),
 				),
 			},
 			{
@@ -187,9 +242,52 @@ func TestAccAWSDefaultRouteTable_Route_TransitGatewayID(t *testing.T) {
 	})
 }
 
-func TestAccAWSDefaultRouteTable_vpc_endpoint(t *testing.T) {
-	var v ec2.RouteTable
-	resourceName := "aws_default_route_table.foo"
+func TestAccAWSDefaultRouteTable_IPv4_To_VpcEndpoint(t *testing.T) {
+	var routeTable ec2.RouteTable
+	resourceName := "aws_default_route_table.test"
+	vpceResourceName := "aws_vpc_endpoint.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr := "0.0.0.0/0"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckRouteTableDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccDefaultRouteTableConfigIpv4VpcEndpoint(rName, destinationCidr),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 2),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "vpc_endpoint_id", vpceResourceName, "id"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateIdFunc: testAccAWSDefaultRouteTableImportStateIdFunc(resourceName),
+				ImportStateVerify: true,
+			},
+			// Default route tables do not currently have a method to remove routes during deletion.
+			// VPC Endpoints will not delete unless the route is removed prior, otherwise will error:
+			// InvalidParameter: Endpoint must be removed from route table before deletion
+			{
+				Config: testAccDefaultRouteTableConfigIpv4VpcEndpointNoRoute(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+				),
+			},
+		},
+	})
+}
+
+func TestAccAWSDefaultRouteTable_VpcEndpointAssociation(t *testing.T) {
+	var routeTable ec2.RouteTable
+	resourceName := "aws_default_route_table.test"
+	igwResourceName := "aws_internet_gateway.test"
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr := "10.2.0.0/16"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:      func() { testAccPreCheck(t) },
@@ -198,10 +296,12 @@ func TestAccAWSDefaultRouteTable_vpc_endpoint(t *testing.T) {
 		CheckDestroy:  testAccCheckDefaultRouteTableDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccDefaultRouteTable_vpc_endpoint,
+				Config: testAccDefaultRouteTableConfigVpcEndpointAssociation(rName, destinationCidr),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckRouteTableExists(
-						resourceName, &v),
+					testAccCheckRouteTableExists(resourceName, &routeTable),
+					testAccCheckAWSRouteTableNumberOfRoutes(&routeTable, 3),
+					resource.TestCheckResourceAttr(resourceName, "route.#", "1"),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "gateway_id", igwResourceName, "id"),
 				),
 			},
 			{
@@ -256,7 +356,10 @@ func TestAccAWSDefaultRouteTable_tags(t *testing.T) {
 func TestAccAWSDefaultRouteTable_ConditionalCidrBlock(t *testing.T) {
 	var routeTable ec2.RouteTable
 	resourceName := "aws_default_route_table.test"
+	igwResourceName := "aws_internet_gateway.test"
 	rName := acctest.RandomWithPrefix("tf-acc-test")
+	destinationCidr := "10.2.0.0/16"
+	destinationIpv6Cidr := "::/0"
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t) },
@@ -264,23 +367,17 @@ func TestAccAWSDefaultRouteTable_ConditionalCidrBlock(t *testing.T) {
 		CheckDestroy: testAccCheckAWSRouteDestroy,
 		Steps: []resource.TestStep{
 			{
-				Config: testAccAWSDefaultRouteTableConfigConditionalIpv4Ipv6(rName, false),
+				Config: testAccDefaultRouteTableConfigConditionalIpv4Ipv6(rName, destinationCidr, destinationIpv6Cidr, false),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckRouteTableExists(resourceName, &routeTable),
-					tfawsresource.TestCheckTypeSetElemNestedAttrs(resourceName, "route.*", map[string]string{
-						"cidr_block":      "0.0.0.0/0",
-						"ipv6_cidr_block": "",
-					}),
+					testAccCheckDefaultRouteTableRoute(resourceName, "cidr_block", destinationCidr, "gateway_id", igwResourceName, "id"),
 				),
 			},
 			{
-				Config: testAccAWSDefaultRouteTableConfigConditionalIpv4Ipv6(rName, true),
+				Config: testAccDefaultRouteTableConfigConditionalIpv4Ipv6(rName, destinationCidr, destinationIpv6Cidr, true),
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckRouteTableExists(resourceName, &routeTable),
-					tfawsresource.TestCheckTypeSetElemNestedAttrs(resourceName, "route.*", map[string]string{
-						"cidr_block":      "",
-						"ipv6_cidr_block": "::/0",
-					}),
+					testAccCheckDefaultRouteTableRoute(resourceName, "ipv6_cidr_block", destinationIpv6Cidr, "gateway_id", igwResourceName, "id"),
 				),
 			},
 			{
@@ -322,6 +419,25 @@ func testAccCheckDefaultRouteTableDestroy(s *terraform.State) error {
 	return nil
 }
 
+func testAccCheckDefaultRouteTableRoute(resourceName, destinationAttr, destination, targetAttr, targetResourceName, targetResourceAttr string) resource.TestCheckFunc {
+	return func(s *terraform.State) error {
+		rs, ok := s.RootModule().Resources[targetResourceName]
+		if !ok {
+			return fmt.Errorf("Not found: %s", targetResourceName)
+		}
+
+		target := rs.Primary.Attributes[targetResourceAttr]
+		if target == "" {
+			return fmt.Errorf("Not found: %s.%s", targetResourceName, targetResourceAttr)
+		}
+
+		return resource.TestCheckTypeSetElemNestedAttrs(resourceName, "route.*", map[string]string{
+			destinationAttr: destination,
+			targetAttr:      target,
+		})(s)
+	}
+}
+
 func testAccDefaultRouteTableConfigDefaultRouteTableId(defaultRouteTableId string) string {
 	return fmt.Sprintf(`
 resource "aws_default_route_table" "test" {
@@ -330,222 +446,189 @@ resource "aws_default_route_table" "test" {
 `, defaultRouteTableId)
 }
 
-func testAccDefaultRouteTableConfigRequired() string {
-	return `
+func testAccDefaultRouteTableConfigBasic(rName string) string {
+	return fmt.Sprintf(`
 resource "aws_vpc" "test" {
   cidr_block = "10.1.0.0/16"
+
+  tags = {
+    Name = %[1]q
+  }
 }
 
 resource "aws_default_route_table" "test" {
   default_route_table_id = aws_vpc.test.default_route_table_id
 }
-`
+`, rName)
 }
 
-const testAccDefaultRouteTableConfig = `
-resource "aws_vpc" "foo" {
+func testAccDefaultRouteTableConfigIpv4InternetGateway(rName, destinationCidr string) string {
+	return fmt.Sprintf(`
+resource "aws_vpc" "test" {
   cidr_block           = "10.1.0.0/16"
   enable_dns_hostnames = true
 
   tags = {
-    Name = "terraform-testacc-default-route-table"
+    Name = %[1]q
   }
 }
 
-resource "aws_default_route_table" "foo" {
-  default_route_table_id = aws_vpc.foo.default_route_table_id
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
 
   route {
-    cidr_block = "10.0.1.0/32"
-    gateway_id = aws_internet_gateway.gw.id
+    cidr_block = %[2]q
+    gateway_id = aws_internet_gateway.test.id
   }
 
   tags = {
-    Name = "tf-default-route-table-test"
+    Name = %[1]q
   }
 }
 
-resource "aws_internet_gateway" "gw" {
-  vpc_id = aws_vpc.foo.id
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
 
   tags = {
-    Name = "tf-default-route-table-test"
+    Name = %[1]q
   }
-}`
+}
+`, rName, destinationCidr)
+}
 
-const testAccDefaultRouteTableConfig_noRouteBlock = `
-resource "aws_vpc" "foo" {
+func testAccDefaultRouteTableConfigNoRouteBlock(rName string) string {
+	return fmt.Sprintf(`
+resource "aws_vpc" "test" {
   cidr_block           = "10.1.0.0/16"
   enable_dns_hostnames = true
 
   tags = {
-    Name = "terraform-testacc-default-route-table"
+    Name = %[1]q
   }
 }
 
-resource "aws_default_route_table" "foo" {
-  default_route_table_id = aws_vpc.foo.default_route_table_id
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
 
   tags = {
-    Name = "tf-default-route-table-test"
+    Name = %[1]q
   }
 }
 
-resource "aws_internet_gateway" "gw" {
-  vpc_id = aws_vpc.foo.id
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
 
   tags = {
-    Name = "tf-default-route-table-test"
+    Name = %[1]q
   }
-}`
+}`, rName)
+}
 
-const testAccDefaultRouteTableConfig_routeBlocksExplicitZero = `
-resource "aws_vpc" "foo" {
+func testAccDefaultRouteTableConfigRouteBlocksExplicitZero(rName string) string {
+	return fmt.Sprintf(`
+resource "aws_vpc" "test" {
   cidr_block           = "10.1.0.0/16"
   enable_dns_hostnames = true
 
   tags = {
-    Name = "terraform-testacc-default-route-table"
+    Name = %[1]q
   }
 }
 
-resource "aws_default_route_table" "foo" {
-  default_route_table_id = aws_vpc.foo.default_route_table_id
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
 
   route = []
 
   tags = {
-    Name = "tf-default-route-table-test"
+    Name = %[1]q
   }
 }
 
-resource "aws_internet_gateway" "gw" {
-  vpc_id = aws_vpc.foo.id
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
 
   tags = {
-    Name = "tf-default-route-table-test"
-  }
-}`
-
-const testAccDefaultRouteTable_change = `
-resource "aws_vpc" "foo" {
-  cidr_block           = "10.1.0.0/16"
-  enable_dns_hostnames = true
-
-  tags = {
-    Name = "terraform-testacc-default-route-table-change"
+    Name = %[1]q
   }
+}`, rName)
 }
 
-resource "aws_default_route_table" "foo" {
-  default_route_table_id = aws_vpc.foo.default_route_table_id
-
-  route {
-    cidr_block = "10.0.1.0/32"
-    gateway_id = aws_internet_gateway.gw.id
-  }
-
-  tags = {
-    Name = "this was the first main"
-  }
-}
-
-resource "aws_internet_gateway" "gw" {
-  vpc_id = aws_vpc.foo.id
-
-  tags = {
-    Name = "main-igw"
-  }
-}
-
-# Thing to help testing changes
-resource "aws_route_table" "r" {
-  vpc_id = aws_vpc.foo.id
-
-  route {
-    cidr_block = "10.0.1.0/24"
-    gateway_id = aws_internet_gateway.gw.id
-  }
-
-  tags = {
-    Name = "other"
-  }
-}
-`
-
-const testAccDefaultRouteTable_change_mod = `
-resource "aws_vpc" "foo" {
-  cidr_block           = "10.1.0.0/16"
-  enable_dns_hostnames = true
-
-  tags = {
-    Name = "terraform-testacc-default-route-table-change"
-  }
-}
-
-resource "aws_default_route_table" "foo" {
-  default_route_table_id = aws_vpc.foo.default_route_table_id
-
-  route {
-    cidr_block = "10.0.1.0/32"
-    gateway_id = aws_internet_gateway.gw.id
-  }
-
-  tags = {
-    Name = "this was the first main"
-  }
-}
-
-resource "aws_internet_gateway" "gw" {
-  vpc_id = aws_vpc.foo.id
-
-  tags = {
-    Name = "main-igw"
-  }
-}
-
-# Thing to help testing changes
-resource "aws_route_table" "r" {
-  vpc_id = aws_vpc.foo.id
-
-  route {
-    cidr_block = "10.0.1.0/24"
-    gateway_id = aws_internet_gateway.gw.id
-  }
-
-  tags = {
-    Name = "other"
-  }
-}
-
-resource "aws_main_route_table_association" "a" {
-  vpc_id         = aws_vpc.foo.id
-  route_table_id = aws_route_table.r.id
-}
-`
-
-func testAccAWSDefaultRouteTableConfigRouteTransitGatewayID() string {
-	return `
+func testAccDefaultRouteTableConfigSwap(rName, destinationCidr1, destinationCidr2 string) string {
+	return fmt.Sprintf(`
 resource "aws_vpc" "test" {
-  cidr_block = "10.0.0.0/16"
+  cidr_block           = "10.1.0.0/16"
+  enable_dns_hostnames = true
 
   tags = {
-    Name = "tf-acc-test-ec2-default-route-table-transit-gateway-id"
+    Name = %[1]q
+  }
+}
+
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
+
+  route {
+    cidr_block = %[2]q
+    gateway_id = aws_internet_gateway.test.id
+  }
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_route_table" "test" {
+  vpc_id = aws_vpc.test.id
+
+  route {
+    cidr_block = %[3]q
+    gateway_id = aws_internet_gateway.test.id
+  }
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_main_route_table_association" "test" {
+  vpc_id         = aws_vpc.test.id
+  route_table_id = aws_route_table.test.id
+}
+`, rName, destinationCidr1, destinationCidr2)
+}
+
+func testAccDefaultRouteTableConfigIpv4TransitGateway(rName, destinationCidr string) string {
+	return composeConfig(testAccAvailableAZsNoOptInDefaultExcludeConfig(), fmt.Sprintf(`
+resource "aws_vpc" "test" {
+  cidr_block = "10.1.0.0/16"
+
+  tags = {
+    Name = %[1]q
   }
 }
 
 resource "aws_subnet" "test" {
-  cidr_block = "10.0.0.0/24"
-  vpc_id     = aws_vpc.test.id
+  availability_zone = data.aws_availability_zones.available.names[0]
+  cidr_block        = "10.1.1.0/24"
+  vpc_id            = aws_vpc.test.id
 
   tags = {
-    Name = "tf-acc-test-ec2-default-route-table-transit-gateway-id"
+    Name = %[1]q
   }
 }
 
 resource "aws_ec2_transit_gateway" "test" {
   tags = {
-    Name = "tf-acc-test-ec2-default-route-table-transit-gateway-id"
+    Name = %[1]q
   }
 }
 
@@ -555,7 +638,7 @@ resource "aws_ec2_transit_gateway_vpc_attachment" "test" {
   vpc_id             = aws_vpc.test.id
 
   tags = {
-    Name = "tf-acc-test-ec2-default-route-table-transit-gateway-id"
+    Name = %[1]q
   }
 }
 
@@ -563,55 +646,217 @@ resource "aws_default_route_table" "test" {
   default_route_table_id = aws_vpc.test.default_route_table_id
 
   route {
-    cidr_block         = "0.0.0.0/0"
+    cidr_block         = %[2]q
     transit_gateway_id = aws_ec2_transit_gateway_vpc_attachment.test.transit_gateway_id
   }
+
+  tags = {
+    Name = %[1]q
+  }
 }
-`
+`, rName, destinationCidr))
 }
 
-const testAccDefaultRouteTable_vpc_endpoint = `
+func testAccDefaultRouteTableConfigIpv4VpcEndpoint(rName, destinationCidr string) string {
+	return composeConfig(
+		testAccAvailableAZsNoOptInConfig(),
+		fmt.Sprintf(`
+data "aws_caller_identity" "current" {}
+
+resource "aws_vpc" "test" {
+  cidr_block = "10.10.10.0/25"
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+# Another route destination for update
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_subnet" "test" {
+  availability_zone = data.aws_availability_zones.available.names[0]
+  cidr_block        = cidrsubnet(aws_vpc.test.cidr_block, 2, 0)
+  vpc_id            = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_lb" "test" {
+  load_balancer_type = "gateway"
+  name               = %[1]q
+
+  subnet_mapping {
+    subnet_id = aws_subnet.test.id
+  }
+}
+
+resource "aws_vpc_endpoint_service" "test" {
+  acceptance_required        = false
+  allowed_principals         = [data.aws_caller_identity.current.arn]
+  gateway_load_balancer_arns = [aws_lb.test.arn]
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_vpc_endpoint" "test" {
+  service_name      = aws_vpc_endpoint_service.test.service_name
+  subnet_ids        = [aws_subnet.test.id]
+  vpc_endpoint_type = aws_vpc_endpoint_service.test.service_type
+  vpc_id            = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
+
+  route {
+    cidr_block      = %[2]q
+    vpc_endpoint_id = aws_vpc_endpoint.test.id
+  }
+
+  tags = {
+    Name = %[1]q
+  }
+}
+`, rName, destinationCidr))
+}
+
+func testAccDefaultRouteTableConfigIpv4VpcEndpointNoRoute(rName string) string {
+	return composeConfig(
+		testAccAvailableAZsNoOptInConfig(),
+		fmt.Sprintf(`
+data "aws_caller_identity" "current" {}
+
+resource "aws_vpc" "test" {
+  cidr_block = "10.10.10.0/25"
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+# Another route destination for update
+resource "aws_internet_gateway" "test" {
+  vpc_id = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_subnet" "test" {
+  availability_zone = data.aws_availability_zones.available.names[0]
+  cidr_block        = cidrsubnet(aws_vpc.test.cidr_block, 2, 0)
+  vpc_id            = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_lb" "test" {
+  load_balancer_type = "gateway"
+  name               = %[1]q
+
+  subnet_mapping {
+    subnet_id = aws_subnet.test.id
+  }
+}
+
+resource "aws_vpc_endpoint_service" "test" {
+  acceptance_required        = false
+  allowed_principals         = [data.aws_caller_identity.current.arn]
+  gateway_load_balancer_arns = [aws_lb.test.arn]
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_vpc_endpoint" "test" {
+  service_name      = aws_vpc_endpoint_service.test.service_name
+  subnet_ids        = [aws_subnet.test.id]
+  vpc_endpoint_type = aws_vpc_endpoint_service.test.service_type
+  vpc_id            = aws_vpc.test.id
+
+  tags = {
+    Name = %[1]q
+  }
+}
+
+resource "aws_default_route_table" "test" {
+  default_route_table_id = aws_vpc.test.default_route_table_id
+
+  route {
+    cidr_block = "0.0.0.0/0"
+    gateway_id = aws_internet_gateway.test.id
+  }
+
+  tags = {
+    Name = %[1]q
+  }
+}
+`, rName))
+}
+
+func testAccDefaultRouteTableConfigVpcEndpointAssociation(rName, destinationCidr string) string {
+	return fmt.Sprintf(`
 data "aws_region" "current" {}
 
 resource "aws_vpc" "test" {
   cidr_block = "10.0.0.0/16"
 
   tags = {
-    Name = "terraform-testacc-default-route-table-vpc-endpoint"
+    Name = %[1]q
   }
 }
 
-resource "aws_internet_gateway" "igw" {
+resource "aws_internet_gateway" "test" {
   vpc_id = aws_vpc.test.id
 
   tags = {
-    Name = "terraform-testacc-default-route-table-vpc-endpoint"
+    Name = %[1]q
   }
 }
 
-resource "aws_vpc_endpoint" "s3" {
+resource "aws_vpc_endpoint" "test" {
   vpc_id          = aws_vpc.test.id
   service_name    = "com.amazonaws.${data.aws_region.current.name}.s3"
   route_table_ids = [aws_vpc.test.default_route_table_id]
 
   tags = {
-    Name = "terraform-testacc-default-route-table-vpc-endpoint"
+    Name = %[1]q
   }
 }
 
-resource "aws_default_route_table" "foo" {
+resource "aws_default_route_table" "test" {
   default_route_table_id = aws_vpc.test.default_route_table_id
 
   tags = {
-    Name = "test"
+    Name = %[1]q
   }
 
   route {
-    cidr_block = "0.0.0.0/0"
-    gateway_id = aws_internet_gateway.igw.id
+    cidr_block = %[2]q
+    gateway_id = aws_internet_gateway.test.id
   }
 }
-`
+`, rName, destinationCidr)
+}
 
 func testAccDefaultRouteTableConfigTags1(rName, tagKey1, tagValue1 string) string {
 	return fmt.Sprintf(`
@@ -654,7 +899,7 @@ resource "aws_default_route_table" "test" {
 `, rName, tagKey1, tagValue1, tagKey2, tagValue2)
 }
 
-func testAccAWSDefaultRouteTableConfigConditionalIpv4Ipv6(rName string, ipv6Route bool) string {
+func testAccDefaultRouteTableConfigConditionalIpv4Ipv6(rName, destinationCidr, destinationIpv6Cidr string, ipv6Route bool) string {
 	return fmt.Sprintf(`
 resource "aws_vpc" "test" {
   cidr_block = "10.1.0.0/16"
@@ -666,14 +911,6 @@ resource "aws_vpc" "test" {
   }
 }
 
-resource "aws_egress_only_internet_gateway" "test" {
-  vpc_id = aws_vpc.test.id
-
-  tags = {
-    Name = %[1]q
-  }
-}
-
 resource "aws_internet_gateway" "test" {
   vpc_id = aws_vpc.test.id
 
@@ -683,9 +920,9 @@ resource "aws_internet_gateway" "test" {
 }
 
 locals {
-  ipv6             = %[2]t
-  destination      = "0.0.0.0/0"
-  destination_ipv6 = "::/0"
+  ipv6             = %[4]t
+  destination      = %[2]q
+  destination_ipv6 = %[3]q
 }
 
 resource "aws_default_route_table" "test" {
@@ -701,7 +938,7 @@ resource "aws_default_route_table" "test" {
     Name = %[1]q
   }
 }
-`, rName, ipv6Route)
+`, rName, destinationCidr, destinationIpv6Cidr, ipv6Route)
 }
 
 func testAccAWSDefaultRouteTableImportStateIdFunc(resourceName string) resource.ImportStateIdFunc {
