@@ -190,6 +190,44 @@ func resourceAwsEc2Fleet() *schema.Resource {
 							Default:      1,
 							ValidateFunc: validation.IntAtLeast(1),
 						},
+						"maintenance_strategies": {
+							Type:     schema.TypeList,
+							Optional: true,
+							MaxItems: 1,
+							DiffSuppressFunc: func(k, old, new string, d *schema.ResourceData) bool {
+								if old == "1" && new == "0" {
+									return true
+								}
+								return false
+							},
+							Elem: &schema.Resource{
+								Schema: map[string]*schema.Schema{
+									"capacity_rebalance": {
+										Type:     schema.TypeList,
+										Optional: true,
+										MaxItems: 1,
+										DiffSuppressFunc: func(k, old, new string, d *schema.ResourceData) bool {
+											if old == "1" && new == "0" {
+												return true
+											}
+											return false
+										},
+										Elem: &schema.Resource{
+											Schema: map[string]*schema.Schema{
+												"replacement_strategy": {
+													Type:     schema.TypeString,
+													Optional: true,
+													ForceNew: true,
+													ValidateFunc: validation.StringInSlice([]string{
+														"launch",
+													}, false),
+												},
+											},
+										},
+									},
+								},
+							},
+						},
 					},
 				},
 			},
@@ -312,6 +350,14 @@ func resourceAwsEc2FleetCreate(d *schema.ResourceData, meta interface{}) error {
 		Type:                             aws.String(d.Get("type").(string)),
 	}
 
+	if d.Get("type").(string) != ec2.FleetTypeMaintain {
+		if input.SpotOptions.MaintenanceStrategies != nil {
+			log.Printf("[WARN] EC2 Fleet (%s) has an invalid configuration and can not be created. Capacity Rebalance maintenance strategies can only be specified for fleets of type maintain.", input)
+			d.SetId("")
+			return nil
+		}
+	}
+
 	log.Printf("[DEBUG] Creating EC2 Fleet: %s", input)
 	output, err := conn.CreateFleet(input)
 	if err != nil {
@@ -688,6 +734,7 @@ func expandEc2SpotOptionsRequest(l []interface{}) *ec2.SpotOptionsRequest {
 	spotOptionsRequest := &ec2.SpotOptionsRequest{
 		AllocationStrategy:           aws.String(m["allocation_strategy"].(string)),
 		InstanceInterruptionBehavior: aws.String(m["instance_interruption_behavior"].(string)),
+		MaintenanceStrategies:        expandFleetSpotMaintenanceStrategiesRequest(m["maintenance_strategies"].([]interface{})),
 	}
 
 	// InvalidFleetConfig: InstancePoolsToUseCount option is only available with the lowestPrice allocation strategy.
@@ -698,6 +745,36 @@ func expandEc2SpotOptionsRequest(l []interface{}) *ec2.SpotOptionsRequest {
 	return spotOptionsRequest
 }
 
+func expandFleetSpotMaintenanceStrategiesRequest(l []interface{}) *ec2.FleetSpotMaintenanceStrategiesRequest {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	m := l[0].(map[string]interface{})
+
+	fleetSpotMaintenanceStrategiesRequest := &ec2.FleetSpotMaintenanceStrategiesRequest{
+		CapacityRebalance: expandFleetSpotCapacityRebalanceRequest(m["capacity_rebalance"].([]interface{})),
+	}
+
+	return fleetSpotMaintenanceStrategiesRequest
+}
+
+func expandFleetSpotCapacityRebalanceRequest(l []interface{}) *ec2.FleetSpotCapacityRebalanceRequest {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	m := l[0].(map[string]interface{})
+
+	capacityRebalance := &ec2.FleetSpotCapacityRebalanceRequest{}
+
+	if v, ok := m["replacement_strategy"]; ok && v.(string) != "" {
+		capacityRebalance.ReplacementStrategy = aws.String(v.(string))
+	}
+
+	return capacityRebalance
+}
+
 func expandEc2TargetCapacitySpecificationRequest(l []interface{}) *ec2.TargetCapacitySpecificationRequest {
 	if len(l) == 0 || l[0] == nil {
 		return nil
@@ -799,6 +876,7 @@ func flattenEc2SpotOptions(spotOptions *ec2.SpotOptions) []interface{} {
 		"allocation_strategy":            aws.StringValue(spotOptions.AllocationStrategy),
 		"instance_interruption_behavior": aws.StringValue(spotOptions.InstanceInterruptionBehavior),
 		"instance_pools_to_use_count":    aws.Int64Value(spotOptions.InstancePoolsToUseCount),
+		"maintenance_strategies":         flattenFleetSpotMaintenanceStrategies(spotOptions.MaintenanceStrategies),
 	}
 
 	// API will omit InstancePoolsToUseCount if AllocationStrategy is diversified, which breaks our Default: 1
@@ -810,6 +888,30 @@ func flattenEc2SpotOptions(spotOptions *ec2.SpotOptions) []interface{} {
 	return []interface{}{m}
 }
 
+func flattenFleetSpotMaintenanceStrategies(fleetSpotMaintenanceStrategies *ec2.FleetSpotMaintenanceStrategies) []interface{} {
+	if fleetSpotMaintenanceStrategies == nil {
+		return []interface{}{}
+	}
+
+	m := map[string]interface{}{
+		"capacity_rebalance": flattenFleetSpotCapacityRebalance(fleetSpotMaintenanceStrategies.CapacityRebalance),
+	}
+
+	return []interface{}{m}
+}
+
+func flattenFleetSpotCapacityRebalance(fleetSpotCapacityRebalance *ec2.FleetSpotCapacityRebalance) []interface{} {
+	if fleetSpotCapacityRebalance == nil {
+		return []interface{}{}
+	}
+
+	m := map[string]interface{}{
+		"replacement_strategy": aws.StringValue(fleetSpotCapacityRebalance.ReplacementStrategy),
+	}
+
+	return []interface{}{m}
+}
+
 func flattenEc2TargetCapacitySpecification(targetCapacitySpecification *ec2.TargetCapacitySpecification) []interface{} {
 	if targetCapacitySpecification == nil {
 		return []interface{}{}
