@@ -11,7 +11,6 @@ import (
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/aws-sdk-go/service/elasticache"
 	gversion "github.com/hashicorp/go-version"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/customdiff"
@@ -19,6 +18,14 @@ import (
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/keyvaluetags"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/service/elasticache/finder"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/service/elasticache/waiter"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/tfresource"
+)
+
+const (
+	elasticacheDefaultRedisPort     = "6379"
+	elasticacheDefaultMemcachedPort = "11211"
 )
 
 func resourceAwsElasticacheCluster() *schema.Resource {
@@ -89,7 +96,7 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				Required: true,
 				ForceNew: true,
 				StateFunc: func(val interface{}) string {
-					// Elasticache normalizes cluster ids to lowercase,
+					// ElastiCache normalizes cluster ids to lowercase,
 					// so we have to do this too or else we can end up
 					// with non-converging diffs.
 					return strings.ToLower(val.(string))
@@ -122,7 +129,7 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				Optional: true,
 				Computed: true,
 				StateFunc: func(val interface{}) string {
-					// Elasticache always changes the maintenance
+					// ElastiCache always changes the maintenance
 					// to lowercase
 					return strings.ToLower(val.(string))
 				},
@@ -154,7 +161,7 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				ForceNew: true,
 				DiffSuppressFunc: func(k, old, new string, d *schema.ResourceData) bool {
 					// Suppress default memcached/redis ports when not defined
-					if !d.IsNewResource() && new == "0" && (old == "6379" || old == "11211") {
+					if !d.IsNewResource() && new == "0" && (old == elasticacheDefaultRedisPort || old == elasticacheDefaultMemcachedPort) {
 						return true
 					}
 					return false
@@ -204,18 +211,18 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				Elem:     &schema.Schema{Type: schema.TypeString},
 				Set:      schema.HashString,
 			},
-			// A single-element string list containing an Amazon Resource Name (ARN) that
-			// uniquely identifies a Redis RDB snapshot file stored in Amazon S3. The snapshot
-			// file will be used to populate the node group.
-			//
-			// See also:
-			// https://github.com/aws/aws-sdk-go/blob/4862a174f7fc92fb523fc39e68f00b87d91d2c3d/service/elasticache/api.go#L2079
 			"snapshot_arns": {
-				Type:     schema.TypeSet,
+				Type:     schema.TypeList,
 				Optional: true,
 				ForceNew: true,
-				Elem:     &schema.Schema{Type: schema.TypeString},
-				Set:      schema.HashString,
+				MaxItems: 1,
+				Elem: &schema.Schema{
+					Type: schema.TypeString,
+					ValidateFunc: validation.All(
+						validateArn,
+						validation.StringDoesNotContainAny(","),
+					),
+				},
 			},
 			"snapshot_retention_limit": {
 				Type:         schema.TypeInt,
@@ -239,6 +246,10 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				Computed: true,
 				ForceNew: true,
 			},
+			"final_snapshot_identifier": {
+				Type:     schema.TypeString,
+				Optional: true,
+			},
 			"tags": tagsSchema(),
 		},
 
@@ -289,7 +300,7 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 			func(_ context.Context, diff *schema.ResourceDiff, v interface{}) error {
 				// Engine memcached does not currently support vertical scaling
 				// InvalidParameterCombination: Scaling is not supported for engine memcached
-				// https://docs.aws.amazon.com/AmazonElastiCache/latest/UserGuide/Scaling.Memcached.html#Scaling.Memcached.Vertically
+				// https://docs.aws.amazon.com/AmazonElastiCache/latest/mem-ug/Scaling.html#Scaling.Memcached.Vertically
 				if diff.Id() == "" || !diff.HasChange("node_type") {
 					return nil
 				}
@@ -298,6 +309,15 @@ func resourceAwsElasticacheCluster() *schema.Resource {
 				}
 				return diff.ForceNew("node_type")
 			},
+			func(_ context.Context, diff *schema.ResourceDiff, v interface{}) error {
+				if v, ok := diff.GetOk("engine"); !ok || v.(string) == "redis" {
+					return nil
+				}
+				if _, ok := diff.GetOk("final_snapshot_identifier"); !ok {
+					return nil
+				}
+				return errors.New(`engine "memcached" does not support final_snapshot_identifier`)
+			},
 		),
 	}
 }
@@ -310,15 +330,9 @@ func resourceAwsElasticacheClusterCreate(d *schema.ResourceData, meta interface{
 	if v, ok := d.GetOk("replication_group_id"); ok {
 		req.ReplicationGroupId = aws.String(v.(string))
 	} else {
-		securityNameSet := d.Get("security_group_names").(*schema.Set)
-		securityIdSet := d.Get("security_group_ids").(*schema.Set)
-		securityNames := expandStringList(securityNameSet.List())
-		securityIds := expandStringList(securityIdSet.List())
-		tags := keyvaluetags.New(d.Get("tags").(map[string]interface{})).IgnoreAws().ElasticacheTags()
-
-		req.CacheSecurityGroupNames = securityNames
-		req.SecurityGroupIds = securityIds
-		req.Tags = tags
+		req.CacheSecurityGroupNames = expandStringSet(d.Get("security_group_names").(*schema.Set))
+		req.SecurityGroupIds = expandStringSet(d.Get("security_group_ids").(*schema.Set))
+		req.Tags = keyvaluetags.New(d.Get("tags").(map[string]interface{})).IgnoreAws().ElasticacheTags()
 	}
 
 	if v, ok := d.GetOk("cluster_id"); ok {
@@ -370,11 +384,10 @@ func resourceAwsElasticacheClusterCreate(d *schema.ResourceData, meta interface{
 		req.NotificationTopicArn = aws.String(v.(string))
 	}
 
-	snaps := d.Get("snapshot_arns").(*schema.Set).List()
+	snaps := d.Get("snapshot_arns").([]interface{})
 	if len(snaps) > 0 {
-		s := expandStringList(snaps)
-		req.SnapshotArns = s
-		log.Printf("[DEBUG] Restoring Redis cluster from S3 snapshot: %#v", s)
+		req.SnapshotArns = expandStringList(snaps)
+		log.Printf("[DEBUG] Restoring Redis cluster from S3 snapshot: %#v", snaps)
 	}
 
 	if v, ok := d.GetOk("snapshot_name"); ok {
@@ -395,14 +408,14 @@ func resourceAwsElasticacheClusterCreate(d *schema.ResourceData, meta interface{
 
 	id, err := createElasticacheCacheCluster(conn, req)
 	if err != nil {
-		return fmt.Errorf("error creating Elasticache Cache Cluster: %s", err)
+		return fmt.Errorf("error creating ElastiCache Cache Cluster: %w", err)
 	}
 
 	d.SetId(id)
 
-	err = waitForCreateElasticacheCacheCluster(conn, d.Id(), 40*time.Minute)
+	_, err = waiter.CacheClusterAvailable(conn, d.Id(), 40*time.Minute)
 	if err != nil {
-		return fmt.Errorf("error waiting for Elasticache Cache Cluster (%s) to be created: %s", d.Id(), err)
+		return fmt.Errorf("error waiting for ElastiCache Cache Cluster (%s) to be created: %w", d.Id(), err)
 	}
 
 	return resourceAwsElasticacheClusterRead(d, meta)
@@ -412,85 +425,68 @@ func resourceAwsElasticacheClusterRead(d *schema.ResourceData, meta interface{})
 	conn := meta.(*AWSClient).elasticacheconn
 	ignoreTagsConfig := meta.(*AWSClient).IgnoreTagsConfig
 
-	req := &elasticache.DescribeCacheClustersInput{
-		CacheClusterId:    aws.String(d.Id()),
-		ShowCacheNodeInfo: aws.Bool(true),
+	c, err := finder.CacheClusterWithNodeInfoByID(conn, d.Id())
+	if !d.IsNewResource() && tfresource.NotFound(err) {
+		log.Printf("[WARN] ElastiCache Cache Cluster (%s) not found, removing from state", d.Id())
+		d.SetId("")
+		return nil
+	}
+	if err != nil {
+		return fmt.Errorf("error reading ElastiCache Cache Cluster (%s): %w", d.Id(), err)
 	}
 
-	res, err := conn.DescribeCacheClusters(req)
-	if err != nil {
-		if isAWSErr(err, elasticache.ErrCodeCacheClusterNotFoundFault, "") {
-			log.Printf("[WARN] ElastiCache Cluster (%s) not found", d.Id())
-			d.SetId("")
-			return nil
-		}
+	d.Set("cluster_id", c.CacheClusterId)
+	d.Set("node_type", c.CacheNodeType)
+	d.Set("num_cache_nodes", c.NumCacheNodes)
+	d.Set("engine", c.Engine)
+	d.Set("engine_version", c.EngineVersion)
+	if c.ConfigurationEndpoint != nil {
+		d.Set("port", c.ConfigurationEndpoint.Port)
+		d.Set("configuration_endpoint", aws.String(fmt.Sprintf("%s:%d", aws.StringValue(c.ConfigurationEndpoint.Address), aws.Int64Value(c.ConfigurationEndpoint.Port))))
+		d.Set("cluster_address", c.ConfigurationEndpoint.Address)
+	} else if len(c.CacheNodes) > 0 {
+		d.Set("port", int(aws.Int64Value(c.CacheNodes[0].Endpoint.Port)))
+	}
 
+	if c.ReplicationGroupId != nil {
+		d.Set("replication_group_id", c.ReplicationGroupId)
+	}
+
+	d.Set("subnet_group_name", c.CacheSubnetGroupName)
+	d.Set("security_group_names", flattenElastiCacheSecurityGroupNames(c.CacheSecurityGroups))
+	d.Set("security_group_ids", flattenElastiCacheSecurityGroupIds(c.SecurityGroups))
+	if c.CacheParameterGroup != nil {
+		d.Set("parameter_group_name", c.CacheParameterGroup.CacheParameterGroupName)
+	}
+	d.Set("maintenance_window", c.PreferredMaintenanceWindow)
+	d.Set("snapshot_window", c.SnapshotWindow)
+	d.Set("snapshot_retention_limit", c.SnapshotRetentionLimit)
+	if c.NotificationConfiguration != nil {
+		if *c.NotificationConfiguration.TopicStatus == "active" {
+			d.Set("notification_topic_arn", c.NotificationConfiguration.TopicArn)
+		}
+	}
+	d.Set("availability_zone", c.PreferredAvailabilityZone)
+	if aws.StringValue(c.PreferredAvailabilityZone) == "Multiple" {
+		d.Set("az_mode", "cross-az")
+	} else {
+		d.Set("az_mode", "single-az")
+	}
+
+	if err := setCacheNodeData(d, c); err != nil {
 		return err
 	}
 
-	if len(res.CacheClusters) == 1 {
-		c := res.CacheClusters[0]
-		d.Set("cluster_id", c.CacheClusterId)
-		d.Set("node_type", c.CacheNodeType)
-		d.Set("num_cache_nodes", c.NumCacheNodes)
-		d.Set("engine", c.Engine)
-		d.Set("engine_version", c.EngineVersion)
-		if c.ConfigurationEndpoint != nil {
-			d.Set("port", c.ConfigurationEndpoint.Port)
-			d.Set("configuration_endpoint", aws.String(fmt.Sprintf("%s:%d", *c.ConfigurationEndpoint.Address, *c.ConfigurationEndpoint.Port)))
-			d.Set("cluster_address", aws.String((*c.ConfigurationEndpoint.Address)))
-		} else if len(c.CacheNodes) > 0 {
-			d.Set("port", int(aws.Int64Value(c.CacheNodes[0].Endpoint.Port)))
-		}
+	d.Set("arn", c.ARN)
 
-		if c.ReplicationGroupId != nil {
-			d.Set("replication_group_id", c.ReplicationGroupId)
-		}
+	tags, err := keyvaluetags.ElasticacheListTags(conn, aws.StringValue(c.ARN))
 
-		d.Set("subnet_group_name", c.CacheSubnetGroupName)
-		d.Set("security_group_names", flattenElastiCacheSecurityGroupNames(c.CacheSecurityGroups))
-		d.Set("security_group_ids", flattenElastiCacheSecurityGroupIds(c.SecurityGroups))
-		if c.CacheParameterGroup != nil {
-			d.Set("parameter_group_name", c.CacheParameterGroup.CacheParameterGroupName)
-		}
-		d.Set("maintenance_window", c.PreferredMaintenanceWindow)
-		d.Set("snapshot_window", c.SnapshotWindow)
-		d.Set("snapshot_retention_limit", c.SnapshotRetentionLimit)
-		if c.NotificationConfiguration != nil {
-			if *c.NotificationConfiguration.TopicStatus == "active" {
-				d.Set("notification_topic_arn", c.NotificationConfiguration.TopicArn)
-			}
-		}
-		d.Set("availability_zone", c.PreferredAvailabilityZone)
-		if *c.PreferredAvailabilityZone == "Multiple" {
-			d.Set("az_mode", "cross-az")
-		} else {
-			d.Set("az_mode", "single-az")
-		}
+	if err != nil {
+		return fmt.Errorf("error listing tags for ElastiCache Cluster (%s): %w", d.Id(), err)
+	}
 
-		if err := setCacheNodeData(d, c); err != nil {
-			return err
-		}
-
-		arn := arn.ARN{
-			Partition: meta.(*AWSClient).partition,
-			Service:   "elasticache",
-			Region:    meta.(*AWSClient).region,
-			AccountID: meta.(*AWSClient).accountid,
-			Resource:  fmt.Sprintf("cluster:%s", d.Id()),
-		}.String()
-
-		d.Set("arn", arn)
-
-		tags, err := keyvaluetags.ElasticacheListTags(conn, arn)
-
-		if err != nil {
-			return fmt.Errorf("error listing tags for Elasticache Cluster (%s): %s", arn, err)
-		}
-
-		if err := d.Set("tags", tags.IgnoreAws().IgnoreConfig(ignoreTagsConfig).Map()); err != nil {
-			return fmt.Errorf("error setting tags: %s", err)
-		}
+	if err := d.Set("tags", tags.IgnoreAws().IgnoreConfig(ignoreTagsConfig).Map()); err != nil {
+		return fmt.Errorf("error setting tags: %w", err)
 	}
 
 	return nil
@@ -503,7 +499,7 @@ func resourceAwsElasticacheClusterUpdate(d *schema.ResourceData, meta interface{
 		o, n := d.GetChange("tags")
 
 		if err := keyvaluetags.ElasticacheUpdateTags(conn, d.Get("arn").(string), o, n); err != nil {
-			return fmt.Errorf("error updating Elasticache Cluster (%s) tags: %s", d.Get("arn").(string), err)
+			return fmt.Errorf("error updating ElastiCache Cluster (%s) tags: %w", d.Get("arn").(string), err)
 		}
 	}
 
@@ -515,7 +511,7 @@ func resourceAwsElasticacheClusterUpdate(d *schema.ResourceData, meta interface{
 	requestUpdate := false
 	if d.HasChange("security_group_ids") {
 		if attr := d.Get("security_group_ids").(*schema.Set); attr.Len() > 0 {
-			req.SecurityGroupIds = expandStringList(attr.List())
+			req.SecurityGroupIds = expandStringSet(attr)
 			requestUpdate = true
 		}
 	}
@@ -600,23 +596,12 @@ func resourceAwsElasticacheClusterUpdate(d *schema.ResourceData, meta interface{
 		log.Printf("[DEBUG] Modifying ElastiCache Cluster (%s), opts:\n%s", d.Id(), req)
 		_, err := conn.ModifyCacheCluster(req)
 		if err != nil {
-			return fmt.Errorf("Error updating ElastiCache cluster (%s), error: %s", d.Id(), err)
+			return fmt.Errorf("Error updating ElastiCache cluster (%s), error: %w", d.Id(), err)
 		}
 
-		log.Printf("[DEBUG] Waiting for update: %s", d.Id())
-		pending := []string{"modifying", "rebooting cache cluster nodes", "snapshotting"}
-		stateConf := &resource.StateChangeConf{
-			Pending:    pending,
-			Target:     []string{"available"},
-			Refresh:    cacheClusterStateRefreshFunc(conn, d.Id(), "available", pending),
-			Timeout:    80 * time.Minute,
-			MinTimeout: 10 * time.Second,
-			Delay:      30 * time.Second,
-		}
-
-		_, sterr := stateConf.WaitForState()
-		if sterr != nil {
-			return fmt.Errorf("Error waiting for elasticache (%s) to update: %s", d.Id(), sterr)
+		_, err = waiter.CacheClusterAvailable(conn, d.Id(), waiter.CacheClusterUpdatedTimeout)
+		if err != nil {
+			return fmt.Errorf("error waiting for ElastiCache Cache Cluster (%s) to update: %w", d.Id(), err)
 		}
 	}
 
@@ -667,94 +652,24 @@ func (b byCacheNodeId) Less(i, j int) bool {
 func resourceAwsElasticacheClusterDelete(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).elasticacheconn
 
-	err := deleteElasticacheCacheCluster(conn, d.Id())
+	var finalSnapshotID = d.Get("final_snapshot_identifier").(string)
+	err := deleteElasticacheCacheCluster(conn, d.Id(), finalSnapshotID)
 	if err != nil {
 		if isAWSErr(err, elasticache.ErrCodeCacheClusterNotFoundFault, "") {
 			return nil
 		}
-		return fmt.Errorf("error deleting Elasticache Cache Cluster (%s): %s", d.Id(), err)
+		return fmt.Errorf("error deleting ElastiCache Cache Cluster (%s): %w", d.Id(), err)
 	}
-	err = waitForDeleteElasticacheCacheCluster(conn, d.Id(), 40*time.Minute)
+	_, err = waiter.CacheClusterDeleted(conn, d.Id(), waiter.CacheClusterDeletedTimeout)
 	if err != nil {
-		return fmt.Errorf("error waiting for Elasticache Cache Cluster (%s) to be deleted: %s", d.Id(), err)
+		return fmt.Errorf("error waiting for ElastiCache Cache Cluster (%s) to be deleted: %w", d.Id(), err)
 	}
 
 	return nil
 }
 
-func cacheClusterStateRefreshFunc(conn *elasticache.ElastiCache, clusterID, givenState string, pending []string) resource.StateRefreshFunc {
-	return func() (interface{}, string, error) {
-		resp, err := conn.DescribeCacheClusters(&elasticache.DescribeCacheClustersInput{
-			CacheClusterId:    aws.String(clusterID),
-			ShowCacheNodeInfo: aws.Bool(true),
-		})
-		if err != nil {
-			if isAWSErr(err, elasticache.ErrCodeCacheClusterNotFoundFault, "") {
-				log.Printf("[DEBUG] Detect deletion")
-				return nil, "", nil
-			}
-
-			log.Printf("[ERROR] CacheClusterStateRefreshFunc: %s", err)
-			return nil, "", err
-		}
-
-		if len(resp.CacheClusters) == 0 {
-			return nil, "", fmt.Errorf("Error: no Cache Clusters found for id (%s)", clusterID)
-		}
-
-		var c *elasticache.CacheCluster
-		for _, cluster := range resp.CacheClusters {
-			if *cluster.CacheClusterId == clusterID {
-				log.Printf("[DEBUG] Found matching ElastiCache cluster: %s", *cluster.CacheClusterId)
-				c = cluster
-			}
-		}
-
-		if c == nil {
-			return nil, "", fmt.Errorf("Error: no matching Elastic Cache cluster for id (%s)", clusterID)
-		}
-
-		log.Printf("[DEBUG] ElastiCache Cluster (%s) status: %v", clusterID, *c.CacheClusterStatus)
-
-		// return the current state if it's in the pending array
-		for _, p := range pending {
-			log.Printf("[DEBUG] ElastiCache: checking pending state (%s) for cluster (%s), cluster status: %s", pending, clusterID, *c.CacheClusterStatus)
-			s := *c.CacheClusterStatus
-			if p == s {
-				log.Printf("[DEBUG] Return with status: %v", *c.CacheClusterStatus)
-				return c, p, nil
-			}
-		}
-
-		// return given state if it's not in pending
-		if givenState != "" {
-			log.Printf("[DEBUG] ElastiCache: checking given state (%s) of cluster (%s) against cluster status (%s)", givenState, clusterID, *c.CacheClusterStatus)
-			// check to make sure we have the node count we're expecting
-			if int64(len(c.CacheNodes)) != *c.NumCacheNodes {
-				log.Printf("[DEBUG] Node count is not what is expected: %d found, %d expected", len(c.CacheNodes), *c.NumCacheNodes)
-				return nil, "creating", nil
-			}
-
-			log.Printf("[DEBUG] Node count matched (%d)", len(c.CacheNodes))
-			// loop the nodes and check their status as well
-			for _, n := range c.CacheNodes {
-				log.Printf("[DEBUG] Checking cache node for status: %s", n)
-				if n.CacheNodeStatus != nil && *n.CacheNodeStatus != "available" {
-					log.Printf("[DEBUG] Node (%s) is not yet available, status: %s", *n.CacheNodeId, *n.CacheNodeStatus)
-					return nil, "creating", nil
-				}
-				log.Printf("[DEBUG] Cache node not in expected state")
-			}
-			log.Printf("[DEBUG] ElastiCache returning given state (%s), cluster: %s", givenState, c)
-			return c, givenState, nil
-		}
-		log.Printf("[DEBUG] current status: %v", *c.CacheClusterStatus)
-		return c, *c.CacheClusterStatus, nil
-	}
-}
-
 func createElasticacheCacheCluster(conn *elasticache.ElastiCache, input *elasticache.CreateCacheClusterInput) (string, error) {
-	log.Printf("[DEBUG] Creating Elasticache Cache Cluster: %s", input)
+	log.Printf("[DEBUG] Creating ElastiCache Cache Cluster: %s", input)
 	output, err := conn.CreateCacheCluster(input)
 	if err != nil {
 		return "", err
@@ -768,27 +683,15 @@ func createElasticacheCacheCluster(conn *elasticache.ElastiCache, input *elastic
 	return strings.ToLower(aws.StringValue(output.CacheCluster.CacheClusterId)), nil
 }
 
-func waitForCreateElasticacheCacheCluster(conn *elasticache.ElastiCache, cacheClusterID string, timeout time.Duration) error {
-	pending := []string{"creating", "modifying", "restoring", "snapshotting"}
-	stateConf := &resource.StateChangeConf{
-		Pending:    pending,
-		Target:     []string{"available"},
-		Refresh:    cacheClusterStateRefreshFunc(conn, cacheClusterID, "available", pending),
-		Timeout:    timeout,
-		MinTimeout: 10 * time.Second,
-		Delay:      30 * time.Second,
-	}
-
-	log.Printf("[DEBUG] Waiting for Elasticache Cache Cluster (%s) to be created", cacheClusterID)
-	_, err := stateConf.WaitForState()
-	return err
-}
-
-func deleteElasticacheCacheCluster(conn *elasticache.ElastiCache, cacheClusterID string) error {
+func deleteElasticacheCacheCluster(conn *elasticache.ElastiCache, cacheClusterID string, finalSnapshotID string) error {
 	input := &elasticache.DeleteCacheClusterInput{
 		CacheClusterId: aws.String(cacheClusterID),
 	}
-	log.Printf("[DEBUG] Deleting Elasticache Cache Cluster: %s", input)
+	if finalSnapshotID != "" {
+		input.FinalSnapshotIdentifier = aws.String(finalSnapshotID)
+	}
+
+	log.Printf("[DEBUG] Deleting ElastiCache Cache Cluster: %s", input)
 	err := resource.Retry(5*time.Minute, func() *resource.RetryError {
 		_, err := conn.DeleteCacheCluster(input)
 		if err != nil {
@@ -810,18 +713,3 @@ func deleteElasticacheCacheCluster(conn *elasticache.ElastiCache, cacheClusterID
 
 	return err
 }
-
-func waitForDeleteElasticacheCacheCluster(conn *elasticache.ElastiCache, cacheClusterID string, timeout time.Duration) error {
-	stateConf := &resource.StateChangeConf{
-		Pending:    []string{"creating", "available", "deleting", "incompatible-parameters", "incompatible-network", "restore-failed", "snapshotting"},
-		Target:     []string{},
-		Refresh:    cacheClusterStateRefreshFunc(conn, cacheClusterID, "", []string{}),
-		Timeout:    timeout,
-		MinTimeout: 10 * time.Second,
-		Delay:      30 * time.Second,
-	}
-	log.Printf("[DEBUG] Waiting for Elasticache Cache Cluster deletion: %v", cacheClusterID)
-
-	_, err := stateConf.WaitForState()
-	return err
-}
