@@ -2,6 +2,7 @@ package aws
 
 import (
 	"fmt"
+	"reflect"
 	"testing"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -9,13 +10,13 @@ import (
 	"github.com/aws/aws-sdk-go/service/elasticache"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/acctest"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/terraform"
-	"github.com/terraform-providers/terraform-provider-aws/aws/internal/tfawsresource"
 )
 
 func TestAccAWSElasticacheParameterGroup_basic(t *testing.T) {
 	var v elasticache.CacheParameterGroup
-	resourceName := "aws_elasticache_parameter_group.bar"
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -44,6 +45,7 @@ func TestAccAWSElasticacheParameterGroup_basic(t *testing.T) {
 
 func TestAccAWSElasticacheParameterGroup_addParameter(t *testing.T) {
 	var v elasticache.CacheParameterGroup
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -54,29 +56,29 @@ func TestAccAWSElasticacheParameterGroup_addParameter(t *testing.T) {
 			{
 				Config: testAccAWSElasticacheParameterGroupConfigParameter1(rName, "redis2.8", "appendonly", "yes"),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSElasticacheParameterGroupExists("aws_elasticache_parameter_group.bar", &v),
-					resource.TestCheckResourceAttr("aws_elasticache_parameter_group.bar", "parameter.#", "1"),
-					tfawsresource.TestCheckTypeSetElemNestedAttrs("aws_elasticache_parameter_group.bar", "parameter.*", map[string]string{
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &v),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
 						"name":  "appendonly",
 						"value": "yes",
 					}),
 				),
 			},
 			{
-				ResourceName:      "aws_elasticache_parameter_group.bar",
+				ResourceName:      resourceName,
 				ImportState:       true,
 				ImportStateVerify: true,
 			},
 			{
 				Config: testAccAWSElasticacheParameterGroupConfigParameter2(rName, "redis2.8", "appendonly", "yes", "appendfsync", "always"),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSElasticacheParameterGroupExists("aws_elasticache_parameter_group.bar", &v),
-					resource.TestCheckResourceAttr("aws_elasticache_parameter_group.bar", "parameter.#", "2"),
-					tfawsresource.TestCheckTypeSetElemNestedAttrs("aws_elasticache_parameter_group.bar", "parameter.*", map[string]string{
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &v),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "2"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
 						"name":  "appendonly",
 						"value": "yes",
 					}),
-					tfawsresource.TestCheckTypeSetElemNestedAttrs("aws_elasticache_parameter_group.bar", "parameter.*", map[string]string{
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
 						"name":  "appendfsync",
 						"value": "always",
 					}),
@@ -86,9 +88,10 @@ func TestAccAWSElasticacheParameterGroup_addParameter(t *testing.T) {
 	})
 }
 
-// Regression for https://github.com/terraform-providers/terraform-provider-aws/issues/116
+// Regression for https://github.com/hashicorp/terraform-provider-aws/issues/116
 func TestAccAWSElasticacheParameterGroup_removeAllParameters(t *testing.T) {
 	var v elasticache.CacheParameterGroup
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -99,26 +102,34 @@ func TestAccAWSElasticacheParameterGroup_removeAllParameters(t *testing.T) {
 			{
 				Config: testAccAWSElasticacheParameterGroupConfigParameter2(rName, "redis2.8", "appendonly", "yes", "appendfsync", "always"),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSElasticacheParameterGroupExists("aws_elasticache_parameter_group.bar", &v),
-					resource.TestCheckResourceAttr("aws_elasticache_parameter_group.bar", "parameter.#", "2"),
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &v),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "2"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "appendonly",
+						"value": "yes",
+					}),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "appendfsync",
+						"value": "always",
+					}),
 				),
 			},
 			{
 				Config: testAccAWSElasticacheParameterGroupConfig(rName),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSElasticacheParameterGroupExists("aws_elasticache_parameter_group.bar", &v),
-					resource.TestCheckResourceAttr("aws_elasticache_parameter_group.bar", "parameter.#", "0"),
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &v),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "0"),
 				),
 			},
 		},
 	})
 }
 
-// The API throws 500 errors when attempting to reset the reserved-memory parameter.
+// The API returns errors when attempting to reset the reserved-memory parameter.
 // This covers our custom logic handling for this situation.
-func TestAccAWSElasticacheParameterGroup_removeReservedMemoryParameter(t *testing.T) {
+func TestAccAWSElasticacheParameterGroup_removeReservedMemoryParameter_AllParameters(t *testing.T) {
 	var cacheParameterGroup1 elasticache.CacheParameterGroup
-	resourceName := "aws_elasticache_parameter_group.bar"
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -131,6 +142,10 @@ func TestAccAWSElasticacheParameterGroup_removeReservedMemoryParameter(t *testin
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
 					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory",
+						"value": "0",
+					}),
 				),
 			},
 			{
@@ -149,11 +164,58 @@ func TestAccAWSElasticacheParameterGroup_removeReservedMemoryParameter(t *testin
 	})
 }
 
-// The API throws 500 errors when attempting to reset the reserved-memory parameter.
+// The API returns errors when attempting to reset the reserved-memory parameter.
+// This covers our custom logic handling for this situation.
+func TestAccAWSElasticacheParameterGroup_removeReservedMemoryParameter_RemainingParameters(t *testing.T) {
+	var cacheParameterGroup1 elasticache.CacheParameterGroup
+	resourceName := "aws_elasticache_parameter_group.test"
+	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSElasticacheParameterGroupDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSElasticacheParameterGroupConfigParameter2(rName, "redis3.2", "reserved-memory", "0", "tcp-keepalive", "360"),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "2"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory",
+						"value": "0",
+					}),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "tcp-keepalive",
+						"value": "360",
+					}),
+				),
+			},
+			{
+				Config: testAccAWSElasticacheParameterGroupConfigParameter1(rName, "redis3.2", "tcp-keepalive", "360"),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
+					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "tcp-keepalive",
+						"value": "360",
+					}),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
+// The API returns errors when attempting to reset the reserved-memory parameter.
 // This covers our custom logic handling for this situation.
 func TestAccAWSElasticacheParameterGroup_switchReservedMemoryParameter(t *testing.T) {
 	var cacheParameterGroup1 elasticache.CacheParameterGroup
-	resourceName := "aws_elasticache_parameter_group.bar"
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -166,6 +228,10 @@ func TestAccAWSElasticacheParameterGroup_switchReservedMemoryParameter(t *testin
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
 					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory",
+						"value": "0",
+					}),
 				),
 			},
 			{
@@ -173,6 +239,10 @@ func TestAccAWSElasticacheParameterGroup_switchReservedMemoryParameter(t *testin
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
 					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory-percent",
+						"value": "25",
+					}),
 				),
 			},
 			{
@@ -184,11 +254,11 @@ func TestAccAWSElasticacheParameterGroup_switchReservedMemoryParameter(t *testin
 	})
 }
 
-// The API throws 500 errors when attempting to reset the reserved-memory parameter.
+// The API returns errors when attempting to reset the reserved-memory parameter.
 // This covers our custom logic handling for this situation.
 func TestAccAWSElasticacheParameterGroup_updateReservedMemoryParameter(t *testing.T) {
 	var cacheParameterGroup1 elasticache.CacheParameterGroup
-	resourceName := "aws_elasticache_parameter_group.bar"
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -201,6 +271,10 @@ func TestAccAWSElasticacheParameterGroup_updateReservedMemoryParameter(t *testin
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
 					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory",
+						"value": "0",
+					}),
 				),
 			},
 			{
@@ -208,6 +282,10 @@ func TestAccAWSElasticacheParameterGroup_updateReservedMemoryParameter(t *testin
 				Check: resource.ComposeTestCheckFunc(
 					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &cacheParameterGroup1),
 					resource.TestCheckResourceAttr(resourceName, "parameter.#", "1"),
+					resource.TestCheckTypeSetElemNestedAttrs(resourceName, "parameter.*", map[string]string{
+						"name":  "reserved-memory",
+						"value": "1",
+					}),
 				),
 			},
 			{
@@ -221,6 +299,7 @@ func TestAccAWSElasticacheParameterGroup_updateReservedMemoryParameter(t *testin
 
 func TestAccAWSElasticacheParameterGroup_UppercaseName(t *testing.T) {
 	var v elasticache.CacheParameterGroup
+	resourceName := "aws_elasticache_parameter_group.test"
 	rInt := acctest.RandInt()
 	rName := fmt.Sprintf("TF-ELASTIPG-%d", rInt)
 
@@ -232,13 +311,12 @@ func TestAccAWSElasticacheParameterGroup_UppercaseName(t *testing.T) {
 			{
 				Config: testAccAWSElasticacheParameterGroupConfigParameter1(rName, "redis2.8", "appendonly", "yes"),
 				Check: resource.ComposeTestCheckFunc(
-					testAccCheckAWSElasticacheParameterGroupExists("aws_elasticache_parameter_group.bar", &v),
-					resource.TestCheckResourceAttr(
-						"aws_elasticache_parameter_group.bar", "name", fmt.Sprintf("tf-elastipg-%d", rInt)),
+					testAccCheckAWSElasticacheParameterGroupExists(resourceName, &v),
+					resource.TestCheckResourceAttr(resourceName, "name", fmt.Sprintf("tf-elastipg-%d", rInt)),
 				),
 			},
 			{
-				ResourceName:      "aws_elasticache_parameter_group.bar",
+				ResourceName:      resourceName,
 				ImportState:       true,
 				ImportStateVerify: true,
 			},
@@ -248,7 +326,7 @@ func TestAccAWSElasticacheParameterGroup_UppercaseName(t *testing.T) {
 
 func TestAccAWSElasticacheParameterGroup_Description(t *testing.T) {
 	var v elasticache.CacheParameterGroup
-	resourceName := "aws_elasticache_parameter_group.bar"
+	resourceName := "aws_elasticache_parameter_group.test"
 	rName := fmt.Sprintf("parameter-group-test-terraform-%d", acctest.RandInt())
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -357,7 +435,7 @@ func testAccCheckAWSElasticacheParameterGroupExists(n string, v *elasticache.Cac
 
 func testAccAWSElasticacheParameterGroupConfig(rName string) string {
 	return fmt.Sprintf(`
-resource "aws_elasticache_parameter_group" "bar" {
+resource "aws_elasticache_parameter_group" "test" {
   family = "redis2.8"
   name   = %q
 }
@@ -366,7 +444,7 @@ resource "aws_elasticache_parameter_group" "bar" {
 
 func testAccAWSElasticacheParameterGroupConfigDescription(rName, description string) string {
 	return fmt.Sprintf(`
-resource "aws_elasticache_parameter_group" "bar" {
+resource "aws_elasticache_parameter_group" "test" {
   description = %q
   family      = "redis2.8"
   name        = %q
@@ -376,7 +454,7 @@ resource "aws_elasticache_parameter_group" "bar" {
 
 func testAccAWSElasticacheParameterGroupConfigParameter1(rName, family, parameterName1, parameterValue1 string) string {
 	return fmt.Sprintf(`
-resource "aws_elasticache_parameter_group" "bar" {
+resource "aws_elasticache_parameter_group" "test" {
   family = %q
   name   = %q
 
@@ -390,7 +468,7 @@ resource "aws_elasticache_parameter_group" "bar" {
 
 func testAccAWSElasticacheParameterGroupConfigParameter2(rName, family, parameterName1, parameterValue1, parameterName2, parameterValue2 string) string {
 	return fmt.Sprintf(`
-resource "aws_elasticache_parameter_group" "bar" {
+resource "aws_elasticache_parameter_group" "test" {
   family = %q
   name   = %q
 
@@ -406,3 +484,169 @@ resource "aws_elasticache_parameter_group" "bar" {
 }
 `, family, rName, parameterName1, parameterValue1, parameterName2, parameterValue2)
 }
+
+func TestFlattenElasticacheParameters(t *testing.T) {
+	cases := []struct {
+		Input  []*elasticache.Parameter
+		Output []map[string]interface{}
+	}{
+		{
+			Input: []*elasticache.Parameter{
+				{
+					ParameterName:  aws.String("activerehashing"),
+					ParameterValue: aws.String("yes"),
+				},
+			},
+			Output: []map[string]interface{}{
+				{
+					"name":  "activerehashing",
+					"value": "yes",
+				},
+			},
+		},
+	}
+
+	for _, tc := range cases {
+		output := flattenElastiCacheParameters(tc.Input)
+		if !reflect.DeepEqual(output, tc.Output) {
+			t.Fatalf("Got:\n\n%#v\n\nExpected:\n\n%#v", output, tc.Output)
+		}
+	}
+}
+
+func TestExpandElasticacheParameters(t *testing.T) {
+	expanded := []interface{}{
+		map[string]interface{}{
+			"name":         "activerehashing",
+			"value":        "yes",
+			"apply_method": "immediate",
+		},
+	}
+	parameters := expandElastiCacheParameters(expanded)
+
+	expected := &elasticache.ParameterNameValue{
+		ParameterName:  aws.String("activerehashing"),
+		ParameterValue: aws.String("yes"),
+	}
+
+	if !reflect.DeepEqual(parameters[0], expected) {
+		t.Fatalf(
+			"Got:\n\n%#v\n\nExpected:\n\n%#v\n",
+			parameters[0],
+			expected)
+	}
+}
+
+func TestElastiCacheParameterChanges(t *testing.T) {
+	cases := []struct {
+		Name                string
+		Old                 *schema.Set
+		New                 *schema.Set
+		ExpectedRemove      []*elasticache.ParameterNameValue
+		ExpectedAddOrUpdate []*elasticache.ParameterNameValue
+	}{
+		{
+			Name:                "Empty",
+			Old:                 new(schema.Set),
+			New:                 new(schema.Set),
+			ExpectedRemove:      []*elasticache.ParameterNameValue{},
+			ExpectedAddOrUpdate: []*elasticache.ParameterNameValue{},
+		},
+		{
+			Name: "Remove all",
+			Old: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "reserved-memory",
+					"value": "0",
+				},
+			}),
+			New: new(schema.Set),
+			ExpectedRemove: []*elasticache.ParameterNameValue{
+				{
+					ParameterName:  aws.String("reserved-memory"),
+					ParameterValue: aws.String("0"),
+				},
+			},
+			ExpectedAddOrUpdate: []*elasticache.ParameterNameValue{},
+		},
+		{
+			Name: "No change",
+			Old: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "reserved-memory",
+					"value": "0",
+				},
+			}),
+			New: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "reserved-memory",
+					"value": "0",
+				},
+			}),
+			ExpectedRemove:      []*elasticache.ParameterNameValue{},
+			ExpectedAddOrUpdate: []*elasticache.ParameterNameValue{},
+		},
+		{
+			Name: "Remove partial",
+			Old: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "reserved-memory",
+					"value": "0",
+				},
+				map[string]interface{}{
+					"name":  "appendonly",
+					"value": "yes",
+				},
+			}),
+			New: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "appendonly",
+					"value": "yes",
+				},
+			}),
+			ExpectedRemove: []*elasticache.ParameterNameValue{
+				{
+					ParameterName:  aws.String("reserved-memory"),
+					ParameterValue: aws.String("0"),
+				},
+			},
+			ExpectedAddOrUpdate: []*elasticache.ParameterNameValue{},
+		},
+		{
+			Name: "Add to existing",
+			Old: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "appendonly",
+					"value": "yes",
+				},
+			}),
+			New: schema.NewSet(resourceAwsElasticacheParameterHash, []interface{}{
+				map[string]interface{}{
+					"name":  "appendonly",
+					"value": "yes",
+				},
+				map[string]interface{}{
+					"name":  "appendfsync",
+					"value": "always",
+				},
+			}),
+			ExpectedRemove: []*elasticache.ParameterNameValue{},
+			ExpectedAddOrUpdate: []*elasticache.ParameterNameValue{
+				{
+					ParameterName:  aws.String("appendfsync"),
+					ParameterValue: aws.String("always"),
+				},
+			},
+		},
+	}
+
+	for _, tc := range cases {
+		remove, addOrUpdate := elastiCacheParameterChanges(tc.Old, tc.New)
+		if !reflect.DeepEqual(remove, tc.ExpectedRemove) {
+			t.Errorf("Case %q: Remove did not match\n%#v\n\nGot:\n%#v", tc.Name, tc.ExpectedRemove, remove)
+		}
+		if !reflect.DeepEqual(addOrUpdate, tc.ExpectedAddOrUpdate) {
+			t.Errorf("Case %q: AddOrUpdate did not match\n%#v\n\nGot:\n%#v", tc.Name, tc.ExpectedAddOrUpdate, addOrUpdate)
+		}
+	}
+}
