@@ -3,12 +3,15 @@ package aws
 import (
 	"fmt"
 	"log"
+	"regexp"
 	"strings"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/aws-sdk-go/service/glue"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
+	"github.com/terraform-providers/terraform-provider-aws/aws/internal/service/glue/finder"
 )
 
 func resourceAwsGlueCatalogTable() *schema.Resource {
@@ -38,13 +41,18 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 				Required: true,
 			},
 			"description": {
-				Type:     schema.TypeString,
-				Optional: true,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validation.StringLenBetween(0, 2048),
 			},
 			"name": {
 				Type:     schema.TypeString,
 				ForceNew: true,
 				Required: true,
+				ValidateFunc: validation.All(
+					validation.StringLenBetween(1, 255),
+					validation.StringDoesNotMatch(regexp.MustCompile(`[A-Z]`), "uppercase characters cannot be used"),
+				),
 			},
 			"owner": {
 				Type:     schema.TypeString,
@@ -61,23 +69,27 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"comment": {
-							Type:     schema.TypeString,
-							Optional: true,
+							Type:         schema.TypeString,
+							Optional:     true,
+							ValidateFunc: validation.StringLenBetween(0, 255),
 						},
 						"name": {
-							Type:     schema.TypeString,
-							Required: true,
+							Type:         schema.TypeString,
+							Required:     true,
+							ValidateFunc: validation.StringLenBetween(1, 255),
 						},
 						"type": {
-							Type:     schema.TypeString,
-							Optional: true,
+							Type:         schema.TypeString,
+							Optional:     true,
+							ValidateFunc: validation.StringLenBetween(0, 131072),
 						},
 					},
 				},
 			},
 			"retention": {
-				Type:     schema.TypeInt,
-				Optional: true,
+				Type:         schema.TypeInt,
+				Optional:     true,
+				ValidateFunc: validation.IntAtLeast(0),
 			},
 			"storage_descriptor": {
 				Type:     schema.TypeList,
@@ -88,24 +100,36 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 						"bucket_columns": {
 							Type:     schema.TypeList,
 							Optional: true,
-							Elem:     &schema.Schema{Type: schema.TypeString},
+							Elem: &schema.Schema{
+								Type:         schema.TypeString,
+								ValidateFunc: validation.StringLenBetween(1, 255),
+							},
 						},
 						"columns": {
 							Type:     schema.TypeList,
 							Optional: true,
+							Computed: true,
 							Elem: &schema.Resource{
 								Schema: map[string]*schema.Schema{
 									"comment": {
-										Type:     schema.TypeString,
-										Optional: true,
+										Type:         schema.TypeString,
+										Optional:     true,
+										ValidateFunc: validation.StringLenBetween(0, 255),
 									},
 									"name": {
-										Type:     schema.TypeString,
-										Required: true,
+										Type:         schema.TypeString,
+										Required:     true,
+										ValidateFunc: validation.StringLenBetween(1, 255),
+									},
+									"parameters": {
+										Type:     schema.TypeMap,
+										Optional: true,
+										Elem:     &schema.Schema{Type: schema.TypeString},
 									},
 									"type": {
-										Type:     schema.TypeString,
-										Optional: true,
+										Type:         schema.TypeString,
+										Optional:     true,
+										ValidateFunc: validation.StringLenBetween(0, 131072),
 									},
 								},
 							},
@@ -142,8 +166,9 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 							Elem: &schema.Resource{
 								Schema: map[string]*schema.Schema{
 									"name": {
-										Type:     schema.TypeString,
-										Optional: true,
+										Type:         schema.TypeString,
+										Optional:     true,
+										ValidateFunc: validation.StringLenBetween(1, 255),
 									},
 									"parameters": {
 										Type:     schema.TypeMap,
@@ -151,8 +176,53 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 										Elem:     &schema.Schema{Type: schema.TypeString},
 									},
 									"serialization_library": {
-										Type:     schema.TypeString,
+										Type:         schema.TypeString,
+										Optional:     true,
+										ValidateFunc: validation.StringIsNotEmpty,
+									},
+								},
+							},
+						},
+						"schema_reference": {
+							Type:     schema.TypeList,
+							Optional: true,
+							MaxItems: 1,
+							Elem: &schema.Resource{
+								Schema: map[string]*schema.Schema{
+									"schema_id": {
+										Type:     schema.TypeList,
 										Optional: true,
+										MaxItems: 1,
+										Elem: &schema.Resource{
+											Schema: map[string]*schema.Schema{
+												"schema_arn": {
+													Type:         schema.TypeString,
+													Optional:     true,
+													ValidateFunc: validateArn,
+													ExactlyOneOf: []string{"storage_descriptor.0.schema_reference.0.schema_id.0.schema_arn", "storage_descriptor.0.schema_reference.0.schema_id.0.schema_name"},
+												},
+												"schema_name": {
+													Type:         schema.TypeString,
+													Optional:     true,
+													ExactlyOneOf: []string{"storage_descriptor.0.schema_reference.0.schema_id.0.schema_arn", "storage_descriptor.0.schema_reference.0.schema_id.0.schema_name"},
+												},
+												"registry_name": {
+													Type:          schema.TypeString,
+													Optional:      true,
+													ConflictsWith: []string{"storage_descriptor.0.schema_reference.0.schema_id.0.schema_arn"},
+												},
+											},
+										},
+									},
+									"schema_version_id": {
+										Type:         schema.TypeString,
+										Optional:     true,
+										ExactlyOneOf: []string{"storage_descriptor.0.schema_reference.0.schema_version_id", "storage_descriptor.0.schema_reference.0.schema_id"},
+									},
+									"schema_version_number": {
+										Type:         schema.TypeInt,
+										Required:     true,
+										ValidateFunc: validation.IntBetween(1, 100000),
 									},
 								},
 							},
@@ -166,7 +236,10 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 									"skewed_column_names": {
 										Type:     schema.TypeList,
 										Optional: true,
-										Elem:     &schema.Schema{Type: schema.TypeString},
+										Elem: &schema.Schema{
+											Type:         schema.TypeString,
+											ValidateFunc: validation.StringLenBetween(1, 255),
+										},
 									},
 									"skewed_column_values": {
 										Type:     schema.TypeList,
@@ -187,12 +260,14 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 							Elem: &schema.Resource{
 								Schema: map[string]*schema.Schema{
 									"column": {
-										Type:     schema.TypeString,
-										Required: true,
+										Type:         schema.TypeString,
+										Required:     true,
+										ValidateFunc: validation.StringLenBetween(1, 255),
 									},
 									"sort_order": {
-										Type:     schema.TypeInt,
-										Required: true,
+										Type:         schema.TypeInt,
+										Required:     true,
+										ValidateFunc: validation.IntInSlice([]int{0, 1}),
 									},
 								},
 							},
@@ -209,12 +284,39 @@ func resourceAwsGlueCatalogTable() *schema.Resource {
 				Optional: true,
 			},
 			"view_original_text": {
-				Type:     schema.TypeString,
-				Optional: true,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validation.StringLenBetween(0, 409600),
 			},
 			"view_expanded_text": {
-				Type:     schema.TypeString,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validation.StringLenBetween(0, 409600),
+			},
+			"partition_index": {
+				Type:     schema.TypeList,
 				Optional: true,
+				ForceNew: true,
+				MaxItems: 3,
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"index_name": {
+							Type:         schema.TypeString,
+							Required:     true,
+							ValidateFunc: validation.StringLenBetween(1, 255),
+						},
+						"keys": {
+							Type:     schema.TypeSet,
+							Required: true,
+							MinItems: 1,
+							Elem:     &schema.Schema{Type: schema.TypeString},
+						},
+						"index_status": {
+							Type:     schema.TypeString,
+							Computed: true,
+						},
+					},
+				},
 			},
 		},
 	}
@@ -235,14 +337,16 @@ func resourceAwsGlueCatalogTableCreate(d *schema.ResourceData, meta interface{})
 	name := d.Get("name").(string)
 
 	input := &glue.CreateTableInput{
-		CatalogId:    aws.String(catalogID),
-		DatabaseName: aws.String(dbName),
-		TableInput:   expandGlueTableInput(d),
+		CatalogId:        aws.String(catalogID),
+		DatabaseName:     aws.String(dbName),
+		TableInput:       expandGlueTableInput(d),
+		PartitionIndexes: expandGlueTablePartitionIndexes(d.Get("partition_index").([]interface{})),
 	}
 
+	log.Printf("[DEBUG] Glue catalog table input: %#v", input)
 	_, err := conn.CreateTable(input)
 	if err != nil {
-		return fmt.Errorf("Error creating Catalog Table: %s", err)
+		return fmt.Errorf("Error creating Glue Catalog Table: %w", err)
 	}
 
 	d.SetId(fmt.Sprintf("%s:%s:%s", catalogID, dbName, name))
@@ -258,13 +362,7 @@ func resourceAwsGlueCatalogTableRead(d *schema.ResourceData, meta interface{}) e
 		return err
 	}
 
-	input := &glue.GetTableInput{
-		CatalogId:    aws.String(catalogID),
-		DatabaseName: aws.String(dbName),
-		Name:         aws.String(name),
-	}
-
-	out, err := conn.GetTable(input)
+	out, err := finder.TableByName(conn, catalogID, dbName, name)
 	if err != nil {
 
 		if isAWSErr(err, glue.ErrCodeEntityNotFoundException, "") {
@@ -273,39 +371,56 @@ func resourceAwsGlueCatalogTableRead(d *schema.ResourceData, meta interface{}) e
 			return nil
 		}
 
-		return fmt.Errorf("Error reading Glue Catalog Table: %s", err)
+		return fmt.Errorf("Error reading Glue Catalog Table: %w", err)
 	}
 
+	table := out.Table
 	tableArn := arn.ARN{
 		Partition: meta.(*AWSClient).partition,
 		Service:   "glue",
 		Region:    meta.(*AWSClient).region,
 		AccountID: meta.(*AWSClient).accountid,
-		Resource:  fmt.Sprintf("table/%s/%s", dbName, aws.StringValue(out.Table.Name)),
+		Resource:  fmt.Sprintf("table/%s/%s", dbName, aws.StringValue(table.Name)),
 	}.String()
 	d.Set("arn", tableArn)
 
-	d.Set("name", out.Table.Name)
+	d.Set("name", table.Name)
 	d.Set("catalog_id", catalogID)
 	d.Set("database_name", dbName)
-	d.Set("description", out.Table.Description)
-	d.Set("owner", out.Table.Owner)
-	d.Set("retention", out.Table.Retention)
+	d.Set("description", table.Description)
+	d.Set("owner", table.Owner)
+	d.Set("retention", table.Retention)
 
-	if err := d.Set("storage_descriptor", flattenGlueStorageDescriptor(out.Table.StorageDescriptor)); err != nil {
-		return fmt.Errorf("error setting storage_descriptor: %s", err)
+	if err := d.Set("storage_descriptor", flattenGlueStorageDescriptor(table.StorageDescriptor)); err != nil {
+		return fmt.Errorf("error setting storage_descriptor: %w", err)
 	}
 
-	if err := d.Set("partition_keys", flattenGlueColumns(out.Table.PartitionKeys)); err != nil {
-		return fmt.Errorf("error setting partition_keys: %s", err)
+	if err := d.Set("partition_keys", flattenGlueColumns(table.PartitionKeys)); err != nil {
+		return fmt.Errorf("error setting partition_keys: %w", err)
 	}
 
-	d.Set("view_original_text", out.Table.ViewOriginalText)
-	d.Set("view_expanded_text", out.Table.ViewExpandedText)
-	d.Set("table_type", out.Table.TableType)
+	d.Set("view_original_text", table.ViewOriginalText)
+	d.Set("view_expanded_text", table.ViewExpandedText)
+	d.Set("table_type", table.TableType)
 
-	if err := d.Set("parameters", aws.StringValueMap(out.Table.Parameters)); err != nil {
-		return fmt.Errorf("error setting parameters: %s", err)
+	if err := d.Set("parameters", aws.StringValueMap(table.Parameters)); err != nil {
+		return fmt.Errorf("error setting parameters: %w", err)
+	}
+
+	partIndexInput := &glue.GetPartitionIndexesInput{
+		CatalogId:    out.Table.CatalogId,
+		TableName:    out.Table.Name,
+		DatabaseName: out.Table.DatabaseName,
+	}
+	partOut, err := conn.GetPartitionIndexes(partIndexInput)
+	if err != nil {
+		return fmt.Errorf("error getting Glue Partition Indexes: %w", err)
+	}
+
+	if partOut != nil && len(partOut.PartitionIndexDescriptorList) > 0 {
+		if err := d.Set("partition_index", flattenGluePartitionIndexes(partOut.PartitionIndexDescriptorList)); err != nil {
+			return fmt.Errorf("error setting partition_index: %w", err)
+		}
 	}
 
 	return nil
@@ -326,7 +441,7 @@ func resourceAwsGlueCatalogTableUpdate(d *schema.ResourceData, meta interface{})
 	}
 
 	if _, err := conn.UpdateTable(updateTableInput); err != nil {
-		return fmt.Errorf("Error updating Glue Catalog Table: %s", err)
+		return fmt.Errorf("Error updating Glue Catalog Table: %w", err)
 	}
 
 	return resourceAwsGlueCatalogTableRead(d, meta)
@@ -347,7 +462,7 @@ func resourceAwsGlueCatalogTableDelete(d *schema.ResourceData, meta interface{})
 		DatabaseName: aws.String(dbName),
 	})
 	if err != nil {
-		return fmt.Errorf("Error deleting Glue Catalog Table: %s", err.Error())
+		return fmt.Errorf("Error deleting Glue Catalog Table: %w", err)
 	}
 	return nil
 }
@@ -374,8 +489,9 @@ func expandGlueTableInput(d *schema.ResourceData) *glue.TableInput {
 	}
 
 	if v, ok := d.GetOk("partition_keys"); ok {
-		columns := expandGlueColumns(v.([]interface{}))
-		tableInput.PartitionKeys = columns
+		tableInput.PartitionKeys = expandGlueColumns(v.([]interface{}))
+	} else {
+		tableInput.PartitionKeys = []*glue.Column{}
 	}
 
 	if v, ok := d.GetOk("view_original_text"); ok {
@@ -391,16 +507,31 @@ func expandGlueTableInput(d *schema.ResourceData) *glue.TableInput {
 	}
 
 	if v, ok := d.GetOk("parameters"); ok {
-		paramsMap := map[string]string{}
-		for key, value := range v.(map[string]interface{}) {
-			paramsMap[key] = value.(string)
-		}
-		tableInput.Parameters = aws.StringMap(paramsMap)
+		tableInput.Parameters = stringMapToPointers(v.(map[string]interface{}))
 	}
 
 	return tableInput
 }
 
+func expandGlueTablePartitionIndexes(a []interface{}) []*glue.PartitionIndex {
+	partitionIndexes := make([]*glue.PartitionIndex, 0, len(a))
+
+	for _, m := range a {
+		partitionIndexes = append(partitionIndexes, expandGlueTablePartitionIndex(m.(map[string]interface{})))
+	}
+
+	return partitionIndexes
+}
+
+func expandGlueTablePartitionIndex(m map[string]interface{}) *glue.PartitionIndex {
+	partitionIndex := &glue.PartitionIndex{
+		IndexName: aws.String(m["index_name"].(string)),
+		Keys:      expandStringSet(m["keys"].(*schema.Set)),
+	}
+
+	return partitionIndex
+}
+
 func expandGlueStorageDescriptor(l []interface{}) *glue.StorageDescriptor {
 	if len(l) == 0 || l[0] == nil {
 		return nil
@@ -410,8 +541,7 @@ func expandGlueStorageDescriptor(l []interface{}) *glue.StorageDescriptor {
 	storageDescriptor := &glue.StorageDescriptor{}
 
 	if v, ok := s["columns"]; ok {
-		columns := expandGlueColumns(v.([]interface{}))
-		storageDescriptor.Columns = columns
+		storageDescriptor.Columns = expandGlueColumns(v.([]interface{}))
 	}
 
 	if v, ok := s["location"]; ok {
@@ -439,11 +569,7 @@ func expandGlueStorageDescriptor(l []interface{}) *glue.StorageDescriptor {
 	}
 
 	if v, ok := s["bucket_columns"]; ok {
-		bucketColumns := make([]string, len(v.([]interface{})))
-		for i, item := range v.([]interface{}) {
-			bucketColumns[i] = fmt.Sprint(item)
-		}
-		storageDescriptor.BucketColumns = aws.StringSlice(bucketColumns)
+		storageDescriptor.BucketColumns = expandStringList(v.([]interface{}))
 	}
 
 	if v, ok := s["sort_columns"]; ok {
@@ -455,17 +581,17 @@ func expandGlueStorageDescriptor(l []interface{}) *glue.StorageDescriptor {
 	}
 
 	if v, ok := s["parameters"]; ok {
-		paramsMap := map[string]string{}
-		for key, value := range v.(map[string]interface{}) {
-			paramsMap[key] = value.(string)
-		}
-		storageDescriptor.Parameters = aws.StringMap(paramsMap)
+		storageDescriptor.Parameters = stringMapToPointers(v.(map[string]interface{}))
 	}
 
 	if v, ok := s["stored_as_sub_directories"]; ok {
 		storageDescriptor.StoredAsSubDirectories = aws.Bool(v.(bool))
 	}
 
+	if v, ok := s["schema_reference"]; ok {
+		storageDescriptor.SchemaReference = expandGlueTableSchemaReference(v.([]interface{}))
+	}
+
 	return storageDescriptor
 }
 
@@ -486,6 +612,10 @@ func expandGlueColumns(columns []interface{}) []*glue.Column {
 			column.Type = aws.String(v.(string))
 		}
 
+		if v, ok := elementMap["parameters"]; ok {
+			column.Parameters = stringMapToPointers(v.(map[string]interface{}))
+		}
+
 		columnSlice = append(columnSlice, column)
 	}
 
@@ -500,19 +630,15 @@ func expandGlueSerDeInfo(l []interface{}) *glue.SerDeInfo {
 	s := l[0].(map[string]interface{})
 	serDeInfo := &glue.SerDeInfo{}
 
-	if v, ok := s["name"]; ok {
+	if v := s["name"]; len(v.(string)) > 0 {
 		serDeInfo.Name = aws.String(v.(string))
 	}
 
-	if v, ok := s["parameters"]; ok {
-		paramsMap := map[string]string{}
-		for key, value := range v.(map[string]interface{}) {
-			paramsMap[key] = value.(string)
-		}
-		serDeInfo.Parameters = aws.StringMap(paramsMap)
+	if v := s["parameters"]; len(v.(map[string]interface{})) > 0 {
+		serDeInfo.Parameters = stringMapToPointers(v.(map[string]interface{}))
 	}
 
-	if v, ok := s["serialization_library"]; ok {
+	if v := s["serialization_library"]; len(v.(string)) > 0 {
 		serDeInfo.SerializationLibrary = aws.String(v.(string))
 	}
 
@@ -548,32 +674,66 @@ func expandGlueSkewedInfo(l []interface{}) *glue.SkewedInfo {
 	skewedInfo := &glue.SkewedInfo{}
 
 	if v, ok := s["skewed_column_names"]; ok {
-		columnsSlice := make([]string, len(v.([]interface{})))
-		for i, item := range v.([]interface{}) {
-			columnsSlice[i] = fmt.Sprint(item)
-		}
-		skewedInfo.SkewedColumnNames = aws.StringSlice(columnsSlice)
+		skewedInfo.SkewedColumnNames = expandStringList(v.([]interface{}))
 	}
 
 	if v, ok := s["skewed_column_value_location_maps"]; ok {
-		typeMap := map[string]string{}
-		for key, value := range v.(map[string]interface{}) {
-			typeMap[key] = value.(string)
-		}
-		skewedInfo.SkewedColumnValueLocationMaps = aws.StringMap(typeMap)
+		skewedInfo.SkewedColumnValueLocationMaps = stringMapToPointers(v.(map[string]interface{}))
 	}
 
 	if v, ok := s["skewed_column_values"]; ok {
-		columnsSlice := make([]string, len(v.([]interface{})))
-		for i, item := range v.([]interface{}) {
-			columnsSlice[i] = fmt.Sprint(item)
-		}
-		skewedInfo.SkewedColumnValues = aws.StringSlice(columnsSlice)
+		skewedInfo.SkewedColumnValues = expandStringList(v.([]interface{}))
 	}
 
 	return skewedInfo
 }
 
+func expandGlueTableSchemaReference(l []interface{}) *glue.SchemaReference {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	s := l[0].(map[string]interface{})
+	schemaRef := &glue.SchemaReference{}
+
+	if v, ok := s["schema_version_id"].(string); ok && v != "" {
+		schemaRef.SchemaVersionId = aws.String(v)
+	}
+
+	if v, ok := s["schema_id"]; ok {
+		schemaRef.SchemaId = expandGlueTableSchemaReferenceSchemaID(v.([]interface{}))
+	}
+
+	if v, ok := s["schema_version_number"].(int); ok {
+		schemaRef.SchemaVersionNumber = aws.Int64(int64(v))
+	}
+
+	return schemaRef
+}
+
+func expandGlueTableSchemaReferenceSchemaID(l []interface{}) *glue.SchemaId {
+	if len(l) == 0 || l[0] == nil {
+		return nil
+	}
+
+	s := l[0].(map[string]interface{})
+	schemaID := &glue.SchemaId{}
+
+	if v, ok := s["registry_name"].(string); ok && v != "" {
+		schemaID.RegistryName = aws.String(v)
+	}
+
+	if v, ok := s["schema_name"].(string); ok && v != "" {
+		schemaID.SchemaName = aws.String(v)
+	}
+
+	if v, ok := s["schema_arn"].(string); ok && v != "" {
+		schemaID.SchemaArn = aws.String(v)
+	}
+
+	return schemaID
+}
+
 func flattenGlueStorageDescriptor(s *glue.StorageDescriptor) []map[string]interface{} {
 	if s == nil {
 		storageDescriptors := make([]map[string]interface{}, 0)
@@ -595,6 +755,7 @@ func flattenGlueStorageDescriptor(s *glue.StorageDescriptor) []map[string]interf
 	storageDescriptor["sort_columns"] = flattenGlueOrders(s.SortColumns)
 	storageDescriptor["parameters"] = aws.StringValueMap(s.Parameters)
 	storageDescriptor["skewed_info"] = flattenGlueSkewedInfo(s.SkewedInfo)
+	storageDescriptor["schema_reference"] = flattenGlueTableSchemaReference(s.SchemaReference)
 	storageDescriptor["stored_as_sub_directories"] = aws.BoolValue(s.StoredAsSubDirectories)
 
 	storageDescriptors[0] = storageDescriptor
@@ -602,8 +763,8 @@ func flattenGlueStorageDescriptor(s *glue.StorageDescriptor) []map[string]interf
 	return storageDescriptors
 }
 
-func flattenGlueColumns(cs []*glue.Column) []map[string]string {
-	columnsSlice := make([]map[string]string, len(cs))
+func flattenGlueColumns(cs []*glue.Column) []map[string]interface{} {
+	columnsSlice := make([]map[string]interface{}, len(cs))
 	if len(cs) > 0 {
 		for i, v := range cs {
 			columnsSlice[i] = flattenGlueColumn(v)
@@ -613,8 +774,8 @@ func flattenGlueColumns(cs []*glue.Column) []map[string]string {
 	return columnsSlice
 }
 
-func flattenGlueColumn(c *glue.Column) map[string]string {
-	column := make(map[string]string)
+func flattenGlueColumn(c *glue.Column) map[string]interface{} {
+	column := make(map[string]interface{})
 
 	if c == nil {
 		return column
@@ -632,9 +793,50 @@ func flattenGlueColumn(c *glue.Column) map[string]string {
 		column["comment"] = v
 	}
 
+	if v := c.Parameters; v != nil {
+		column["parameters"] = aws.StringValueMap(v)
+	}
+
 	return column
 }
 
+func flattenGluePartitionIndexes(cs []*glue.PartitionIndexDescriptor) []map[string]interface{} {
+	partitionIndexSlice := make([]map[string]interface{}, len(cs))
+	if len(cs) > 0 {
+		for i, v := range cs {
+			partitionIndexSlice[i] = flattenGluePartitionIndex(v)
+		}
+	}
+
+	return partitionIndexSlice
+}
+
+func flattenGluePartitionIndex(c *glue.PartitionIndexDescriptor) map[string]interface{} {
+	partitionIndex := make(map[string]interface{})
+
+	if c == nil {
+		return partitionIndex
+	}
+
+	if v := aws.StringValue(c.IndexName); v != "" {
+		partitionIndex["index_name"] = v
+	}
+
+	if v := aws.StringValue(c.IndexStatus); v != "" {
+		partitionIndex["index_status"] = v
+	}
+
+	if c.Keys != nil {
+		names := make([]*string, 0, len(c.Keys))
+		for _, key := range c.Keys {
+			names = append(names, key.Name)
+		}
+		partitionIndex["keys"] = flattenStringSet(names)
+	}
+
+	return partitionIndex
+}
+
 func flattenGlueSerDeInfo(s *glue.SerDeInfo) []map[string]interface{} {
 	if s == nil {
 		serDeInfos := make([]map[string]interface{}, 0)
@@ -644,9 +846,15 @@ func flattenGlueSerDeInfo(s *glue.SerDeInfo) []map[string]interface{} {
 	serDeInfos := make([]map[string]interface{}, 1)
 	serDeInfo := make(map[string]interface{})
 
-	serDeInfo["name"] = aws.StringValue(s.Name)
+	if v := aws.StringValue(s.Name); v != "" {
+		serDeInfo["name"] = v
+	}
+
 	serDeInfo["parameters"] = aws.StringValueMap(s.Parameters)
-	serDeInfo["serialization_library"] = aws.StringValue(s.SerializationLibrary)
+
+	if v := aws.StringValue(s.SerializationLibrary); v != "" {
+		serDeInfo["serialization_library"] = v
+	}
 
 	serDeInfos[0] = serDeInfo
 	return serDeInfos
@@ -680,3 +888,57 @@ func flattenGlueSkewedInfo(s *glue.SkewedInfo) []map[string]interface{} {
 
 	return skewedInfoSlice
 }
+
+func flattenGlueTableSchemaReference(s *glue.SchemaReference) []map[string]interface{} {
+	if s == nil {
+		schemaReferenceInfoSlice := make([]map[string]interface{}, 0)
+		return schemaReferenceInfoSlice
+	}
+
+	schemaReferenceInfoSlice := make([]map[string]interface{}, 1)
+
+	schemaReferenceInfo := make(map[string]interface{})
+
+	if s.SchemaVersionId != nil {
+		schemaReferenceInfo["schema_version_id"] = aws.StringValue(s.SchemaVersionId)
+	}
+
+	if s.SchemaVersionNumber != nil {
+		schemaReferenceInfo["schema_version_number"] = aws.Int64Value(s.SchemaVersionNumber)
+	}
+
+	if s.SchemaId != nil {
+		schemaReferenceInfo["schema_id"] = flattenGlueTableSchemaReferenceSchemaID(s.SchemaId)
+	}
+
+	schemaReferenceInfoSlice[0] = schemaReferenceInfo
+
+	return schemaReferenceInfoSlice
+}
+
+func flattenGlueTableSchemaReferenceSchemaID(s *glue.SchemaId) []map[string]interface{} {
+	if s == nil {
+		schemaIDInfoSlice := make([]map[string]interface{}, 0)
+		return schemaIDInfoSlice
+	}
+
+	schemaIDInfoSlice := make([]map[string]interface{}, 1)
+
+	schemaIDInfo := make(map[string]interface{})
+
+	if s.RegistryName != nil {
+		schemaIDInfo["registry_name"] = aws.StringValue(s.RegistryName)
+	}
+
+	if s.SchemaArn != nil {
+		schemaIDInfo["schema_arn"] = aws.StringValue(s.SchemaArn)
+	}
+
+	if s.SchemaName != nil {
+		schemaIDInfo["schema_name"] = aws.StringValue(s.SchemaName)
+	}
+
+	schemaIDInfoSlice[0] = schemaIDInfo
+
+	return schemaIDInfoSlice
+}
