@@ -89,7 +89,6 @@ func TestAccAWSGlueClassifier_CsvClassifier(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.disable_value_trimming", "false"),
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.header.0", "header_column1"),
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.header.1", "header_column2"),
-					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.quote_symbol", "\""),
 					resource.TestCheckResourceAttr(resourceName, "grok_classifier.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "json_classifier.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
@@ -107,7 +106,6 @@ func TestAccAWSGlueClassifier_CsvClassifier(t *testing.T) {
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.disable_value_trimming", "false"),
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.header.0", "header_column1"),
 					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.header.1", "header_column2"),
-					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.quote_symbol", "\""),
 					resource.TestCheckResourceAttr(resourceName, "grok_classifier.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "json_classifier.#", "0"),
 					resource.TestCheckResourceAttr(resourceName, "name", rName),
@@ -123,6 +121,42 @@ func TestAccAWSGlueClassifier_CsvClassifier(t *testing.T) {
 	})
 }
 
+func TestAccAWSGlueClassifier_CsvClassifier_quoteSymbol(t *testing.T) {
+	var classifier glue.Classifier
+
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_glue_classifier.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSGlueClassifierDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSGlueClassifierConfigCsvClassifierQuoteSymbol(rName, "\""),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueClassifierExists(resourceName, &classifier),
+					resource.TestCheckResourceAttr(resourceName, "csv_classifier.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.quote_symbol", "\""),
+				),
+			},
+			{
+				Config: testAccAWSGlueClassifierConfigCsvClassifierQuoteSymbol(rName, "'"),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueClassifierExists(resourceName, &classifier),
+					resource.TestCheckResourceAttr(resourceName, "csv_classifier.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "csv_classifier.0.quote_symbol", "'"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
 func TestAccAWSGlueClassifier_GrokClassifier(t *testing.T) {
 	var classifier glue.Classifier
 
@@ -377,6 +411,29 @@ func TestAccAWSGlueClassifier_XmlClassifier(t *testing.T) {
 	})
 }
 
+func TestAccAWSGlueClassifier_disappears(t *testing.T) {
+	var classifier glue.Classifier
+
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_glue_classifier.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSGlueClassifierDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSGlueClassifierConfig_CsvClassifier(rName, false, "PRESENT", "|", false),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueClassifierExists(resourceName, &classifier),
+					testAccCheckResourceDisappears(testAccProvider, resourceAwsGlueClassifier(), resourceName),
+				),
+				ExpectNonEmptyPlan: true,
+			},
+		},
+	})
+}
+
 func testAccCheckAWSGlueClassifierExists(resourceName string, classifier *glue.Classifier) resource.TestCheckFunc {
 	return func(s *terraform.State) error {
 		rs, ok := s.RootModule().Resources[resourceName]
@@ -447,12 +504,27 @@ resource "aws_glue_classifier" "test" {
     delimiter              = "%s"
     disable_value_trimming = "%t"
     header                 = ["header_column1", "header_column2"]
-    quote_symbol           = "\""
   }
 }
 `, rName, allowSingleColumn, containsHeader, delimiter, disableValueTrimming)
 }
 
+func testAccAWSGlueClassifierConfigCsvClassifierQuoteSymbol(rName, symbol string) string {
+	return fmt.Sprintf(`
+resource "aws_glue_classifier" "test" {
+  name = %[1]q
+
+  csv_classifier {
+    allow_single_column = false
+    contains_header     = "PRESENT"
+    delimiter           = ","
+    header              = ["header_column1", "header_column2"]
+    quote_symbol        = %[2]q
+  }
+}
+`, rName, symbol)
+}
+
 func testAccAWSGlueClassifierConfig_GrokClassifier(rName, classification, grokPattern string) string {
 	return fmt.Sprintf(`
 resource "aws_glue_classifier" "test" {
