@@ -3,17 +3,19 @@ package aws
 import (
 	"fmt"
 	"log"
+	"regexp"
 	"strings"
-	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/aws-sdk-go/service/glue"
+	"github.com/hashicorp/aws-sdk-go-base/tfawserr"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/structure"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/keyvaluetags"
+	iamwaiter "github.com/terraform-providers/terraform-provider-aws/aws/internal/service/iam/waiter"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/tfresource"
 )
 
@@ -32,6 +34,10 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				Type:     schema.TypeString,
 				ForceNew: true,
 				Required: true,
+				ValidateFunc: validation.All(
+					validation.StringLenBetween(1, 255),
+					validation.StringMatch(regexp.MustCompile(`[a-zA-Z0-9-_$#]+$`), ""),
+				),
 			},
 			"arn": {
 				Type:     schema.TypeString,
@@ -57,8 +63,9 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				},
 			},
 			"description": {
-				Type:     schema.TypeString,
-				Optional: true,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validation.StringLenBetween(0, 2048),
 			},
 			"schedule": {
 				Type:     schema.TypeString,
@@ -97,13 +104,15 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				},
 			},
 			"table_prefix": {
-				Type:     schema.TypeString,
-				Optional: true,
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validation.StringLenBetween(0, 128),
 			},
 			"s3_target": {
-				Type:     schema.TypeList,
-				Optional: true,
-				MinItems: 1,
+				Type:         schema.TypeList,
+				Optional:     true,
+				MinItems:     1,
+				AtLeastOneOf: []string{"s3_target", "dynamodb_target", "mongodb_target", "jdbc_target", "catalog_target"},
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"connection_name": {
@@ -123,9 +132,10 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				},
 			},
 			"dynamodb_target": {
-				Type:     schema.TypeList,
-				Optional: true,
-				MinItems: 1,
+				Type:         schema.TypeList,
+				Optional:     true,
+				MinItems:     1,
+				AtLeastOneOf: []string{"s3_target", "dynamodb_target", "mongodb_target", "jdbc_target", "catalog_target"},
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"path": {
@@ -145,10 +155,34 @@ func resourceAwsGlueCrawler() *schema.Resource {
 					},
 				},
 			},
+			"mongodb_target": {
+				Type:         schema.TypeList,
+				Optional:     true,
+				MinItems:     1,
+				AtLeastOneOf: []string{"s3_target", "dynamodb_target", "mongodb_target", "jdbc_target", "catalog_target"},
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"connection_name": {
+							Type:     schema.TypeString,
+							Required: true,
+						},
+						"path": {
+							Type:     schema.TypeString,
+							Required: true,
+						},
+						"scan_all": {
+							Type:     schema.TypeBool,
+							Optional: true,
+							Default:  true,
+						},
+					},
+				},
+			},
 			"jdbc_target": {
-				Type:     schema.TypeList,
-				Optional: true,
-				MinItems: 1,
+				Type:         schema.TypeList,
+				Optional:     true,
+				MinItems:     1,
+				AtLeastOneOf: []string{"s3_target", "dynamodb_target", "mongodb_target", "jdbc_target", "catalog_target"},
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"connection_name": {
@@ -168,9 +202,10 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				},
 			},
 			"catalog_target": {
-				Type:     schema.TypeList,
-				Optional: true,
-				MinItems: 1,
+				Type:         schema.TypeList,
+				Optional:     true,
+				MinItems:     1,
+				AtLeastOneOf: []string{"s3_target", "dynamodb_target", "mongodb_target", "jdbc_target", "catalog_target"},
 				Elem: &schema.Resource{
 					Schema: map[string]*schema.Schema{
 						"database_name": {
@@ -195,6 +230,48 @@ func resourceAwsGlueCrawler() *schema.Resource {
 				},
 				ValidateFunc: validation.StringIsJSON,
 			},
+			"lineage_configuration": {
+				Type:     schema.TypeList,
+				Optional: true,
+				MaxItems: 1,
+				DiffSuppressFunc: func(k, old, new string, d *schema.ResourceData) bool {
+					if old == "1" && new == "0" {
+						return true
+					}
+					return false
+				},
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"crawler_lineage_settings": {
+							Type:         schema.TypeString,
+							Optional:     true,
+							Default:      glue.CrawlerLineageSettingsDisable,
+							ValidateFunc: validation.StringInSlice(glue.CrawlerLineageSettings_Values(), false),
+						},
+					},
+				},
+			},
+			"recrawl_policy": {
+				Type:     schema.TypeList,
+				Optional: true,
+				MaxItems: 1,
+				DiffSuppressFunc: func(k, old, new string, d *schema.ResourceData) bool {
+					if old == "1" && new == "0" {
+						return true
+					}
+					return false
+				},
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"recrawl_behavior": {
+							Type:         schema.TypeString,
+							Optional:     true,
+							Default:      glue.RecrawlBehaviorCrawlEverything,
+							ValidateFunc: validation.StringInSlice(glue.RecrawlBehavior_Values(), false),
+						},
+					},
+				},
+			},
 			"security_configuration": {
 				Type:     schema.TypeString,
 				Optional: true,
@@ -214,16 +291,23 @@ func resourceAwsGlueCrawlerCreate(d *schema.ResourceData, meta interface{}) erro
 	}
 
 	// Retry for IAM eventual consistency
-	err = resource.Retry(1*time.Minute, func() *resource.RetryError {
+	err = resource.Retry(iamwaiter.PropagationTimeout, func() *resource.RetryError {
 		_, err = glueConn.CreateCrawler(crawlerInput)
 		if err != nil {
-			if isAWSErr(err, glue.ErrCodeInvalidInputException, "Service is unable to assume role") {
+			// InvalidInputException: Insufficient Lake Formation permission(s) on xxx
+			if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "Insufficient Lake Formation permission") {
 				return resource.RetryableError(err)
 			}
+
+			if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "Service is unable to assume role") {
+				return resource.RetryableError(err)
+			}
+
 			// InvalidInputException: Unable to retrieve connection tf-acc-test-8656357591012534997: User: arn:aws:sts::*******:assumed-role/tf-acc-test-8656357591012534997/AWS-Crawler is not authorized to perform: glue:GetConnection on resource: * (Service: AmazonDataCatalog; Status Code: 400; Error Code: AccessDeniedException; Request ID: 4d72b66f-9c75-11e8-9faf-5b526c7be968)
-			if isAWSErr(err, glue.ErrCodeInvalidInputException, "is not authorized") {
+			if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "is not authorized") {
 				return resource.RetryableError(err)
 			}
+
 			return resource.NonRetryableError(err)
 		}
 		return nil
@@ -232,7 +316,7 @@ func resourceAwsGlueCrawlerCreate(d *schema.ResourceData, meta interface{}) erro
 		_, err = glueConn.CreateCrawler(crawlerInput)
 	}
 	if err != nil {
-		return fmt.Errorf("error creating Glue crawler: %s", err)
+		return fmt.Errorf("error creating Glue crawler: %w", err)
 	}
 	d.SetId(name)
 
@@ -240,16 +324,12 @@ func resourceAwsGlueCrawlerCreate(d *schema.ResourceData, meta interface{}) erro
 }
 
 func createCrawlerInput(crawlerName string, d *schema.ResourceData) (*glue.CreateCrawlerInput, error) {
-	crawlerTargets, err := expandGlueCrawlerTargets(d)
-	if err != nil {
-		return nil, err
-	}
 	crawlerInput := &glue.CreateCrawlerInput{
 		Name:         aws.String(crawlerName),
 		DatabaseName: aws.String(d.Get("database_name").(string)),
 		Role:         aws.String(d.Get("role").(string)),
 		Tags:         keyvaluetags.New(d.Get("tags").(map[string]interface{})).IgnoreAws().GlueTags(),
-		Targets:      crawlerTargets,
+		Targets:      expandGlueCrawlerTargets(d),
 	}
 	if description, ok := d.GetOk("description"); ok {
 		crawlerInput.Description = aws.String(description.(string))
@@ -282,19 +362,23 @@ func createCrawlerInput(crawlerName string, d *schema.ResourceData) (*glue.Creat
 		crawlerInput.CrawlerSecurityConfiguration = aws.String(securityConfiguration.(string))
 	}
 
+	if v, ok := d.GetOk("lineage_configuration"); ok {
+		crawlerInput.LineageConfiguration = expandGlueCrawlerLineageConfiguration(v.([]interface{}))
+	}
+
+	if v, ok := d.GetOk("recrawl_policy"); ok {
+		crawlerInput.RecrawlPolicy = expandGlueCrawlerRecrawlPolicy(v.([]interface{}))
+	}
+
 	return crawlerInput, nil
 }
 
 func updateCrawlerInput(crawlerName string, d *schema.ResourceData) (*glue.UpdateCrawlerInput, error) {
-	crawlerTargets, err := expandGlueCrawlerTargets(d)
-	if err != nil {
-		return nil, err
-	}
 	crawlerInput := &glue.UpdateCrawlerInput{
 		Name:         aws.String(crawlerName),
 		DatabaseName: aws.String(d.Get("database_name").(string)),
 		Role:         aws.String(d.Get("role").(string)),
-		Targets:      crawlerTargets,
+		Targets:      expandGlueCrawlerTargets(d),
 	}
 	if description, ok := d.GetOk("description"); ok {
 		crawlerInput.Description = aws.String(description.(string))
@@ -330,6 +414,14 @@ func updateCrawlerInput(crawlerName string, d *schema.ResourceData) (*glue.Updat
 		crawlerInput.CrawlerSecurityConfiguration = aws.String(securityConfiguration.(string))
 	}
 
+	if v, ok := d.GetOk("lineage_configuration"); ok {
+		crawlerInput.LineageConfiguration = expandGlueCrawlerLineageConfiguration(v.([]interface{}))
+	}
+
+	if v, ok := d.GetOk("recrawl_policy"); ok {
+		crawlerInput.RecrawlPolicy = expandGlueCrawlerRecrawlPolicy(v.([]interface{}))
+	}
+
 	return crawlerInput, nil
 }
 
@@ -352,24 +444,32 @@ func expandGlueSchemaChangePolicy(v []interface{}) *glue.SchemaChangePolicy {
 	return schemaPolicy
 }
 
-func expandGlueCrawlerTargets(d *schema.ResourceData) (*glue.CrawlerTargets, error) {
+func expandGlueCrawlerTargets(d *schema.ResourceData) *glue.CrawlerTargets {
 	crawlerTargets := &glue.CrawlerTargets{}
 
-	dynamodbTargets, dynamodbTargetsOk := d.GetOk("dynamodb_target")
-	jdbcTargets, jdbcTargetsOk := d.GetOk("jdbc_target")
-	s3Targets, s3TargetsOk := d.GetOk("s3_target")
-	catalogTargets, catalogTargetsOk := d.GetOk("catalog_target")
-	if !dynamodbTargetsOk && !jdbcTargetsOk && !s3TargetsOk && !catalogTargetsOk {
-		return nil, fmt.Errorf("One of the following configurations is required: dynamodb_target, jdbc_target, s3_target, catalog_target")
+	log.Print("[DEBUG] Creating crawler target")
+
+	if v, ok := d.GetOk("dynamodb_target"); ok {
+		crawlerTargets.DynamoDBTargets = expandGlueDynamoDBTargets(v.([]interface{}))
 	}
 
-	log.Print("[DEBUG] Creating crawler target")
-	crawlerTargets.DynamoDBTargets = expandGlueDynamoDBTargets(dynamodbTargets.([]interface{}))
-	crawlerTargets.JdbcTargets = expandGlueJdbcTargets(jdbcTargets.([]interface{}))
-	crawlerTargets.S3Targets = expandGlueS3Targets(s3Targets.([]interface{}))
-	crawlerTargets.CatalogTargets = expandGlueCatalogTargets(catalogTargets.([]interface{}))
+	if v, ok := d.GetOk("jdbc_target"); ok {
+		crawlerTargets.JdbcTargets = expandGlueJdbcTargets(v.([]interface{}))
+	}
 
-	return crawlerTargets, nil
+	if v, ok := d.GetOk("s3_target"); ok {
+		crawlerTargets.S3Targets = expandGlueS3Targets(v.([]interface{}))
+	}
+
+	if v, ok := d.GetOk("catalog_target"); ok {
+		crawlerTargets.CatalogTargets = expandGlueCatalogTargets(v.([]interface{}))
+	}
+
+	if v, ok := d.GetOk("mongodb_target"); ok {
+		crawlerTargets.MongoDBTargets = expandGlueMongoDBTargets(v.([]interface{}))
+	}
+
+	return crawlerTargets
 }
 
 func expandGlueDynamoDBTargets(targets []interface{}) []*glue.DynamoDBTarget {
@@ -473,29 +573,57 @@ func expandGlueCatalogTarget(cfg map[string]interface{}) *glue.CatalogTarget {
 	return target
 }
 
+func expandGlueMongoDBTargets(targets []interface{}) []*glue.MongoDBTarget {
+	if len(targets) < 1 {
+		return []*glue.MongoDBTarget{}
+	}
+
+	perms := make([]*glue.MongoDBTarget, len(targets))
+	for i, rawCfg := range targets {
+		cfg := rawCfg.(map[string]interface{})
+		perms[i] = expandGlueMongoDBTarget(cfg)
+	}
+	return perms
+}
+
+func expandGlueMongoDBTarget(cfg map[string]interface{}) *glue.MongoDBTarget {
+	target := &glue.MongoDBTarget{
+		ConnectionName: aws.String(cfg["connection_name"].(string)),
+		Path:           aws.String(cfg["path"].(string)),
+		ScanAll:        aws.Bool(cfg["scan_all"].(bool)),
+	}
+
+	return target
+}
+
 func resourceAwsGlueCrawlerUpdate(d *schema.ResourceData, meta interface{}) error {
 	glueConn := meta.(*AWSClient).glueconn
 	name := d.Get("name").(string)
 
-	if d.HasChanges(
-		"catalog_target", "classifiers", "configuration", "description", "dynamodb_target", "jdbc_target", "role",
-		"s3_target", "schedule", "schema_change_policy", "security_configuration", "table_prefix") {
+	if d.HasChangesExcept("tags") {
 		updateCrawlerInput, err := updateCrawlerInput(name, d)
 		if err != nil {
 			return err
 		}
 
 		// Retry for IAM eventual consistency
-		err = resource.Retry(1*time.Minute, func() *resource.RetryError {
+		err = resource.Retry(iamwaiter.PropagationTimeout, func() *resource.RetryError {
 			_, err := glueConn.UpdateCrawler(updateCrawlerInput)
 			if err != nil {
-				if isAWSErr(err, glue.ErrCodeInvalidInputException, "Service is unable to assume role") {
+				// InvalidInputException: Insufficient Lake Formation permission(s) on xxx
+				if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "Insufficient Lake Formation permission") {
 					return resource.RetryableError(err)
 				}
+
+				if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "Service is unable to assume role") {
+					return resource.RetryableError(err)
+				}
+
 				// InvalidInputException: Unable to retrieve connection tf-acc-test-8656357591012534997: User: arn:aws:sts::*******:assumed-role/tf-acc-test-8656357591012534997/AWS-Crawler is not authorized to perform: glue:GetConnection on resource: * (Service: AmazonDataCatalog; Status Code: 400; Error Code: AccessDeniedException; Request ID: 4d72b66f-9c75-11e8-9faf-5b526c7be968)
-				if isAWSErr(err, glue.ErrCodeInvalidInputException, "is not authorized") {
+				if tfawserr.ErrMessageContains(err, glue.ErrCodeInvalidInputException, "is not authorized") {
 					return resource.RetryableError(err)
 				}
+
 				return resource.NonRetryableError(err)
 			}
 			return nil
@@ -506,14 +634,14 @@ func resourceAwsGlueCrawlerUpdate(d *schema.ResourceData, meta interface{}) erro
 		}
 
 		if err != nil {
-			return fmt.Errorf("error updating Glue crawler: %s", err)
+			return fmt.Errorf("error updating Glue crawler: %w", err)
 		}
 	}
 
 	if d.HasChange("tags") {
 		o, n := d.GetChange("tags")
 		if err := keyvaluetags.GlueUpdateTags(glueConn, d.Get("arn").(string), o, n); err != nil {
-			return fmt.Errorf("error updating tags: %s", err)
+			return fmt.Errorf("error updating tags: %w", err)
 		}
 	}
 
@@ -536,10 +664,11 @@ func resourceAwsGlueCrawlerRead(d *schema.ResourceData, meta interface{}) error
 			return nil
 		}
 
-		return fmt.Errorf("error reading Glue crawler: %s", err.Error())
+		return fmt.Errorf("error reading Glue crawler: %w", err)
 	}
 
-	if crawlerOutput.Crawler == nil {
+	crawler := crawlerOutput.Crawler
+	if crawler == nil {
 		log.Printf("[WARN] Glue Crawler (%s) not found, removing from state", d.Id())
 		d.SetId("")
 		return nil
@@ -553,58 +682,65 @@ func resourceAwsGlueCrawlerRead(d *schema.ResourceData, meta interface{}) error
 		Resource:  fmt.Sprintf("crawler/%s", d.Id()),
 	}.String()
 	d.Set("arn", crawlerARN)
-	d.Set("name", crawlerOutput.Crawler.Name)
-	d.Set("database_name", crawlerOutput.Crawler.DatabaseName)
-	d.Set("role", crawlerOutput.Crawler.Role)
-	d.Set("configuration", crawlerOutput.Crawler.Configuration)
-	d.Set("description", crawlerOutput.Crawler.Description)
-	d.Set("security_configuration", crawlerOutput.Crawler.CrawlerSecurityConfiguration)
+	d.Set("name", crawler.Name)
+	d.Set("database_name", crawler.DatabaseName)
+	d.Set("role", crawler.Role)
+	d.Set("configuration", crawler.Configuration)
+	d.Set("description", crawler.Description)
+	d.Set("security_configuration", crawler.CrawlerSecurityConfiguration)
 	d.Set("schedule", "")
-	if crawlerOutput.Crawler.Schedule != nil {
-		d.Set("schedule", crawlerOutput.Crawler.Schedule.ScheduleExpression)
+	if crawler.Schedule != nil {
+		d.Set("schedule", crawler.Schedule.ScheduleExpression)
 	}
-	if err := d.Set("classifiers", flattenStringList(crawlerOutput.Crawler.Classifiers)); err != nil {
-		return fmt.Errorf("error setting classifiers: %s", err)
+	if err := d.Set("classifiers", flattenStringList(crawler.Classifiers)); err != nil {
+		return fmt.Errorf("error setting classifiers: %w", err)
 	}
-	d.Set("table_prefix", crawlerOutput.Crawler.TablePrefix)
+	d.Set("table_prefix", crawler.TablePrefix)
 
-	if crawlerOutput.Crawler.SchemaChangePolicy != nil {
-		schemaPolicy := map[string]string{
-			"delete_behavior": aws.StringValue(crawlerOutput.Crawler.SchemaChangePolicy.DeleteBehavior),
-			"update_behavior": aws.StringValue(crawlerOutput.Crawler.SchemaChangePolicy.UpdateBehavior),
-		}
-
-		if err := d.Set("schema_change_policy", []map[string]string{schemaPolicy}); err != nil {
-			return fmt.Errorf("error setting schema_change_policy: %s", schemaPolicy)
+	if crawler.SchemaChangePolicy != nil {
+		if err := d.Set("schema_change_policy", flattenGlueCrawlerSchemaChangePolicy(crawler.SchemaChangePolicy)); err != nil {
+			return fmt.Errorf("error setting schema_change_policy: %w", err)
 		}
 	}
 
-	if crawlerOutput.Crawler.Targets != nil {
-		if err := d.Set("dynamodb_target", flattenGlueDynamoDBTargets(crawlerOutput.Crawler.Targets.DynamoDBTargets)); err != nil {
-			return fmt.Errorf("error setting dynamodb_target: %s", err)
+	if crawler.Targets != nil {
+		if err := d.Set("dynamodb_target", flattenGlueDynamoDBTargets(crawler.Targets.DynamoDBTargets)); err != nil {
+			return fmt.Errorf("error setting dynamodb_target: %w", err)
 		}
 
-		if err := d.Set("jdbc_target", flattenGlueJdbcTargets(crawlerOutput.Crawler.Targets.JdbcTargets)); err != nil {
-			return fmt.Errorf("error setting jdbc_target: %s", err)
+		if err := d.Set("jdbc_target", flattenGlueJdbcTargets(crawler.Targets.JdbcTargets)); err != nil {
+			return fmt.Errorf("error setting jdbc_target: %w", err)
 		}
 
-		if err := d.Set("s3_target", flattenGlueS3Targets(crawlerOutput.Crawler.Targets.S3Targets)); err != nil {
-			return fmt.Errorf("error setting s3_target: %s", err)
+		if err := d.Set("s3_target", flattenGlueS3Targets(crawler.Targets.S3Targets)); err != nil {
+			return fmt.Errorf("error setting s3_target: %w", err)
 		}
 
-		if err := d.Set("catalog_target", flattenGlueCatalogTargets(crawlerOutput.Crawler.Targets.CatalogTargets)); err != nil {
-			return fmt.Errorf("error setting catalog_target: %s", err)
+		if err := d.Set("catalog_target", flattenGlueCatalogTargets(crawler.Targets.CatalogTargets)); err != nil {
+			return fmt.Errorf("error setting catalog_target: %w", err)
+		}
+
+		if err := d.Set("mongodb_target", flattenGlueMongoDBTargets(crawler.Targets.MongoDBTargets)); err != nil {
+			return fmt.Errorf("error setting mongodb_target: %w", err)
 		}
 	}
 
 	tags, err := keyvaluetags.GlueListTags(glueConn, crawlerARN)
 
 	if err != nil {
-		return fmt.Errorf("error listing tags for Glue Crawler (%s): %s", crawlerARN, err)
+		return fmt.Errorf("error listing tags for Glue Crawler (%s): %w", crawlerARN, err)
 	}
 
 	if err := d.Set("tags", tags.IgnoreAws().IgnoreConfig(ignoreTagsConfig).Map()); err != nil {
-		return fmt.Errorf("error setting tags: %s", err)
+		return fmt.Errorf("error setting tags: %w", err)
+	}
+
+	if err := d.Set("lineage_configuration", flattenGlueCrawlerLineageConfiguration(crawler.LineageConfiguration)); err != nil {
+		return fmt.Errorf("error setting lineage_configuration: %w", err)
+	}
+
+	if err := d.Set("recrawl_policy", flattenGlueCrawlerRecrawlPolicy(crawler.RecrawlPolicy)); err != nil {
+		return fmt.Errorf("error setting recrawl_policy: %w", err)
 	}
 
 	return nil
@@ -665,6 +801,20 @@ func flattenGlueJdbcTargets(jdbcTargets []*glue.JdbcTarget) []map[string]interfa
 	return result
 }
 
+func flattenGlueMongoDBTargets(mongoDBTargets []*glue.MongoDBTarget) []map[string]interface{} {
+	result := make([]map[string]interface{}, 0)
+
+	for _, mongoDBTarget := range mongoDBTargets {
+		attrs := make(map[string]interface{})
+		attrs["connection_name"] = aws.StringValue(mongoDBTarget.ConnectionName)
+		attrs["path"] = aws.StringValue(mongoDBTarget.Path)
+		attrs["scan_all"] = aws.BoolValue(mongoDBTarget.ScanAll)
+
+		result = append(result, attrs)
+	}
+	return result
+}
+
 func resourceAwsGlueCrawlerDelete(d *schema.ResourceData, meta interface{}) error {
 	glueConn := meta.(*AWSClient).glueconn
 
@@ -676,7 +826,62 @@ func resourceAwsGlueCrawlerDelete(d *schema.ResourceData, meta interface{}) erro
 		if isAWSErr(err, glue.ErrCodeEntityNotFoundException, "") {
 			return nil
 		}
-		return fmt.Errorf("error deleting Glue crawler: %s", err.Error())
+		return fmt.Errorf("error deleting Glue crawler: %w", err)
 	}
 	return nil
 }
+
+func flattenGlueCrawlerSchemaChangePolicy(cfg *glue.SchemaChangePolicy) []map[string]interface{} {
+	if cfg == nil {
+		return []map[string]interface{}{}
+	}
+
+	m := map[string]interface{}{
+		"delete_behavior": aws.StringValue(cfg.DeleteBehavior),
+		"update_behavior": aws.StringValue(cfg.UpdateBehavior),
+	}
+
+	return []map[string]interface{}{m}
+}
+
+func expandGlueCrawlerLineageConfiguration(cfg []interface{}) *glue.LineageConfiguration {
+	m := cfg[0].(map[string]interface{})
+
+	target := &glue.LineageConfiguration{
+		CrawlerLineageSettings: aws.String(m["crawler_lineage_settings"].(string)),
+	}
+	return target
+}
+
+func flattenGlueCrawlerLineageConfiguration(cfg *glue.LineageConfiguration) []map[string]interface{} {
+	if cfg == nil {
+		return []map[string]interface{}{}
+	}
+
+	m := map[string]interface{}{
+		"crawler_lineage_settings": aws.StringValue(cfg.CrawlerLineageSettings),
+	}
+
+	return []map[string]interface{}{m}
+}
+
+func expandGlueCrawlerRecrawlPolicy(cfg []interface{}) *glue.RecrawlPolicy {
+	m := cfg[0].(map[string]interface{})
+
+	target := &glue.RecrawlPolicy{
+		RecrawlBehavior: aws.String(m["recrawl_behavior"].(string)),
+	}
+	return target
+}
+
+func flattenGlueCrawlerRecrawlPolicy(cfg *glue.RecrawlPolicy) []map[string]interface{} {
+	if cfg == nil {
+		return []map[string]interface{}{}
+	}
+
+	m := map[string]interface{}{
+		"recrawl_behavior": aws.StringValue(cfg.RecrawlBehavior),
+	}
+
+	return []map[string]interface{}{m}
+}
