@@ -57,7 +57,7 @@ func testSweepGlueTriggers(region string) error {
 func TestAccAWSGlueTrigger_basic(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -71,6 +71,7 @@ func TestAccAWSGlueTrigger_basic(t *testing.T) {
 					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
 					resource.TestCheckResourceAttr(resourceName, "actions.#", "1"),
 					resource.TestCheckResourceAttr(resourceName, "actions.0.job_name", rName),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.#", "0"),
 					testAccCheckResourceAttrRegionalARN(resourceName, "arn", "glue", fmt.Sprintf("trigger/%s", rName)),
 					resource.TestCheckResourceAttr(resourceName, "description", ""),
 					resource.TestCheckResourceAttr(resourceName, "enabled", "true"),
@@ -94,7 +95,7 @@ func TestAccAWSGlueTrigger_basic(t *testing.T) {
 func TestAccAWSGlueTrigger_Crawler(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test_trigger"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -140,7 +141,7 @@ func TestAccAWSGlueTrigger_Crawler(t *testing.T) {
 func TestAccAWSGlueTrigger_Description(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -174,7 +175,7 @@ func TestAccAWSGlueTrigger_Description(t *testing.T) {
 func TestAccAWSGlueTrigger_Enabled(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -215,7 +216,7 @@ func TestAccAWSGlueTrigger_Enabled(t *testing.T) {
 func TestAccAWSGlueTrigger_Predicate(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -257,7 +258,7 @@ func TestAccAWSGlueTrigger_Predicate(t *testing.T) {
 func TestAccAWSGlueTrigger_Schedule(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -291,7 +292,7 @@ func TestAccAWSGlueTrigger_Schedule(t *testing.T) {
 func TestAccAWSGlueTrigger_Tags(t *testing.T) {
 	var trigger1, trigger2, trigger3 glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -336,7 +337,7 @@ func TestAccAWSGlueTrigger_Tags(t *testing.T) {
 func TestAccAWSGlueTrigger_WorkflowName(t *testing.T) {
 	var trigger glue.Trigger
 
-	rName := fmt.Sprintf("tf-acc-test-%s", acctest.RandString(5))
+	rName := acctest.RandomWithPrefix("tf-acc-test")
 	resourceName := "aws_glue_trigger.test"
 
 	resource.ParallelTest(t, resource.TestCase{
@@ -360,6 +361,108 @@ func TestAccAWSGlueTrigger_WorkflowName(t *testing.T) {
 	})
 }
 
+func TestAccAWSGlueTrigger_actions_notify(t *testing.T) {
+	var trigger glue.Trigger
+
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_glue_trigger.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSGlueTriggerDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSGlueTriggerConfigActionsNotification(rName, 1),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
+					resource.TestCheckResourceAttr(resourceName, "actions.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.job_name", rName),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.0.notify_delay_after", "1"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+			{
+				Config: testAccAWSGlueTriggerConfigActionsNotification(rName, 2),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
+					resource.TestCheckResourceAttr(resourceName, "actions.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.job_name", rName),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.0.notify_delay_after", "2"),
+				),
+			},
+			{
+				Config: testAccAWSGlueTriggerConfigActionsNotification(rName, 1),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
+					resource.TestCheckResourceAttr(resourceName, "actions.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.job_name", rName),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.notification_property.0.notify_delay_after", "1"),
+				),
+			},
+		},
+	})
+}
+
+func TestAccAWSGlueTrigger_actions_securityConfig(t *testing.T) {
+	var trigger glue.Trigger
+
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_glue_trigger.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSGlueTriggerDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSGlueTriggerConfigActionsSecurityConfiguration(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
+					resource.TestCheckResourceAttr(resourceName, "actions.#", "1"),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.job_name", rName),
+					resource.TestCheckResourceAttr(resourceName, "actions.0.security_configuration", rName),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
+func TestAccAWSGlueTrigger_disappears(t *testing.T) {
+	var trigger glue.Trigger
+
+	rName := acctest.RandomWithPrefix("tf-acc-test")
+	resourceName := "aws_glue_trigger.test"
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:     func() { testAccPreCheck(t) },
+		Providers:    testAccProviders,
+		CheckDestroy: testAccCheckAWSGlueTriggerDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAWSGlueTriggerConfig_OnDemand(rName),
+				Check: resource.ComposeTestCheckFunc(
+					testAccCheckAWSGlueTriggerExists(resourceName, &trigger),
+					testAccCheckResourceDisappears(testAccProvider, resourceAwsGlueTrigger(), resourceName),
+				),
+				ExpectNonEmptyPlan: true,
+			},
+		},
+	})
+}
+
 func testAccCheckAWSGlueTriggerExists(resourceName string, trigger *glue.Trigger) resource.TestCheckFunc {
 	return func(s *terraform.State) error {
 		rs, ok := s.RootModule().Resources[resourceName]
@@ -424,28 +527,24 @@ func testAccCheckAWSGlueTriggerDestroy(s *terraform.State) error {
 }
 
 func testAccAWSGlueTriggerConfig_Description(rName, description string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
-  description = "%s"
-  name        = "%s"
+  description = %[1]q
+  name        = %[2]q
   type        = "ON_DEMAND"
 
   actions {
     job_name = aws_glue_job.test.name
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), description, rName)
+`, description, rName))
 }
 
 func testAccAWSGlueTriggerConfig_Enabled(rName string, enabled bool) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
-  enabled  = %t
-  name     = "%s"
+  enabled  = %[1]t
+  name     = %[2]q
   schedule = "cron(15 12 * * ? *)"
   type     = "SCHEDULED"
 
@@ -453,30 +552,26 @@ resource "aws_glue_trigger" "test" {
     job_name = aws_glue_job.test.name
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), enabled, rName)
+`, enabled, rName))
 }
 
 func testAccAWSGlueTriggerConfig_OnDemand(rName string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
-  name = "%s"
+  name = %[1]q
   type = "ON_DEMAND"
 
   actions {
     job_name = aws_glue_job.test.name
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), rName)
+`, rName))
 }
 
 func testAccAWSGlueTriggerConfig_Predicate(rName, state string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_job" "test2" {
-  name     = "%s2"
+  name     = "%[1]s2"
   role_arn = aws_iam_role.test.arn
 
   command {
@@ -487,7 +582,7 @@ resource "aws_glue_job" "test2" {
 }
 
 resource "aws_glue_trigger" "test" {
-  name = "%s"
+  name = %[1]q
   type = "CONDITIONAL"
 
   actions {
@@ -497,22 +592,20 @@ resource "aws_glue_trigger" "test" {
   predicate {
     conditions {
       job_name = aws_glue_job.test.name
-      state    = "%s"
+      state    = %[2]q
     }
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), rName, rName, state)
+`, rName, state))
 }
 
 func testAccAWSGlueTriggerConfig_Crawler(rName, state string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccGlueCrawlerConfig_S3Target(rName, "s3://test_bucket"), fmt.Sprintf(`
 resource "aws_glue_crawler" "test2" {
   depends_on = [aws_iam_role_policy_attachment.test-AWSGlueServiceRole]
 
   database_name = aws_glue_catalog_database.test.name
-  name          = "%scrawl2"
+  name          = "%[1]scrawl2"
   role          = aws_iam_role.test.name
 
   s3_target {
@@ -521,7 +614,7 @@ resource "aws_glue_crawler" "test2" {
 }
 
 resource "aws_glue_trigger" "test_trigger" {
-  name = "%strigger"
+  name = %[1]q
   type = "CONDITIONAL"
 
   actions {
@@ -531,31 +624,29 @@ resource "aws_glue_trigger" "test_trigger" {
   predicate {
     conditions {
       crawler_name = aws_glue_crawler.test2.name
-      crawl_state  = "%s"
+      crawl_state  = %[2]q
     }
   }
 }
-`, testAccGlueCrawlerConfig_S3Target(rName, "s3://test_bucket"), rName, rName, state)
+`, rName, state))
 }
 
 func testAccAWSGlueTriggerConfig_Schedule(rName, schedule string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
-  name     = "%s"
-  schedule = "%s"
+  name     = %[1]q
+  schedule = %[2]q
   type     = "SCHEDULED"
 
   actions {
     job_name = aws_glue_job.test.name
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), rName, schedule)
+`, rName, schedule))
 }
 
 func testAccAWSGlueTriggerConfigTags1(rName, tagKey1, tagValue1 string) string {
-	return testAccAWSGlueJobConfig_Required(rName) + fmt.Sprintf(`
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
   name = %[1]q
   type = "ON_DEMAND"
@@ -568,11 +659,11 @@ resource "aws_glue_trigger" "test" {
     %[2]q = %[3]q
   }
 }
-`, rName, tagKey1, tagValue1)
+`, rName, tagKey1, tagValue1))
 }
 
 func testAccAWSGlueTriggerConfigTags2(rName, tagKey1, tagValue1, tagKey2, tagValue2 string) string {
-	return testAccAWSGlueJobConfig_Required(rName) + fmt.Sprintf(`
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_trigger" "test" {
   name = %[1]q
   type = "ON_DEMAND"
@@ -586,19 +677,17 @@ resource "aws_glue_trigger" "test" {
     %[4]q = %[5]q
   }
 }
-`, rName, tagKey1, tagValue1, tagKey2, tagValue2)
+`, rName, tagKey1, tagValue1, tagKey2, tagValue2))
 }
 
 func testAccAWSGlueTriggerConfig_WorkflowName(rName string) string {
-	return fmt.Sprintf(`
-%s
-
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
 resource "aws_glue_workflow" test {
-  name = "%s"
+  name = %[1]q
 }
 
 resource "aws_glue_trigger" "test" {
-  name          = "%s"
+  name          = %[1]q
   type          = "ON_DEMAND"
   workflow_name = aws_glue_workflow.test.name
 
@@ -606,5 +695,54 @@ resource "aws_glue_trigger" "test" {
     job_name = aws_glue_job.test.name
   }
 }
-`, testAccAWSGlueJobConfig_Required(rName), rName, rName)
+`, rName))
+}
+
+func testAccAWSGlueTriggerConfigActionsNotification(rName string, delay int) string {
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
+resource "aws_glue_trigger" "test" {
+  name = %[1]q
+  type = "ON_DEMAND"
+
+  actions {
+    job_name = aws_glue_job.test.name
+
+    notification_property {
+      notify_delay_after = %[2]d
+    }
+  }
+}
+`, rName, delay))
+}
+
+func testAccAWSGlueTriggerConfigActionsSecurityConfiguration(rName string) string {
+	return composeConfig(testAccAWSGlueJobConfig_Required(rName), fmt.Sprintf(`
+resource "aws_glue_security_configuration" "test" {
+  name = %[1]q
+
+  encryption_configuration {
+    cloudwatch_encryption {
+      cloudwatch_encryption_mode = "DISABLED"
+    }
+
+    job_bookmarks_encryption {
+      job_bookmarks_encryption_mode = "DISABLED"
+    }
+
+    s3_encryption {
+      s3_encryption_mode = "DISABLED"
+    }
+  }
+}
+
+resource "aws_glue_trigger" "test" {
+  name = %[1]q
+  type = "ON_DEMAND"
+
+  actions {
+    job_name               = aws_glue_job.test.name
+    security_configuration = aws_glue_security_configuration.test.name
+  }
+}
+`, rName))
 }
