@@ -620,6 +620,8 @@ func testAccCheckAWSIoTTopicRuleExists(name string) resource.TestCheckFunc {
 }
 
 const testAccAWSIoTTopicRuleRole = `
+data "aws_partition" "current" {}
+
 resource "aws_iam_role" "iot_role" {
   name = "test_role_%[1]s"
 
@@ -630,7 +632,7 @@ resource "aws_iam_role" "iot_role" {
     {
       "Effect": "Allow",
       "Principal": {
-        "Service": "iot.amazonaws.com"
+        "Service": "iot.${data.aws_partition.current.dns_suffix}"
       },
       "Action": "sts:AssumeRole"
     }
@@ -794,7 +796,7 @@ resource "aws_iot_topic_rule" "rule" {
   sql_version = "2015-10-08"
 
   elasticsearch {
-    endpoint = "https://domain.${data.aws_region.current.name}.es.amazonaws.com"
+    endpoint = "https://domain.${data.aws_region.current.name}.es.${data.aws_partition.current.dns_suffix}"
     id       = "myIdentifier"
     index    = "myindex"
     type     = "mydocument"
@@ -858,6 +860,8 @@ resource "aws_iot_topic_rule" "rule" {
 
 func testAccAWSIoTTopicRule_lambda(rName string) string {
 	return fmt.Sprintf(testAccAWSIoTTopicRuleRole+`
+data "aws_region" "current" {}
+
 resource "aws_iot_topic_rule" "rule" {
   name        = "test_rule_%[1]s"
   description = "Example rule"
@@ -866,7 +870,7 @@ resource "aws_iot_topic_rule" "rule" {
   sql_version = "2015-10-08"
 
   lambda {
-    function_arn = "arn:aws:lambda:us-east-1:123456789012:function:ProcessKinesisRecords"
+    function_arn = "arn:${data.aws_partition.current.partition}:lambda:${data.aws_region.current.name}:123456789012:function:ProcessKinesisRecords"
   }
 }
 `, rName)
@@ -927,6 +931,8 @@ resource "aws_iot_topic_rule" "rule" {
 
 func testAccAWSIoTTopicRule_sns(rName string) string {
 	return fmt.Sprintf(testAccAWSIoTTopicRuleRole+`
+data "aws_region" "current" {}
+
 resource "aws_iot_topic_rule" "rule" {
   name        = "test_rule_%[1]s"
   description = "Example rule"
@@ -936,7 +942,7 @@ resource "aws_iot_topic_rule" "rule" {
 
   sns {
     role_arn   = aws_iam_role.iot_role.arn
-    target_arn = "arn:aws:sns:us-east-1:123456789012:my_corporate_topic"
+    target_arn = "arn:${data.aws_partition.current.partition}:sns:${data.aws_region.current.name}:123456789012:my_corporate_topic"
   }
 }
 `, rName)
