@@ -2,6 +2,7 @@ package aws
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"io/ioutil"
 	"log"
@@ -11,20 +12,22 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/arn"
 	"github.com/aws/aws-sdk-go/aws/awserr"
+	"github.com/aws/aws-sdk-go/aws/endpoints"
 	"github.com/aws/aws-sdk-go/service/lambda"
-	homedir "github.com/mitchellh/go-homedir"
-
-	"errors"
-
+	"github.com/hashicorp/aws-sdk-go-base/tfawserr"
+	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/customdiff"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/resource"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/schema"
 	"github.com/hashicorp/terraform-plugin-sdk/v2/helper/validation"
+	homedir "github.com/mitchellh/go-homedir"
 	"github.com/terraform-providers/terraform-provider-aws/aws/internal/keyvaluetags"
 	iamwaiter "github.com/terraform-providers/terraform-provider-aws/aws/internal/service/iam/waiter"
 )
 
 const awsMutexLambdaKey = `aws_lambda_function`
 
+const LambdaFunctionVersionLatest = "$LATEST"
+
 func resourceAwsLambdaFunction() *schema.Resource {
 	return &schema.Resource{
 		Create: resourceAwsLambdaFunctionCreate,
@@ -46,22 +49,70 @@ func resourceAwsLambdaFunction() *schema.Resource {
 			"filename": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"s3_bucket", "s3_key", "s3_object_version"},
+				ConflictsWith: []string{"s3_bucket", "s3_key", "s3_object_version", "image_uri"},
 			},
 			"s3_bucket": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"filename"},
+				ConflictsWith: []string{"filename", "image_uri"},
 			},
 			"s3_key": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"filename"},
+				ConflictsWith: []string{"filename", "image_uri"},
 			},
 			"s3_object_version": {
 				Type:          schema.TypeString,
 				Optional:      true,
-				ConflictsWith: []string{"filename"},
+				ConflictsWith: []string{"filename", "image_uri"},
+			},
+			"image_uri": {
+				Type:          schema.TypeString,
+				Optional:      true,
+				ConflictsWith: []string{"filename", "s3_bucket", "s3_key", "s3_object_version"},
+			},
+			"package_type": {
+				Type:         schema.TypeString,
+				Optional:     true,
+				ForceNew:     true,
+				Default:      lambda.PackageTypeZip,
+				ValidateFunc: validation.StringInSlice(lambda.PackageType_Values(), false),
+			},
+			"image_config": {
+				Type:     schema.TypeList,
+				Optional: true,
+				MaxItems: 1,
+				Elem: &schema.Resource{
+					Schema: map[string]*schema.Schema{
+						"entry_point": {
+							Type:     schema.TypeList,
+							Optional: true,
+							Elem:     &schema.Schema{Type: schema.TypeString},
+						},
+						"command": {
+							Type:     schema.TypeList,
+							Optional: true,
+							Elem:     &schema.Schema{Type: schema.TypeString},
+						},
+						"working_directory": {
+							Type:     schema.TypeString,
+							Optional: true,
+						},
+					},
+				},
+			},
+			"code_signing_config_arn": {
+				Type:         schema.TypeString,
+				Optional:     true,
+				ValidateFunc: validateArn,
+			},
+			"signing_profile_version_arn": {
+				Type:     schema.TypeString,
+				Computed: true,
+			},
+			"signing_job_arn": {
+				Type:     schema.TypeString,
+				Computed: true,
 			},
 			"description": {
 				Type:     schema.TypeString,
@@ -112,7 +163,7 @@ func resourceAwsLambdaFunction() *schema.Resource {
 			},
 			"handler": {
 				Type:         schema.TypeString,
-				Required:     true,
+				Optional:     true,
 				ValidateFunc: validation.StringLenBetween(1, 128),
 			},
 			"layers": {
@@ -141,7 +192,7 @@ func resourceAwsLambdaFunction() *schema.Resource {
 			},
 			"runtime": {
 				Type:         schema.TypeString,
-				Required:     true,
+				Optional:     true,
 				ValidateFunc: validation.StringInSlice(lambda.Runtime_Values(), false),
 			},
 			"timeout": {
@@ -266,22 +317,57 @@ func resourceAwsLambdaFunction() *schema.Resource {
 			"tags": tagsSchema(),
 		},
 
-		CustomizeDiff: updateComputedAttributesOnPublish,
+		CustomizeDiff: customdiff.Sequence(
+			checkHandlerRuntimeForZipFunction,
+			updateComputedAttributesOnPublish,
+		),
 	}
 }
 
-func updateComputedAttributesOnPublish(_ context.Context, d *schema.ResourceDiff, meta interface{}) error {
-	if needsFunctionCodeUpdate(d) {
-		d.SetNewComputed("last_modified")
-		publish := d.Get("publish").(bool)
-		if publish {
-			d.SetNewComputed("version")
-			d.SetNewComputed("qualified_arn")
-		}
+func checkHandlerRuntimeForZipFunction(_ context.Context, d *schema.ResourceDiff, meta interface{}) error {
+	packageType := d.Get("package_type")
+	_, handlerOk := d.GetOk("handler")
+	_, runtimeOk := d.GetOk("runtime")
+
+	if packageType == lambda.PackageTypeZip && !handlerOk && !runtimeOk {
+		return fmt.Errorf("handler and runtime must be set when PackageType is Zip")
 	}
 	return nil
 }
 
+func updateComputedAttributesOnPublish(_ context.Context, d *schema.ResourceDiff, meta interface{}) error {
+	configChanged := hasConfigChanges(d)
+	functionCodeUpdated := needsFunctionCodeUpdate(d)
+	if functionCodeUpdated {
+		d.SetNewComputed("last_modified")
+	}
+
+	publish := d.Get("publish").(bool)
+	publishChanged := d.HasChange("publish")
+	if publish && (configChanged || functionCodeUpdated || publishChanged) {
+		d.SetNewComputed("version")
+		d.SetNewComputed("qualified_arn")
+	}
+	return nil
+}
+
+func hasConfigChanges(d resourceDiffer) bool {
+	return d.HasChange("description") ||
+		d.HasChange("handler") ||
+		d.HasChange("file_system_config") ||
+		d.HasChange("image_config") ||
+		d.HasChange("memory_size") ||
+		d.HasChange("role") ||
+		d.HasChange("timeout") ||
+		d.HasChange("kms_key_arn") ||
+		d.HasChange("layers") ||
+		d.HasChange("dead_letter_config") ||
+		d.HasChange("tracing_config") ||
+		d.HasChange("vpc_config") ||
+		d.HasChange("runtime") ||
+		d.HasChange("environment")
+}
+
 // resourceAwsLambdaFunction maps to:
 // CreateFunction in the API / SDK
 func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) error {
@@ -297,9 +383,10 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 	s3Bucket, bucketOk := d.GetOk("s3_bucket")
 	s3Key, keyOk := d.GetOk("s3_key")
 	s3ObjectVersion, versionOk := d.GetOk("s3_object_version")
+	imageUri, hasImageUri := d.GetOk("image_uri")
 
-	if !hasFilename && !bucketOk && !keyOk && !versionOk {
-		return errors.New("filename or s3_* attributes must be set")
+	if !hasFilename && !bucketOk && !keyOk && !versionOk && !hasImageUri {
+		return errors.New("filename, s3_* or image_uri attributes must be set")
 	}
 
 	var functionCode *lambda.FunctionCode
@@ -311,11 +398,15 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 		defer awsMutexKV.Unlock(awsMutexLambdaKey)
 		file, err := loadFileContent(filename.(string))
 		if err != nil {
-			return fmt.Errorf("Unable to load %q: %s", filename.(string), err)
+			return fmt.Errorf("Unable to load %q: %w", filename.(string), err)
 		}
 		functionCode = &lambda.FunctionCode{
 			ZipFile: file,
 		}
+	} else if hasImageUri {
+		functionCode = &lambda.FunctionCode{
+			ImageUri: aws.String(imageUri.(string)),
+		}
 	} else {
 		if !bucketOk || !keyOk {
 			return errors.New("s3_bucket and s3_key must all be set while using S3 code source")
@@ -329,16 +420,32 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 		}
 	}
 
+	packageType := d.Get("package_type")
+	handler, handlerOk := d.GetOk("handler")
+	runtime, runtimeOk := d.GetOk("runtime")
+
+	if packageType == lambda.PackageTypeZip && !handlerOk && !runtimeOk {
+		return errors.New("handler and runtime must be set when PackageType is Zip")
+	}
+
 	params := &lambda.CreateFunctionInput{
 		Code:         functionCode,
 		Description:  aws.String(d.Get("description").(string)),
 		FunctionName: aws.String(functionName),
-		Handler:      aws.String(d.Get("handler").(string)),
 		MemorySize:   aws.Int64(int64(d.Get("memory_size").(int))),
 		Role:         aws.String(iamRole),
-		Runtime:      aws.String(d.Get("runtime").(string)),
 		Timeout:      aws.Int64(int64(d.Get("timeout").(int))),
 		Publish:      aws.Bool(d.Get("publish").(bool)),
+		PackageType:  aws.String(d.Get("package_type").(string)),
+	}
+
+	if packageType == lambda.PackageTypeZip {
+		params.Handler = aws.String(handler.(string))
+		params.Runtime = aws.String(runtime.(string))
+	}
+
+	if v, ok := d.GetOk("code_signing_config_arn"); ok {
+		params.CodeSigningConfigArn = aws.String(v.(string))
 	}
 
 	if v, ok := d.GetOk("layers"); ok && len(v.([]interface{})) > 0 {
@@ -363,6 +470,10 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 		params.FileSystemConfigs = expandLambdaFileSystemConfigs(v.([]interface{}))
 	}
 
+	if v, ok := d.GetOk("image_config"); ok && len(v.([]interface{})) > 0 {
+		params.ImageConfig = expandLambdaImageConfigs(v.([]interface{}))
+	}
+
 	if v, ok := d.GetOk("vpc_config"); ok && len(v.([]interface{})) > 0 {
 		config := v.([]interface{})[0].(map[string]interface{})
 
@@ -433,7 +544,7 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 	})
 	if err != nil {
 		if !isResourceTimeoutError(err) && !isAWSErr(err, "InvalidParameterValueException", "Your request has been throttled by EC2") {
-			return fmt.Errorf("Error creating Lambda function: %s", err)
+			return fmt.Errorf("error creating Lambda Function: %w", err)
 		}
 		// Allow additional time for slower uploads or EC2 throttling
 		err := resource.Retry(d.Timeout(schema.TimeoutCreate), func() *resource.RetryError {
@@ -454,14 +565,14 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 			_, err = conn.CreateFunction(params)
 		}
 		if err != nil {
-			return fmt.Errorf("Error creating Lambda function: %s", err)
+			return fmt.Errorf("error creating Lambda Function: %w", err)
 		}
 	}
 
 	d.SetId(d.Get("function_name").(string))
 
 	if err := waitForLambdaFunctionCreation(conn, d.Id(), d.Timeout(schema.TimeoutCreate)); err != nil {
-		return fmt.Errorf("error waiting for Lambda Function (%s) creation: %s", d.Id(), err)
+		return fmt.Errorf("error waiting for Lambda Function (%s) creation: %w", d.Id(), err)
 	}
 
 	if reservedConcurrentExecutions >= 0 {
@@ -487,7 +598,7 @@ func resourceAwsLambdaFunctionCreate(d *schema.ResourceData, meta interface{}) e
 			_, err = conn.PutFunctionConcurrency(concurrencyParams)
 		}
 		if err != nil {
-			return fmt.Errorf("Error setting concurrency for Lambda %s: %s", functionName, err)
+			return fmt.Errorf("Error setting Lambda Function (%s) concurrency: %w", functionName, err)
 		}
 	}
 
@@ -532,7 +643,7 @@ func resourceAwsLambdaFunctionRead(d *schema.ResourceData, meta interface{}) err
 	// Tags on aliases and versions are not supported.
 	if !qualifierExistance {
 		if err := d.Set("tags", keyvaluetags.LambdaKeyValueTags(getFunctionOutput.Tags).IgnoreAws().IgnoreConfig(ignoreTagsConfig).Map()); err != nil {
-			return fmt.Errorf("error setting tags: %s", err)
+			return fmt.Errorf("error setting tags: %w", err)
 		}
 	}
 
@@ -542,35 +653,94 @@ func resourceAwsLambdaFunctionRead(d *schema.ResourceData, meta interface{}) err
 	// getFunctionOutput.Configuration which holds metadata.
 
 	function := getFunctionOutput.Configuration
-	// TODO error checking / handling on the Set() calls.
-	d.Set("arn", function.FunctionArn)
-	d.Set("description", function.Description)
-	d.Set("handler", function.Handler)
-	d.Set("memory_size", function.MemorySize)
-	d.Set("last_modified", function.LastModified)
-	d.Set("role", function.Role)
-	d.Set("runtime", function.Runtime)
-	d.Set("timeout", function.Timeout)
-	d.Set("kms_key_arn", function.KMSKeyArn)
-	d.Set("source_code_hash", function.CodeSha256)
-	d.Set("source_code_size", function.CodeSize)
+
+	if err := d.Set("arn", function.FunctionArn); err != nil {
+		return fmt.Errorf("Error setting function arn for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("description", function.Description); err != nil {
+		return fmt.Errorf("Error setting function description for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("handler", function.Handler); err != nil {
+		return fmt.Errorf("Error setting handler for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("memory_size", function.MemorySize); err != nil {
+		return fmt.Errorf("Error setting memory size for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("last_modified", function.LastModified); err != nil {
+		return fmt.Errorf("Error setting last modified time for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("role", function.Role); err != nil {
+		return fmt.Errorf("Error setting role for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("runtime", function.Runtime); err != nil {
+		return fmt.Errorf("Error setting runtime for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("timeout", function.Timeout); err != nil {
+		return fmt.Errorf("Error setting timeout for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("kms_key_arn", function.KMSKeyArn); err != nil {
+		return fmt.Errorf("Error setting KMS key arn for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("source_code_hash", function.CodeSha256); err != nil {
+		return fmt.Errorf("Error setting CodeSha256 for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("source_code_size", function.CodeSize); err != nil {
+		return fmt.Errorf("Error setting code size for Lambda Function: %s", err)
+	}
+
+	// Add Signing Profile Version ARN
+	if err := d.Set("signing_profile_version_arn", function.SigningProfileVersionArn); err != nil {
+		return fmt.Errorf("Error setting signing profile version arn for Lambda Function: %s", err)
+	}
+
+	// Add Signing Job ARN
+	if err := d.Set("signing_job_arn", function.SigningJobArn); err != nil {
+		return fmt.Errorf("Error setting signing job arn for Lambda Function: %s", err)
+	}
 
 	fileSystemConfigs := flattenLambdaFileSystemConfigs(function.FileSystemConfigs)
 	log.Printf("[INFO] Setting Lambda %s file system configs %#v from API", d.Id(), fileSystemConfigs)
 	if err := d.Set("file_system_config", fileSystemConfigs); err != nil {
-		return fmt.Errorf("Error setting file system config for Lambda Function (%s): %s", d.Id(), err)
+		return fmt.Errorf("Error setting file system config for Lambda Function (%s): %w", d.Id(), err)
+	}
+
+	// Add Package Type
+	log.Printf("[INFO] Setting Lambda %s package type %#v from API", d.Id(), function.PackageType)
+	if err := d.Set("package_type", function.PackageType); err != nil {
+		return fmt.Errorf("Error setting package type for Lambda Function: %w", err)
+	}
+
+	// Add Image Configuration
+	imageConfig := flattenLambdaImageConfig(function.ImageConfigResponse)
+	log.Printf("[INFO] Setting Lambda %s Image config %#v from API", d.Id(), imageConfig)
+	if err := d.Set("image_config", imageConfig); err != nil {
+		return fmt.Errorf("Error setting image config for Lambda Function: %s", err)
+	}
+
+	if err := d.Set("image_uri", getFunctionOutput.Code.ImageUri); err != nil {
+		return fmt.Errorf("Error setting image uri for Lambda Function: %s", err)
 	}
 
 	layers := flattenLambdaLayers(function.Layers)
 	log.Printf("[INFO] Setting Lambda %s Layers %#v from API", d.Id(), layers)
 	if err := d.Set("layers", layers); err != nil {
-		return fmt.Errorf("Error setting layers for Lambda Function (%s): %s", d.Id(), err)
+		return fmt.Errorf("Error setting layers for Lambda Function (%s): %w", d.Id(), err)
 	}
 
 	config := flattenLambdaVpcConfigResponse(function.VpcConfig)
 	log.Printf("[INFO] Setting Lambda %s VPC config %#v from API", d.Id(), config)
 	if err := d.Set("vpc_config", config); err != nil {
-		return fmt.Errorf("Error setting vpc_config for Lambda Function (%s): %s", d.Id(), err)
+		return fmt.Errorf("Error setting vpc_config for Lambda Function (%s): %w", d.Id(), err)
 	}
 
 	environment := flattenLambdaEnvironment(function.Environment)
@@ -632,6 +802,32 @@ func resourceAwsLambdaFunctionRead(d *schema.ResourceData, meta interface{}) err
 	invokeArn := lambdaFunctionInvokeArn(*function.FunctionArn, meta)
 	d.Set("invoke_arn", invokeArn)
 
+	// Currently, this functionality is only enabled in AWS Commercial partition
+	// and other partitions return ambiguous error codes (e.g. AccessDeniedException
+	// in AWS GovCloud (US)) so we cannot just ignore the error as would typically.
+	if meta.(*AWSClient).partition != endpoints.AwsPartitionID {
+		return nil
+	}
+
+	// Code Signing is only supported on zip packaged lambda functions.
+	var codeSigningConfigArn string
+
+	if aws.StringValue(function.PackageType) == lambda.PackageTypeZip {
+		codeSigningConfigInput := &lambda.GetFunctionCodeSigningConfigInput{
+			FunctionName: aws.String(d.Id()),
+		}
+		getCodeSigningConfigOutput, err := conn.GetFunctionCodeSigningConfig(codeSigningConfigInput)
+		if err != nil {
+			return fmt.Errorf("error getting Lambda Function (%s) code signing config %w", d.Id(), err)
+		}
+
+		if getCodeSigningConfigOutput != nil {
+			codeSigningConfigArn = aws.StringValue(getCodeSigningConfigOutput.CodeSigningConfigArn)
+		}
+	}
+
+	d.Set("code_signing_config_arn", codeSigningConfigArn)
+
 	return nil
 }
 
@@ -665,19 +861,26 @@ func resourceAwsLambdaFunctionDelete(d *schema.ResourceData, meta interface{}) e
 	}
 
 	_, err := conn.DeleteFunction(params)
+
+	if tfawserr.ErrCodeEquals(err, lambda.ErrCodeResourceNotFoundException) {
+		return nil
+	}
+
 	if err != nil {
-		return fmt.Errorf("Error deleting Lambda Function: %s", err)
+		return fmt.Errorf("error deleting Lambda Function (%s): %w", d.Id(), err)
 	}
 
 	return nil
 }
 
-type resourceDiffer interface {
-	HasChange(string) bool
-}
-
 func needsFunctionCodeUpdate(d resourceDiffer) bool {
-	return d.HasChange("filename") || d.HasChange("source_code_hash") || d.HasChange("s3_bucket") || d.HasChange("s3_key") || d.HasChange("s3_object_version")
+	return d.HasChange("filename") ||
+		d.HasChange("source_code_hash") ||
+		d.HasChange("s3_bucket") ||
+		d.HasChange("s3_key") ||
+		d.HasChange("s3_object_version") ||
+		d.HasChange("image_uri")
+
 }
 
 // resourceAwsLambdaFunctionUpdate maps to:
@@ -685,12 +888,39 @@ func needsFunctionCodeUpdate(d resourceDiffer) bool {
 func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) error {
 	conn := meta.(*AWSClient).lambdaconn
 
+	// If Code Signing Config is updated, calls PutFunctionCodeSigningConfig
+	// If removed, calls DeleteFunctionCodeSigningConfig
+	if d.HasChange("code_signing_config_arn") {
+		if v, ok := d.GetOk("code_signing_config_arn"); ok {
+			configUpdateInput := &lambda.PutFunctionCodeSigningConfigInput{
+				CodeSigningConfigArn: aws.String(v.(string)),
+				FunctionName:         aws.String(d.Id()),
+			}
+
+			_, err := conn.PutFunctionCodeSigningConfig(configUpdateInput)
+
+			if err != nil {
+				return fmt.Errorf("error updating code signing config arn (Function: %s): %s", d.Id(), err)
+			}
+		} else {
+			configDeleteInput := &lambda.DeleteFunctionCodeSigningConfigInput{
+				FunctionName: aws.String(d.Id()),
+			}
+
+			_, err := conn.DeleteFunctionCodeSigningConfig(configDeleteInput)
+
+			if err != nil {
+				return fmt.Errorf("error deleting code signing config arn (Function: %s): %s", d.Id(), err)
+			}
+		}
+	}
+
 	arn := d.Get("arn").(string)
 	if d.HasChange("tags") {
 		o, n := d.GetChange("tags")
 
 		if err := keyvaluetags.LambdaUpdateTags(conn, arn, o, n); err != nil {
-			return fmt.Errorf("error updating Lambda Function (%s) tags: %s", arn, err)
+			return fmt.Errorf("error updating Lambda Function (%s) tags: %w", arn, err)
 		}
 	}
 
@@ -698,42 +928,40 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 		FunctionName: aws.String(d.Id()),
 	}
 
-	configUpdate := false
 	if d.HasChange("description") {
 		configReq.Description = aws.String(d.Get("description").(string))
-		configUpdate = true
 	}
+
 	if d.HasChange("handler") {
 		configReq.Handler = aws.String(d.Get("handler").(string))
-		configUpdate = true
 	}
 	if d.HasChange("file_system_config") {
 		configReq.FileSystemConfigs = make([]*lambda.FileSystemConfig, 0)
 		if v, ok := d.GetOk("file_system_config"); ok && len(v.([]interface{})) > 0 {
 			configReq.FileSystemConfigs = expandLambdaFileSystemConfigs(v.([]interface{}))
 		}
-		configUpdate = true
+	}
+	if d.HasChange("image_config") {
+		configReq.ImageConfig = &lambda.ImageConfig{}
+		if v, ok := d.GetOk("image_config"); ok && len(v.([]interface{})) > 0 {
+			configReq.ImageConfig = expandLambdaImageConfigs(v.([]interface{}))
+		}
 	}
 	if d.HasChange("memory_size") {
 		configReq.MemorySize = aws.Int64(int64(d.Get("memory_size").(int)))
-		configUpdate = true
 	}
 	if d.HasChange("role") {
 		configReq.Role = aws.String(d.Get("role").(string))
-		configUpdate = true
 	}
 	if d.HasChange("timeout") {
 		configReq.Timeout = aws.Int64(int64(d.Get("timeout").(int)))
-		configUpdate = true
 	}
 	if d.HasChange("kms_key_arn") {
 		configReq.KMSKeyArn = aws.String(d.Get("kms_key_arn").(string))
-		configUpdate = true
 	}
 	if d.HasChange("layers") {
 		layers := d.Get("layers").([]interface{})
 		configReq.Layers = expandStringList(layers)
-		configUpdate = true
 	}
 	if d.HasChange("dead_letter_config") {
 		dlcMaps := d.Get("dead_letter_config").([]interface{})
@@ -744,7 +972,6 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 			dlcMap := dlcMaps[0].(map[string]interface{})
 			configReq.DeadLetterConfig.TargetArn = aws.String(dlcMap["target_arn"].(string))
 		}
-		configUpdate = true
 	}
 	if d.HasChange("tracing_config") {
 		tracingConfig := d.Get("tracing_config").([]interface{})
@@ -753,7 +980,6 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 			configReq.TracingConfig = &lambda.TracingConfig{
 				Mode: aws.String(config["mode"].(string)),
 			}
-			configUpdate = true
 		}
 	}
 	if d.HasChange("vpc_config") {
@@ -766,12 +992,10 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 			configReq.VpcConfig.SecurityGroupIds = expandStringSet(vpcConfig["security_group_ids"].(*schema.Set))
 			configReq.VpcConfig.SubnetIds = expandStringSet(vpcConfig["subnet_ids"].(*schema.Set))
 		}
-		configUpdate = true
 	}
 
 	if d.HasChange("runtime") {
 		configReq.Runtime = aws.String(d.Get("runtime").(string))
-		configUpdate = true
 	}
 	if d.HasChange("environment") {
 		if v, ok := d.GetOk("environment"); ok {
@@ -787,16 +1011,14 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 				configReq.Environment = &lambda.Environment{
 					Variables: aws.StringMap(variables),
 				}
-				configUpdate = true
 			}
 		} else {
 			configReq.Environment = &lambda.Environment{
 				Variables: aws.StringMap(map[string]string{}),
 			}
-			configUpdate = true
 		}
 	}
-
+	configUpdate := hasConfigChanges(d)
 	if configUpdate {
 		log.Printf("[DEBUG] Send Update Lambda Function Configuration request: %#v", configReq)
 
@@ -829,7 +1051,7 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 		})
 		if err != nil {
 			if !isAWSErr(err, "InvalidParameterValueException", "Your request has been throttled by EC2, please make sure you have enough API rate limit.") {
-				return fmt.Errorf("Error modifying Lambda Function Configuration %s: %s", d.Id(), err)
+				return fmt.Errorf("Error modifying Lambda Function (%s) configuration : %w", d.Id(), err)
 			}
 			// Allow 9 more minutes for EC2 throttling
 			err := resource.Retry(9*time.Minute, func() *resource.RetryError {
@@ -849,12 +1071,12 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 				_, err = conn.UpdateFunctionConfiguration(configReq)
 			}
 			if err != nil {
-				return fmt.Errorf("Error modifying Lambda Function Configuration %s: %s", d.Id(), err)
+				return fmt.Errorf("Error modifying Lambda Function Configuration %s: %w", d.Id(), err)
 			}
 		}
 
 		if err := waitForLambdaFunctionUpdate(conn, d.Id(), d.Timeout(schema.TimeoutUpdate)); err != nil {
-			return fmt.Errorf("error waiting for Lambda Function (%s) update: %s", d.Id(), err)
+			return fmt.Errorf("error waiting for Lambda Function (%s) update: %w", d.Id(), err)
 		}
 	}
 
@@ -872,9 +1094,11 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 			defer awsMutexKV.Unlock(awsMutexLambdaKey)
 			file, err := loadFileContent(v.(string))
 			if err != nil {
-				return fmt.Errorf("Unable to load %q: %s", v.(string), err)
+				return fmt.Errorf("Unable to load %q: %w", v.(string), err)
 			}
 			codeReq.ZipFile = file
+		} else if v, ok := d.GetOk("image_uri"); ok {
+			codeReq.ImageUri = aws.String(v.(string))
 		} else {
 			s3Bucket, _ := d.GetOk("s3_bucket")
 			s3Key, _ := d.GetOk("s3_key")
@@ -891,7 +1115,7 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 
 		_, err := conn.UpdateFunctionCode(codeReq)
 		if err != nil {
-			return fmt.Errorf("Error modifying Lambda Function Code %s: %s", d.Id(), err)
+			return fmt.Errorf("error modifying Lambda Function (%s) Code: %w", d.Id(), err)
 		}
 	}
 
@@ -908,7 +1132,7 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 
 			_, err := conn.PutFunctionConcurrency(concurrencyParams)
 			if err != nil {
-				return fmt.Errorf("Error setting concurrency for Lambda %s: %s", d.Id(), err)
+				return fmt.Errorf("error setting Lambda Function (%s) concurrency: %w", d.Id(), err)
 			}
 		} else {
 			log.Printf("[DEBUG] Removing Concurrency for the Lambda Function %s", d.Id())
@@ -918,20 +1142,20 @@ func resourceAwsLambdaFunctionUpdate(d *schema.ResourceData, meta interface{}) e
 			}
 			_, err := conn.DeleteFunctionConcurrency(deleteConcurrencyParams)
 			if err != nil {
-				return fmt.Errorf("Error setting concurrency for Lambda %s: %s", d.Id(), err)
+				return fmt.Errorf("error setting Lambda Function (%s) concurrency: %w", d.Id(), err)
 			}
 		}
 	}
 
 	publish := d.Get("publish").(bool)
-	if publish && (codeUpdate || configUpdate) {
+	if publish && (codeUpdate || configUpdate || d.HasChange("publish")) {
 		versionReq := &lambda.PublishVersionInput{
 			FunctionName: aws.String(d.Id()),
 		}
 
 		_, err := conn.PublishVersion(versionReq)
 		if err != nil {
-			return fmt.Errorf("Error publishing Lambda Function Version %s: %s", d.Id(), err)
+			return fmt.Errorf("Error publishing Lambda Function (%s) version: %w", d.Id(), err)
 		}
 	}
 
@@ -1050,6 +1274,20 @@ func waitForLambdaFunctionUpdate(conn *lambda.Lambda, functionName string, timeo
 	return err
 }
 
+func flattenLambdaEnvironment(apiObject *lambda.EnvironmentResponse) []interface{} {
+	if apiObject == nil {
+		return nil
+	}
+
+	tfMap := map[string]interface{}{}
+
+	if v := apiObject.Variables; v != nil {
+		tfMap["variables"] = aws.StringValueMap(v)
+	}
+
+	return []interface{}{tfMap}
+}
+
 func flattenLambdaFileSystemConfigs(fscList []*lambda.FileSystemConfig) []map[string]interface{} {
 	results := make([]map[string]interface{}, 0, len(fscList))
 	for _, fsc := range fscList {
@@ -1073,3 +1311,33 @@ func expandLambdaFileSystemConfigs(fscMaps []interface{}) []*lambda.FileSystemCo
 	}
 	return fileSystemConfigs
 }
+
+func flattenLambdaImageConfig(response *lambda.ImageConfigResponse) []map[string]interface{} {
+	settings := make(map[string]interface{})
+
+	if response == nil || response.Error != nil {
+		return nil
+	}
+
+	settings["command"] = response.ImageConfig.Command
+	settings["entry_point"] = response.ImageConfig.EntryPoint
+	settings["working_directory"] = response.ImageConfig.WorkingDirectory
+
+	return []map[string]interface{}{settings}
+}
+
+func expandLambdaImageConfigs(imageConfigMaps []interface{}) *lambda.ImageConfig {
+	imageConfig := &lambda.ImageConfig{}
+	// only one image_config block is allowed
+	if len(imageConfigMaps) == 1 && imageConfigMaps[0] != nil {
+		config := imageConfigMaps[0].(map[string]interface{})
+		if len(config["entry_point"].([]interface{})) > 0 {
+			imageConfig.EntryPoint = expandStringList(config["entry_point"].([]interface{}))
+		}
+		if len(config["command"].([]interface{})) > 0 {
+			imageConfig.Command = expandStringList(config["command"].([]interface{}))
+		}
+		imageConfig.WorkingDirectory = aws.String(config["working_directory"].(string))
+	}
+	return imageConfig
+}
