@@ -29,7 +29,7 @@ func TestLambdaPermissionUnmarshalling(t *testing.T) {
 		t.Fatalf("Expected Sid to match (%q != %q)", v.Statement[0].Sid, expectedSid)
 	}
 
-	expectedFunctionName := "arn:aws:lambda:eu-west-1:319201112229:function:myCustomFunction"
+	expectedFunctionName := "arn:aws:lambda:eu-west-1:319201112229:function:myCustomFunction" // lintignore:AWSAT003,AWSAT005 // unit test
 	if v.Statement[0].Resource != expectedFunctionName {
 		t.Fatalf("Expected function name to match (%q != %q)", v.Statement[0].Resource, expectedFunctionName)
 	}
@@ -60,7 +60,7 @@ func TestLambdaPermissionUnmarshalling(t *testing.T) {
 }
 
 func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_alias(t *testing.T) {
-	arnWithAlias := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:testalias"
+	arnWithAlias := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:testalias" // lintignore:AWSAT003,AWSAT005 // unit test
 	expectedQualifier := "testalias"
 	qualifier, err := getQualifierFromLambdaAliasOrVersionArn(arnWithAlias)
 	if err != nil {
@@ -71,7 +71,7 @@ func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_alias(t *testin
 	}
 }
 func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_govcloud(t *testing.T) {
-	arnWithAlias := "arn:aws-us-gov:lambda:us-gov-west-1:187636751137:function:lambda_function_name:testalias"
+	arnWithAlias := "arn:aws-us-gov:lambda:us-gov-west-1:187636751137:function:lambda_function_name:testalias" // lintignore:AWSAT003,AWSAT005 // unit test
 	expectedQualifier := "testalias"
 	qualifier, err := getQualifierFromLambdaAliasOrVersionArn(arnWithAlias)
 	if err != nil {
@@ -83,7 +83,7 @@ func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_govcloud(t *tes
 }
 
 func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_version(t *testing.T) {
-	arnWithVersion := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:223"
+	arnWithVersion := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:223" // lintignore:AWSAT003,AWSAT005 // unit test
 	expectedQualifier := "223"
 	qualifier, err := getQualifierFromLambdaAliasOrVersionArn(arnWithVersion)
 	if err != nil {
@@ -95,7 +95,7 @@ func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_version(t *test
 }
 
 func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_invalid(t *testing.T) {
-	invalidArn := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name"
+	invalidArn := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name" // lintignore:AWSAT003,AWSAT005 // unit test
 	qualifier, err := getQualifierFromLambdaAliasOrVersionArn(invalidArn)
 	if err == nil {
 		t.Fatalf("Expected error when getting qualifier")
@@ -105,7 +105,7 @@ func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_invalid(t *test
 	}
 
 	// with trailing colon
-	invalidArn = "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:"
+	invalidArn = "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:" // lintignore:AWSAT003,AWSAT005 // unit test
 	qualifier, err = getQualifierFromLambdaAliasOrVersionArn(invalidArn)
 	if err == nil {
 		t.Fatalf("Expected error when getting qualifier")
@@ -116,7 +116,7 @@ func TestLambdaPermissionGetQualifierFromLambdaAliasOrVersionArn_invalid(t *test
 }
 
 func TestLambdaPermissionGetFunctionNameFromLambdaArn_invalid(t *testing.T) {
-	invalidArn := "arn:aws:lambda:us-west-2:187636751137:function:"
+	invalidArn := "arn:aws:lambda:us-west-2:187636751137:function:" // lintignore:AWSAT003,AWSAT005 // unit test
 	fn, err := getFunctionNameFromLambdaArn(invalidArn)
 	if err == nil {
 		t.Fatalf("Expected error when parsing invalid ARN (%q)", invalidArn)
@@ -127,7 +127,7 @@ func TestLambdaPermissionGetFunctionNameFromLambdaArn_invalid(t *testing.T) {
 }
 
 func TestLambdaPermissionGetFunctionNameFromLambdaArn_valid(t *testing.T) {
-	validArn := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name"
+	validArn := "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name" // lintignore:AWSAT003,AWSAT005 // unit test
 	fn, err := getFunctionNameFromLambdaArn(validArn)
 	if err != nil {
 		t.Fatalf("Expected no error (%q): %q", validArn, err)
@@ -139,7 +139,7 @@ func TestLambdaPermissionGetFunctionNameFromLambdaArn_valid(t *testing.T) {
 	}
 
 	// With qualifier
-	validArn = "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:12"
+	validArn = "arn:aws:lambda:us-west-2:187636751137:function:lambda_function_name:12" // lintignore:AWSAT003,AWSAT005 // unit test
 	fn, err = getFunctionNameFromLambdaArn(validArn)
 	if err != nil {
 		t.Fatalf("Expected no error (%q): %q", validArn, err)
@@ -152,7 +152,7 @@ func TestLambdaPermissionGetFunctionNameFromLambdaArn_valid(t *testing.T) {
 }
 
 func TestLambdaPermissionGetFunctionNameFromGovCloudLambdaArn(t *testing.T) {
-	validArn := "arn:aws-us-gov:lambda:us-gov-west-1:187636751137:function:lambda_function_name"
+	validArn := "arn:aws-us-gov:lambda:us-gov-west-1:187636751137:function:lambda_function_name" // lintignore:AWSAT003,AWSAT005 // unit test
 	fn, err := getFunctionNameFromLambdaArn(validArn)
 	if err != nil {
 		t.Fatalf("Expected no error (%q): %q", validArn, err)
@@ -884,6 +884,7 @@ EOF
 }
 
 func testAccAWSLambdaPermissionConfig_withQualifier(aliasName, funcName, roleName string) string {
+	// lintignore:AWSAT003,AWSAT005 // ARN, region not actually used
 	return fmt.Sprintf(`
 resource "aws_lambda_permission" "with_qualifier" {
   statement_id   = "AllowExecutionWithQualifier"
@@ -1128,6 +1129,7 @@ EOF
 `, funcName, roleName)
 }
 
+// lintignore:AWSAT003,AWSAT005 // unit test
 var testLambdaPolicy = []byte(`{
   "Version": "2012-10-17",
   "Statement": [
