@@ -196,6 +196,7 @@ func TestAccAWSS3BucketObject_etagEncryption(t *testing.T) {
 	resourceName := "aws_s3_bucket_object.object"
 	rInt := acctest.RandInt()
 	source := testAccAWSS3BucketObjectCreateTempFile(t, "{anything will do }")
+	defer os.Remove(source)
 
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:     func() { testAccPreCheck(t) },
@@ -1258,8 +1259,8 @@ func testAccCheckAWSS3BucketObjectCheckTags(n string, expectedTags map[string]st
 func testAccAWSS3BucketObjectConfigBasic(bucket, key string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket_object" "object" {
-  bucket = %q
-  key    = %q
+  bucket = %[1]q
+  key    = %[2]q
 }
 `, bucket, key)
 }
@@ -1280,13 +1281,13 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfigSource(randInt int, source string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket       = aws_s3_bucket.object_bucket.bucket
   key          = "test-key"
-  source       = %q
+  source       = %[2]q
   content_type = "binary/octet-stream"
 }
 `, randInt, source)
@@ -1295,13 +1296,13 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withContentCharacteristics(randInt int, source string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket           = aws_s3_bucket.object_bucket.bucket
   key              = "test-key"
-  source           = %q
+  source           = %[2]q
   content_language = "en"
   content_type     = "binary/octet-stream"
   website_redirect = "http://google.com"
@@ -1312,13 +1313,13 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfigContent(randInt int, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket  = aws_s3_bucket.object_bucket.bucket
   key     = "test-key"
-  content = %q
+  content = %[2]q
 }
 `, randInt, content)
 }
@@ -1342,13 +1343,13 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfigContentBase64(randInt int, contentBase64 string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket         = aws_s3_bucket.object_bucket.bucket
   key            = "test-key"
-  content_base64 = %q
+  content_base64 = %[2]q
 }
 `, randInt, contentBase64)
 }
@@ -1356,10 +1357,10 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_updateable(randInt int, bucketVersioning bool, source string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket_3" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
-    enabled = %t
+    enabled = %[2]t
   }
 }
 
@@ -1401,13 +1402,13 @@ func testAccAWSS3BucketObjectConfig_withKMSId(randInt int, source string) string
 resource "aws_kms_key" "kms_key_1" {}
 
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket     = aws_s3_bucket.object_bucket.bucket
   key        = "test-key"
-  source     = %q
+  source     = %[2]q
   kms_key_id = aws_kms_key.kms_key_1.arn
 }
 `, randInt, source)
@@ -1416,13 +1417,13 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withSSE(randInt int, source string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket                 = aws_s3_bucket.object_bucket.bucket
   key                    = "test-key"
-  source                 = %q
+  source                 = %[2]q
   server_side_encryption = "AES256"
 }
 `, randInt, source)
@@ -1431,7 +1432,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_acl(randInt int, content, acl string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1441,8 +1442,8 @@ resource "aws_s3_bucket" "object_bucket" {
 resource "aws_s3_bucket_object" "object" {
   bucket  = aws_s3_bucket.object_bucket.bucket
   key     = "test-key"
-  content = %q
-  acl     = %q
+  content = %[2]q
+  acl     = %[3]q
 }
 `, randInt, content, acl)
 }
@@ -1450,14 +1451,14 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_storageClass(randInt int, storage_class string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
   bucket        = aws_s3_bucket.object_bucket.bucket
   key           = "test-key"
   content       = "some_bucket_content"
-  storage_class = %q
+  storage_class = %[2]q
 }
 `, randInt, storage_class)
 }
@@ -1465,7 +1466,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withTags(randInt int, key, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1474,8 +1475,8 @@ resource "aws_s3_bucket" "object_bucket" {
 
 resource "aws_s3_bucket_object" "object" {
   bucket  = aws_s3_bucket.object_bucket.bucket
-  key     = %q
-  content = %q
+  key     = %[2]q
+  content = %[3]q
 
   tags = {
     Key1 = "AAA"
@@ -1489,7 +1490,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withUpdatedTags(randInt int, key, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1498,8 +1499,8 @@ resource "aws_s3_bucket" "object_bucket" {
 
 resource "aws_s3_bucket_object" "object" {
   bucket  = aws_s3_bucket.object_bucket.bucket
-  key     = %q
-  content = %q
+  key     = %[2]q
+  content = %[3]q
 
   tags = {
     Key2 = "BBB"
@@ -1514,7 +1515,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withNoTags(randInt int, key, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1523,8 +1524,8 @@ resource "aws_s3_bucket" "object_bucket" {
 
 resource "aws_s3_bucket_object" "object" {
   bucket  = aws_s3_bucket.object_bucket.bucket
-  key     = %q
-  content = %q
+  key     = %[2]q
+  content = %[3]q
 }
 `, randInt, key, content)
 }
@@ -1532,7 +1533,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withMetadata(randInt int, metadataKey1, metadataValue1, metadataKey2, metadataValue2 string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 }
 
 resource "aws_s3_bucket_object" "object" {
@@ -1550,7 +1551,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_noObjectLockLegalHold(randInt int, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1564,7 +1565,7 @@ resource "aws_s3_bucket" "object_bucket" {
 resource "aws_s3_bucket_object" "object" {
   bucket        = aws_s3_bucket.object_bucket.bucket
   key           = "test-key"
-  content       = %q
+  content       = %[2]q
   force_destroy = true
 }
 `, randInt, content)
@@ -1573,7 +1574,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withObjectLockLegalHold(randInt int, content, legalHoldStatus string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1587,8 +1588,8 @@ resource "aws_s3_bucket" "object_bucket" {
 resource "aws_s3_bucket_object" "object" {
   bucket                        = aws_s3_bucket.object_bucket.bucket
   key                           = "test-key"
-  content                       = %q
-  object_lock_legal_hold_status = %q
+  content                       = %[2]q
+  object_lock_legal_hold_status = %[3]q
   force_destroy                 = true
 }
 `, randInt, content, legalHoldStatus)
@@ -1597,7 +1598,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_noObjectLockRetention(randInt int, content string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1611,7 +1612,7 @@ resource "aws_s3_bucket" "object_bucket" {
 resource "aws_s3_bucket_object" "object" {
   bucket        = aws_s3_bucket.object_bucket.bucket
   key           = "test-key"
-  content       = %q
+  content       = %[2]q
   force_destroy = true
 }
 `, randInt, content)
@@ -1620,7 +1621,7 @@ resource "aws_s3_bucket_object" "object" {
 func testAccAWSS3BucketObjectConfig_withObjectLockRetention(randInt int, content, retainUntilDate string) string {
 	return fmt.Sprintf(`
 resource "aws_s3_bucket" "object_bucket" {
-  bucket = "tf-object-test-bucket-%d"
+  bucket = "tf-object-test-bucket-%[1]d"
 
   versioning {
     enabled = true
@@ -1634,10 +1635,10 @@ resource "aws_s3_bucket" "object_bucket" {
 resource "aws_s3_bucket_object" "object" {
   bucket                        = aws_s3_bucket.object_bucket.bucket
   key                           = "test-key"
-  content                       = %q
+  content                       = %[2]q
   force_destroy                 = true
   object_lock_mode              = "GOVERNANCE"
-  object_lock_retain_until_date = %q
+  object_lock_retain_until_date = %[3]q
 }
 `, randInt, content, retainUntilDate)
 }
