@@ -14,6 +14,26 @@ import (
 	"github.com/hashicorp/terraform-plugin-sdk/v2/terraform"
 )
 
+type TunnelOptions struct {
+	psk                        string
+	tunnelCidr                 string
+	dpdTimeoutAction           string
+	dpdTimeoutSeconds          int
+	ikeVersions                string
+	phase1DhGroupNumbers       string
+	phase1EncryptionAlgorithms string
+	phase1IntegrityAlgorithms  string
+	phase1LifetimeSeconds      int
+	phase2DhGroupNumbers       string
+	phase2EncryptionAlgorithms string
+	phase2IntegrityAlgorithms  string
+	phase2LifetimeSeconds      int
+	rekeyFuzzPercentage        int
+	rekeyMarginTimeSeconds     int
+	replayWindowSize           int
+	startupAction              string
+}
+
 func init() {
 	resource.AddTestSweepers("aws_vpn_connection", &resource.Sweeper{
 		Name: "aws_vpn_connection",
@@ -88,6 +108,7 @@ func TestAccAWSVpnConnection_basic(t *testing.T) {
 				Check: resource.ComposeTestCheckFunc(
 					testAccAwsVpnConnectionExists(resourceName, &vpn),
 					resource.TestCheckResourceAttr(resourceName, "transit_gateway_attachment_id", ""),
+					resource.TestCheckResourceAttr(resourceName, "enable_acceleration", "false"),
 					testAccMatchResourceAttrRegionalARN(resourceName, "arn", "ec2", regexp.MustCompile(`vpn-connection/vpn-.+`)),
 					resource.TestCheckResourceAttr(resourceName, "tags.%", "0"),
 				),
@@ -144,6 +165,46 @@ func TestAccAWSVpnConnection_tunnelOptions(t *testing.T) {
 	resourceName := "aws_vpn_connection.test"
 	var vpn ec2.VpnConnection
 
+	tunnel1 := TunnelOptions{
+		psk:                        "12345678",
+		tunnelCidr:                 "169.254.8.0/30",
+		dpdTimeoutAction:           "clear",
+		dpdTimeoutSeconds:          30,
+		ikeVersions:                "\"ikev1\", \"ikev2\"",
+		phase1DhGroupNumbers:       "2, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24",
+		phase1EncryptionAlgorithms: "\"AES128\", \"AES256\", \"AES128-GCM-16\", \"AES256-GCM-16\"",
+		phase1IntegrityAlgorithms:  "\"SHA1\", \"SHA2-256\", \"SHA2-384\", \"SHA2-512\"",
+		phase1LifetimeSeconds:      28800,
+		phase2DhGroupNumbers:       "2, 5, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24",
+		phase2EncryptionAlgorithms: "\"AES128\", \"AES256\", \"AES128-GCM-16\", \"AES256-GCM-16\"",
+		phase2IntegrityAlgorithms:  "\"SHA1\", \"SHA2-256\", \"SHA2-384\", \"SHA2-512\"",
+		phase2LifetimeSeconds:      3600,
+		rekeyFuzzPercentage:        100,
+		rekeyMarginTimeSeconds:     540,
+		replayWindowSize:           1024,
+		startupAction:              "add",
+	}
+
+	tunnel2 := TunnelOptions{
+		psk:                        "abcdefgh",
+		tunnelCidr:                 "169.254.9.0/30",
+		dpdTimeoutAction:           "clear",
+		dpdTimeoutSeconds:          30,
+		ikeVersions:                "\"ikev1\", \"ikev2\"",
+		phase1DhGroupNumbers:       "2, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24",
+		phase1EncryptionAlgorithms: "\"AES128\", \"AES256\", \"AES128-GCM-16\", \"AES256-GCM-16\"",
+		phase1IntegrityAlgorithms:  "\"SHA1\", \"SHA2-256\", \"SHA2-384\", \"SHA2-512\"",
+		phase1LifetimeSeconds:      28800,
+		phase2DhGroupNumbers:       "2, 5, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24",
+		phase2EncryptionAlgorithms: "\"AES128\", \"AES256\", \"AES128-GCM-16\", \"AES256-GCM-16\"",
+		phase2IntegrityAlgorithms:  "\"SHA1\", \"SHA2-256\", \"SHA2-384\", \"SHA2-512\"",
+		phase2LifetimeSeconds:      3600,
+		rekeyFuzzPercentage:        100,
+		rekeyMarginTimeSeconds:     540,
+		replayWindowSize:           1024,
+		startupAction:              "add",
+	}
+
 	resource.ParallelTest(t, resource.TestCase{
 		PreCheck:      func() { testAccPreCheck(t) },
 		IDRefreshName: resourceName,
@@ -210,9 +271,26 @@ func TestAccAWSVpnConnection_tunnelOptions(t *testing.T) {
 				ExpectError: regexp.MustCompile(`can only contain alphanumeric, period and underscore characters`),
 			},
 
+			// Should pre-check:
+			// - local_ipv4_network_cidr
+			// - local_ipv6_network_cidr
+			// - remote_ipv4_network_cidr
+			// - remote_ipv6_network_cidr
+			// - tunnel_inside_ip_version
+			// - tunnel1_dpd_timeout_action
+			// - tunnel1_dpd_timeout_seconds
+			// - tunnel1_phase1_lifetime_seconds
+			// - tunnel1_phase2_lifetime_seconds
+			// - tunnel1_rekey_fuzz_percentage
+			// - tunnel1_rekey_margin_time_seconds
+			// - tunnel1_replay_window_size
+			// - tunnel1_startup_action
+			// - tunnel1_inside_cidr
+			// - tunnel1_inside_ipv6_cidr
+
 			//Try actual building
 			{
-				Config: testAccAwsVpnConnectionConfigTunnelOptions(rBgpAsn, "12345678", "169.254.8.0/30", "abcdefgh", "169.254.9.0/30"),
+				Config: testAccAwsVpnConnectionConfigTunnelOptions(rBgpAsn, "192.168.1.1/32", "192.168.1.2/32", tunnel1, tunnel2),
 				Check: resource.ComposeTestCheckFunc(
 					testAccAwsVpnConnectionExists(resourceName, &vpn),
 					resource.TestCheckResourceAttr(resourceName, "static_routes_only", "false"),
@@ -246,6 +324,60 @@ func TestAccAWSVpnConnection_withoutStaticRoutes(t *testing.T) {
 				Check: resource.ComposeTestCheckFunc(
 					testAccAwsVpnConnectionExists(resourceName, &vpn),
 					resource.TestCheckResourceAttr(resourceName, "static_routes_only", "false"),
+					resource.TestCheckResourceAttr(resourceName, "enable_acceleration", "false"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
+func TestAccAWSVpnConnection_withEnableAcceleration(t *testing.T) {
+	rBgpAsn := acctest.RandIntRange(64512, 65534)
+	resourceName := "aws_vpn_connection.test"
+	var vpn ec2.VpnConnection
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:      func() { testAccPreCheck(t) },
+		IDRefreshName: resourceName,
+		Providers:     testAccProviders,
+		CheckDestroy:  testAccAwsVpnConnectionDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAwsVpnConnectionConfigEnableAcceleration(rBgpAsn),
+				Check: resource.ComposeTestCheckFunc(
+					testAccAwsVpnConnectionExists(resourceName, &vpn),
+					resource.TestCheckResourceAttr(resourceName, "enable_acceleration", "true"),
+				),
+			},
+			{
+				ResourceName:      resourceName,
+				ImportState:       true,
+				ImportStateVerify: true,
+			},
+		},
+	})
+}
+
+func TestAccAWSVpnConnection_withIpv6(t *testing.T) {
+	rBgpAsn := acctest.RandIntRange(64512, 65534)
+	resourceName := "aws_vpn_connection.test"
+	var vpn ec2.VpnConnection
+
+	resource.ParallelTest(t, resource.TestCase{
+		PreCheck:      func() { testAccPreCheck(t) },
+		IDRefreshName: resourceName,
+		Providers:     testAccProviders,
+		CheckDestroy:  testAccAwsVpnConnectionDestroy,
+		Steps: []resource.TestStep{
+			{
+				Config: testAccAwsVpnConnectionConfigIpv6(rBgpAsn, "fd00:2001:db8:2:2d1:81ff:fe41:d201/128", "fd00:2001:db8:2:2d1:81ff:fe41:d202/128", "fd00:2001:db8:2:2d1:81ff:fe41:d200/126", "fd00:2001:db8:2:2d1:81ff:fe41:d204/126"),
+				Check: resource.ComposeTestCheckFunc(
+					testAccAwsVpnConnectionExists(resourceName, &vpn),
 				),
 			},
 			{
@@ -497,6 +629,55 @@ resource "aws_vpn_connection" "test" {
 `, rBgpAsn, rInt)
 }
 
+func testAccAwsVpnConnectionConfigEnableAcceleration(rBgpAsn int) string {
+	return fmt.Sprintf(`
+resource "aws_ec2_transit_gateway" "test" {}
+resource "aws_customer_gateway" "customer_gateway" {
+  bgp_asn    = %d
+  ip_address = "178.0.0.1"
+  type       = "ipsec.1"
+  tags = {
+    Name = "tf-acc-test-ec2-vpn-connection-enable-acceleration"
+  }
+}
+resource "aws_vpn_connection" "test" {
+  customer_gateway_id = aws_customer_gateway.customer_gateway.id
+  transit_gateway_id  = aws_ec2_transit_gateway.test.id
+  type                = "ipsec.1"
+  static_routes_only  = false
+  enable_acceleration = true
+}
+`, rBgpAsn)
+}
+
+func testAccAwsVpnConnectionConfigIpv6(rBgpAsn int, localIpv6NetworkCidr string, remoteIpv6NetworkCidr string, tunnel1InsideIpv6Cidr string, tunnel2InsideIpv6Cidr string) string {
+	return fmt.Sprintf(`
+resource "aws_ec2_transit_gateway" "test" {}
+resource "aws_customer_gateway" "customer_gateway" {
+  bgp_asn    = %d
+  ip_address = "178.0.0.1"
+  type       = "ipsec.1"
+  tags = {
+    Name = "tf-acc-test-ec2-vpn-connection-enable-acceleration"
+  }
+}
+resource "aws_vpn_connection" "test" {
+  customer_gateway_id = aws_customer_gateway.customer_gateway.id
+  transit_gateway_id  = aws_ec2_transit_gateway.test.id
+  type                = "ipsec.1"
+  static_routes_only  = false
+  enable_acceleration = false
+
+  local_ipv6_network_cidr  = %[2]q
+  remote_ipv6_network_cidr = %[3]q
+  tunnel_inside_ip_version = "ipv6"
+
+  tunnel1_inside_ipv6_cidr = %[4]q
+  tunnel2_inside_ipv6_cidr = %[5]q
+}
+`, rBgpAsn, localIpv6NetworkCidr, remoteIpv6NetworkCidr, tunnel1InsideIpv6Cidr, tunnel2InsideIpv6Cidr)
+}
+
 func testAccAwsVpnConnectionConfigSingleTunnelOptions(rBgpAsn int, psk string, tunnelCidr string) string {
 	return fmt.Sprintf(`
 resource "aws_vpn_gateway" "vpn_gateway" {
@@ -549,7 +730,13 @@ resource "aws_vpn_connection" "test" {
 `, rBgpAsn)
 }
 
-func testAccAwsVpnConnectionConfigTunnelOptions(rBgpAsn int, psk string, tunnelCidr string, psk2 string, tunnelCidr2 string) string {
+func testAccAwsVpnConnectionConfigTunnelOptions(
+	rBgpAsn int,
+	localIpv4NetworkCidr string,
+	remoteIpv4NetworkCidr string,
+	tunnel1 TunnelOptions,
+	tunnel2 TunnelOptions,
+) string {
 	return fmt.Sprintf(`
 resource "aws_vpn_gateway" "vpn_gateway" {
   tags = {
@@ -573,13 +760,83 @@ resource "aws_vpn_connection" "test" {
   type                = "ipsec.1"
   static_routes_only  = false
 
-  tunnel1_inside_cidr   = "%s"
-  tunnel1_preshared_key = "%s"
+  local_ipv4_network_cidr  = %[2]q
+  remote_ipv4_network_cidr = %[3]q
 
-  tunnel2_inside_cidr   = "%s"
-  tunnel2_preshared_key = "%s"
+  tunnel1_inside_cidr                  = %[4]q
+  tunnel1_preshared_key                = %[5]q
+  tunnel1_dpd_timeout_action           = %[6]q
+  tunnel1_dpd_timeout_seconds          = %[7]d
+  tunnel1_ike_versions                 = [%[8]s]
+  tunnel1_phase1_dh_group_numbers      = [%[9]s]
+  tunnel1_phase1_encryption_algorithms = [%[10]s]
+  tunnel1_phase1_integrity_algorithms  = [%[11]s]
+  tunnel1_phase1_lifetime_seconds      = %[12]d
+  tunnel1_phase2_dh_group_numbers      = [%[13]s]
+  tunnel1_phase2_encryption_algorithms = [%[14]s]
+  tunnel1_phase2_integrity_algorithms  = [%[15]s]
+  tunnel1_phase2_lifetime_seconds      = %[16]d
+  tunnel1_rekey_fuzz_percentage        = %[17]d
+  tunnel1_rekey_margin_time_seconds    = %[18]d
+  tunnel1_replay_window_size           = %[19]d
+  tunnel1_startup_action               = %[20]q
+
+  tunnel2_inside_cidr                  = %[21]q
+  tunnel2_preshared_key                = %[22]q
+  tunnel2_dpd_timeout_action           = %[23]q
+  tunnel2_dpd_timeout_seconds          = %[24]d
+  tunnel2_ike_versions                 = [%[25]s]
+  tunnel2_phase1_dh_group_numbers      = [%[26]s]
+  tunnel2_phase1_encryption_algorithms = [%[27]s]
+  tunnel2_phase1_integrity_algorithms  = [%[28]s]
+  tunnel2_phase1_lifetime_seconds      = %[29]d
+  tunnel2_phase2_dh_group_numbers      = [%[30]s]
+  tunnel2_phase2_encryption_algorithms = [%[31]s]
+  tunnel2_phase2_integrity_algorithms  = [%[32]s]
+  tunnel2_phase2_lifetime_seconds      = %[33]d
+  tunnel2_rekey_fuzz_percentage        = %[34]d
+  tunnel2_rekey_margin_time_seconds    = %[35]d
+  tunnel2_replay_window_size           = %[36]d
+  tunnel2_startup_action               = %[37]q
 }
-`, rBgpAsn, tunnelCidr, psk, tunnelCidr2, psk2)
+`,
+		rBgpAsn,
+		localIpv4NetworkCidr,
+		remoteIpv4NetworkCidr,
+		tunnel1.tunnelCidr,
+		tunnel1.psk,
+		tunnel1.dpdTimeoutAction,
+		tunnel1.dpdTimeoutSeconds,
+		tunnel1.ikeVersions,
+		tunnel1.phase1DhGroupNumbers,
+		tunnel1.phase1EncryptionAlgorithms,
+		tunnel1.phase1IntegrityAlgorithms,
+		tunnel1.phase1LifetimeSeconds,
+		tunnel1.phase2DhGroupNumbers,
+		tunnel1.phase2EncryptionAlgorithms,
+		tunnel1.phase2IntegrityAlgorithms,
+		tunnel1.phase2LifetimeSeconds,
+		tunnel1.rekeyFuzzPercentage,
+		tunnel1.rekeyMarginTimeSeconds,
+		tunnel1.replayWindowSize,
+		tunnel1.startupAction,
+		tunnel2.tunnelCidr,
+		tunnel2.psk,
+		tunnel2.dpdTimeoutAction,
+		tunnel2.dpdTimeoutSeconds,
+		tunnel2.ikeVersions,
+		tunnel2.phase1DhGroupNumbers,
+		tunnel2.phase1EncryptionAlgorithms,
+		tunnel2.phase1IntegrityAlgorithms,
+		tunnel2.phase1LifetimeSeconds,
+		tunnel2.phase2DhGroupNumbers,
+		tunnel2.phase2EncryptionAlgorithms,
+		tunnel2.phase2IntegrityAlgorithms,
+		tunnel2.phase2LifetimeSeconds,
+		tunnel2.rekeyFuzzPercentage,
+		tunnel2.rekeyMarginTimeSeconds,
+		tunnel2.replayWindowSize,
+		tunnel2.startupAction)
 }
 
 func testAccAwsVpnConnectionConfigTags1(rBgpAsn int, tagKey1, tagValue1 string) string {
