@@ -10,7 +10,6 @@ import (
 	"github.com/aws/aws-sdk-go/service/autoscaling"
 	"github.com/aws/aws-sdk-go/service/cognitoidentityprovider"
 	"github.com/aws/aws-sdk-go/service/ec2"
-	"github.com/aws/aws-sdk-go/service/elasticache"
 	"github.com/aws/aws-sdk-go/service/elb"
 	"github.com/aws/aws-sdk-go/service/kinesis"
 	"github.com/aws/aws-sdk-go/service/organizations"
@@ -22,8 +21,8 @@ import (
 
 func TestDiffStringMaps(t *testing.T) {
 	cases := []struct {
-		Old, New       map[string]interface{}
-		Create, Remove map[string]interface{}
+		Old, New                  map[string]interface{}
+		Create, Remove, Unchanged map[string]interface{}
 	}{
 		// Add
 		{
@@ -38,6 +37,9 @@ func TestDiffStringMaps(t *testing.T) {
 				"bar": "baz",
 			},
 			Remove: map[string]interface{}{},
+			Unchanged: map[string]interface{}{
+				"foo": "bar",
+			},
 		},
 
 		// Modify
@@ -54,6 +56,7 @@ func TestDiffStringMaps(t *testing.T) {
 			Remove: map[string]interface{}{
 				"foo": "bar",
 			},
+			Unchanged: map[string]interface{}{},
 		},
 
 		// Overlap
@@ -72,6 +75,9 @@ func TestDiffStringMaps(t *testing.T) {
 			Remove: map[string]interface{}{
 				"foo": "bar",
 			},
+			Unchanged: map[string]interface{}{
+				"hello": "world",
+			},
 		},
 
 		// Remove
@@ -87,19 +93,26 @@ func TestDiffStringMaps(t *testing.T) {
 			Remove: map[string]interface{}{
 				"bar": "baz",
 			},
+			Unchanged: map[string]interface{}{
+				"foo": "bar",
+			},
 		},
 	}
 
 	for i, tc := range cases {
-		c, r := diffStringMaps(tc.Old, tc.New)
+		c, r, u := diffStringMaps(tc.Old, tc.New)
 		cm := pointersMapToStringList(c)
 		rm := pointersMapToStringList(r)
+		um := pointersMapToStringList(u)
 		if !reflect.DeepEqual(cm, tc.Create) {
 			t.Fatalf("%d: bad create: %#v", i, cm)
 		}
 		if !reflect.DeepEqual(rm, tc.Remove) {
 			t.Fatalf("%d: bad remove: %#v", i, rm)
 		}
+		if !reflect.DeepEqual(um, tc.Unchanged) {
+			t.Fatalf("%d: bad unchanged: %#v", i, rm)
+		}
 	}
 }
 
@@ -505,7 +518,7 @@ func TestFlattenHealthCheck(t *testing.T) {
 func TestFlattenOrganizationsOrganizationalUnits(t *testing.T) {
 	input := []*organizations.OrganizationalUnit{
 		{
-			Arn:  aws.String("arn:aws:organizations::123456789012:ou/o-abcde12345/ou-ab12-abcd1234"),
+			Arn:  aws.String("arn:aws:organizations::123456789012:ou/o-abcde12345/ou-ab12-abcd1234"), //lintignore:AWSAT005
 			Id:   aws.String("ou-ab12-abcd1234"),
 			Name: aws.String("Engineering"),
 		},
@@ -513,7 +526,7 @@ func TestFlattenOrganizationsOrganizationalUnits(t *testing.T) {
 
 	expected_output := []map[string]interface{}{
 		{
-			"arn":  "arn:aws:organizations::123456789012:ou/o-abcde12345/ou-ab12-abcd1234",
+			"arn":  "arn:aws:organizations::123456789012:ou/o-abcde12345/ou-ab12-abcd1234", //lintignore:AWSAT005
 			"id":   "ou-ab12-abcd1234",
 			"name": "Engineering",
 		},
@@ -526,11 +539,11 @@ func TestFlattenOrganizationsOrganizationalUnits(t *testing.T) {
 }
 
 func TestExpandStringList(t *testing.T) {
-	expanded := []interface{}{"us-east-1a", "us-east-1b"}
+	expanded := []interface{}{"us-east-1a", "us-east-1b"} //lintignore:AWSAT003
 	stringList := expandStringList(expanded)
 	expected := []*string{
-		aws.String("us-east-1a"),
-		aws.String("us-east-1b"),
+		aws.String("us-east-1a"), //lintignore:AWSAT003
+		aws.String("us-east-1b"), //lintignore:AWSAT003
 	}
 
 	if !reflect.DeepEqual(stringList, expected) {
@@ -604,29 +617,6 @@ func TestExpandRedshiftParameters(t *testing.T) {
 	}
 }
 
-func TestExpandElasticacheParameters(t *testing.T) {
-	expanded := []interface{}{
-		map[string]interface{}{
-			"name":         "activerehashing",
-			"value":        "yes",
-			"apply_method": "immediate",
-		},
-	}
-	parameters := expandElastiCacheParameters(expanded)
-
-	expected := &elasticache.ParameterNameValue{
-		ParameterName:  aws.String("activerehashing"),
-		ParameterValue: aws.String("yes"),
-	}
-
-	if !reflect.DeepEqual(parameters[0], expected) {
-		t.Fatalf(
-			"Got:\n\n%#v\n\nExpected:\n\n%#v\n",
-			parameters[0],
-			expected)
-	}
-}
-
 func TestExpandStepAdjustments(t *testing.T) {
 	expanded := []interface{}{
 		map[string]interface{}{
@@ -712,35 +702,6 @@ func TestFlattenRedshiftParameters(t *testing.T) {
 	}
 }
 
-func TestFlattenElasticacheParameters(t *testing.T) {
-	cases := []struct {
-		Input  []*elasticache.Parameter
-		Output []map[string]interface{}
-	}{
-		{
-			Input: []*elasticache.Parameter{
-				{
-					ParameterName:  aws.String("activerehashing"),
-					ParameterValue: aws.String("yes"),
-				},
-			},
-			Output: []map[string]interface{}{
-				{
-					"name":  "activerehashing",
-					"value": "yes",
-				},
-			},
-		},
-	}
-
-	for _, tc := range cases {
-		output := flattenElastiCacheParameters(tc.Input)
-		if !reflect.DeepEqual(output, tc.Output) {
-			t.Fatalf("Got:\n\n%#v\n\nExpected:\n\n%#v", output, tc.Output)
-		}
-	}
-}
-
 func TestExpandInstanceString(t *testing.T) {
 
 	expected := []*elb.Instance{
@@ -1614,7 +1575,7 @@ const testExampleXML_from_msdn_flawed = `
 // TestExpandRdsClusterScalingConfiguration_serverless removed in v3.0.0
 // as all engine_modes are treated equal when expanding scaling_configuration
 // and an override of min_capacity is no longer needed
-// Reference: https://github.com/terraform-providers/terraform-provider-aws/issues/11698
+// Reference: https://github.com/hashicorp/terraform-provider-aws/issues/11698
 
 func TestExpandRdsClusterScalingConfiguration_basic(t *testing.T) {
 	type testCase struct {
